#!/usr/bin/env bash
set -o errexit -o nounset -o pipefail

export SRC=build
export S3_BUCKET="es-use1stag-hm-assets"
export S3_SUBFOLDER="component-library/$CIRCLE_BRANCH"
export DEST="s3://$S3_BUCKET/$S3_SUBFOLDER"
export AWS_REGION="$AWS_DEFAULT_REGION"

if [ -n "$CIRCLE_BRANCH" ]; then
    echo "** Deploy Demo App to $DEST"
    aws s3 sync "$SRC" "$DEST" --delete --cache-control max-age=1800,public --profile assume-role
    aws s3 cp "$SRC/index.html" "$DEST/index.html" --metadata-directive REPLACE --cache-control max-age=0,no-cache,no-store,must-revalidate --content-type text/html --profile assume-role

    if [ -n "${CIRCLE_PULL_REQUEST:-}" ]; then
        export PR_NUMBER=$(echo "${CIRCLE_PULL_REQUEST}" | sed -e 's#^.*pull/\([0-9]\+\)$#\1#')
        if [ -z "${PR_NUMBER}" ]; then
            echo "Could not determine PR_NUMBER from ${CIRCLE_PULL_REQUEST}"
            exit 2
        fi
        python3 .deploy/comment-pr.py ElevateSecurity/elevate-component-library "https://s3.elevatesecurity-staging.com/component-library/${CIRCLE_BRANCH}/index.html"
    else
        echo "Not a Pull Request build - skipping PR comments"
    fi

else
  echo "Not a branch build, skipping"
fi
