/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withState } from '@dump247/storybook-state'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'

// Components
import AppliedFilters from './index'
import { Typography } from '..'
import { humanize } from 'utils/strings'

const { H1 } = Typography

addDecorator(withA11y)
addDecorator(withKnobs)

const state = {
  eventslogAppliedFilters: [
    {
      key: 'action',
      value: 'malware',
      original: 'malware',
      humanizedName: humanize('action')
    }
  ],
  auditlogAppliedFilters: [
    {
      key: 'filterBy',
      value: 'audit logs',
      original: 'audit log',
      humanizedName: humanize('FilterBy')
    },
    {
      key: 'when',
      value: ['2022-07-01', '2022-06-30'],
      original: ['2022-07-01', '2022-06-30'],
      humanizedName: humanize('when')
    },
    {
      key: 'old_value',
      value: 'LOW RISK',
      original: 'LOW RISK',
      humanizedName: humanize('old_value')
    },
    {
      key: 'new_value',
      value: 'HIGH RISK',
      original: 'HIGH RISK',
      humanizedName: humanize('new_value')
    },
    {
      key: 'integration_source',
      value: 'authentication',
      original: 'authentication',
      humanizedName: humanize('integration_source')
    }
  ],
  individualsInvolvedAppliedFilters: [
    {
      key: 'overall',
      value: '2 - 10',
      original: '2 - 10',
      name: 'human_risk_score',
      humanizedName: 'Human Risk Score'
    },
    {
      key: 'access_factor',
      value: 'very_high',
      original: 'very_high',
      name: 'access_factor',
      humanizedName: 'Access Factor'
    },
    {
      key: 'attack_factor',
      value: 'very_high',
      original: 'very_high',
      name: 'attack_factor',
      humanizedName: 'Attack Factor'
    },
    {
      key: 'department',
      value: 'data-science',
      original: 'Data Science',
      name: 'department',
      humanizedName: 'Department'
    },
    {
      key: 'location',
      value: 'eu',
      original: 'EU',
      name: 'location',
      humanizedName: 'Location'
    }
  ],
  rapAppliedFilters: [
    {
      key: 'human_risk_score',
      value: '2 - 10',
      original: '2 - 10',
      name: 'human_risk_score',
      humanizedName: 'Human Risk Score'
    },
    {
      key: 'malware',
      value: '2 - 10',
      original: '2 - 10',
      name: 'malware',
      humanizedName: 'Malware'
    },
    {
      key: 'password_manager',
      value: '2 - 10',
      original: '2 - 10',
      name: 'password_manager',
      humanizedName: 'Password Manager'
    },
    {
      key: 'simulated_phishing',
      value: '2 - 10',
      original: '2 - 10',
      name: 'simulated_phishing',
      humanizedName: 'Simulated Phishing'
    },
    {
      key: 'actual_phishing',
      value: '2 - 10',
      original: '2 - 10',
      name: 'actual_phishing',
      humanizedName: 'Actual Phishing'
    },
    {
      key: 'secure_browsing',
      value: '2 - 10',
      original: '2 - 10',
      name: 'secure_browsing',
      humanizedName: 'Secure Browsing'
    },
    {
      key: 'sensitive_data_handling',
      value: '2 - 10',
      original: '2 - 10',
      name: 'sensitive_data_handling',
      humanizedName: 'Sensitive Data Handling'
    },
    {
      key: 'training',
      value: '2 - 10',
      original: '2 - 10',
      name: 'training',
      humanizedName: 'Training'
    }
  ]
}

storiesOf('AppliedFilters', module)
  .addParameters({
    jest: ['AppliedFilters']
  })
  .add(
    'Events log applied filters',
    withState(state)(({ store }) => (
      <>
        <H1>Events log applied filters</H1>
        <AppliedFilters
          appliedFilters={store.state.eventslogAppliedFilters}
          handleRemoveFilter={() => alert('This action will be handled by client')}
        />
      </>
    ))
  )
  .add(
    'Audit logs applied filters',
    withState(state)(({ store }) => (
      <>
        <H1>Audit logs applied filters</H1>
        <AppliedFilters
          appliedFilters={store.state.auditlogAppliedFilters}
          handleRemoveFilter={() => alert('This action will be handled by client')}
        />
      </>
    ))
  )
  .add(
    'Individuals involved applied filters',
    withState(state)(({ store }) => (
      <>
        <H1>Individuals involved applied filters</H1>
        <AppliedFilters
          appliedFilters={store.state.individualsInvolvedAppliedFilters}
          handleRemoveFilter={() => alert('This action will be handled by client')}
        />
      </>
    ))
  )
  .add(
    'Risk analysis page applied filters',
    withState(state)(({ store }) => (
      <>
        <H1>Risk analysis page applied filters</H1>
        <AppliedFilters
          appliedFilters={store.state.rapAppliedFilters}
          handleRemoveFilter={() => alert('This action will be handled by client')}
        />
      </>
    ))
  )
