import React from 'react'
import { humanize } from 'utils/strings'
import { Icon } from '..'
import { StyledChip } from './AppliedFilters.styles'

export const Chip = ({ name, humanizedName, value, onClick, ...rest }) => {
  const labelMap = {
    overall: val => val,
    date: val => val.join('-'),
    when: val => val.join('-'),
    human_risk_score: val => val,
    malware: val => val,
    password_manager: val => val,
    simulated_phishing: val => val,
    actual_phishing: val => val,
    secure_browsing: val => val,
    sensitive_data_handling: val => val,
    training: val => val
  }

  const display = val => {
    return labelMap[name] !== undefined ? labelMap[name](val) : humanize(val)
  }

  return (
    <StyledChip {...rest}>
      {`${humanize(humanizedName)}: `}
      {React.isValidElement(value) ? value : <b>{display(value)}</b>}

      <span data-test-id="remove-filter-handler" onClick={() => (onClick ? onClick() : '')}>
        <Icon name="Close" stroke="#959DA8" size="sm" />
      </span>
    </StyledChip>
  )
}
