import React from 'react'
import PropTypes from 'prop-types'

import { Chip } from './Chip'
import { TagsBar, List } from './AppliedFilters.styles'

function AppliedFilters(props) {
  const { appliedFilters, handleRemoveFilter } = props

  if (!appliedFilters || !appliedFilters.length) {
    return <></>
  }

  return (
    <TagsBar>
      <List>
        {appliedFilters?.map(section => (
          <Chip
            data-test-id="applied-filters-list-item"
            key={section.value}
            index={section.value}
            name={section.key}
            humanizedName={section.humanizedName}
            value={section.value}
            onClick={() => {
              handleRemoveFilter(section)
            }}
          />
        ))}
      </List>
    </TagsBar>
  )
}

AppliedFilters.defaultFilter = {
  appliedFilters: [],
  handleRemoveFilter: () => {
    // This is intentional
  }
}

AppliedFilters.propTypes = {
  appliedFilters: PropTypes.array,
  handleRemoveFilter: PropTypes.func
}

export default AppliedFilters
