// Libraries
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import styled from 'styled-components'

// Theme
import theme from 'theme'

// D3
import { select } from 'd3-selection'
import {
  axisBottom, axisLeft, axisRight, axisTop
} from 'd3-axis'

// Styles
const AxisGroup = styled.g`
  font-family: ${theme.text.fontFamily.default};
  font-size: ${theme.text.fontSize.sm};
`

class Axis extends Component {
  componentDidMount() {
    this.drawAxis()
  }

  componentDidUpdate() {
    this.drawAxis()
  }

  drawAxis() {
    const {
      gridColor,
      orientation,
      scale,
      showAxis,
      showGrid,
      tickColor,
      tickColorScale,
      tickPadding,
      ticks,
      tickSize,
      tickValues
    } = this.props

    const axes = {
      bottom: axisBottom,
      left: axisLeft,
      right: axisRight,
      top: axisTop
    }

    const axis = axes[orientation]()
      .scale(scale)
      .tickSize(tickSize)
      .tickPadding(tickPadding)

    if (ticks) axis.ticks(ticks)
    if (tickValues) axis.tickValues(tickValues)

    select(this.axisEl).call(axis)

    if (!showAxis) {
      select(this.axisEl)
        .selectAll('path')
        .attr('stroke', 'none')
    }

    if (showGrid) {
      select(this.axisEl)
        .selectAll('.tick')
        .selectAll('line')
        .attr('stroke', gridColor)
        .attr('fill', gridColor)
    }

    select(this.axisEl)
      .selectAll('.tick')
      .selectAll('text')
      .attr('fill', d => (tickColorScale ? tickColorScale(d) : tickColor))
  }

  render() {
    const { translate } = this.props

    return (
      <AxisGroup
        ref={(el) => {
          this.axisEl = el
        }}
        transform={translate}
      />
    )
  }
}

export default Axis

Axis.propTypes = {
  gridColor: PropTypes.string,
  orientation: PropTypes.oneOf(['top', 'right', 'bottom', 'left']),
  scale: PropTypes.func.isRequired,
  showAxis: PropTypes.bool,
  showGrid: PropTypes.bool,
  tickColor: PropTypes.string,
  tickColorScale: PropTypes.func,
  tickSize: PropTypes.arrayOf(PropTypes.number),
  tickPadding: PropTypes.arrayOf(PropTypes.number),
  ticks: PropTypes.oneOfType([PropTypes.array, PropTypes.number, PropTypes.func]),
  tickValues: PropTypes.arrayOf(PropTypes.any),
  translate: PropTypes.string
}

Axis.defaultProps = {
  gridColor: theme.text.color.default,
  orientation: 'bottom',
  showAxis: false,
  showGrid: false,
  tickColor: theme.text.color.default,
  tickColorScale: null,
  tickSize: [0],
  tickPadding: [7],
  ticks: null,
  tickValues: null,
  translate: 'translate(0, 0)'
}
