/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'
import styled from 'styled-components'
import theme from 'theme'

// Components
import Badge from './index'

addDecorator(withA11y)
addDecorator(withKnobs)

const Container = styled.div`
  display: flex;
  flex-wrap: wrap;
  padding: 20px;
  font-family: ${theme.text.fontFamily.default};
`

const Wrapper = styled.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  margin-right: 20px;
  >:last-child {
    margin-top: 10px;
    font-size: 13px;
    color: #333333;
  }

`

const themes = ['gray', 'yellow', 'blue', 'red', 'green', 'white']

storiesOf('Badge', module)
  .addParameters({
    jest: ['Badge'],
  })
  .add('Badge Rounded', () => {
    return (
      <Container>
        <Wrapper>
          <Badge text="Draft" theme="gray" />
          <span>gray</span>
        </Wrapper>
        <Wrapper>
          <Badge text="Scheduled" theme="yellow" />
          <span>yellow</span>
        </Wrapper>
        <Wrapper>
          <Badge text="In Progress" theme="blue" />
          <span>blue</span>
        </Wrapper>
        <Wrapper>
          <Badge text="Cancelled" theme="red" />
          <span>red</span>
        </Wrapper>
        <Wrapper>
          <Badge text="Completed" theme="green" />
          <span>green</span>
        </Wrapper>
        <Wrapper>
          <Badge text="Archived" theme="white" />
          <span>white</span>
        </Wrapper>
      </Container>
    )
  })
  .add('Badge Rectangular', () => {
    return (
      <Container>
        {
          themes.map(_theme => (
            <Wrapper>
              <Badge text="10 of 15 licenses used" theme={_theme} shape="rectangle" />
              <span>{_theme}</span>
            </Wrapper>
          ))
        }
      </Container>
    )
  })
