import React from 'react'
import PropTypes from 'prop-types'
import { getColorAndSizeByScore, SCORE_COLORS } from 'components/BarColors/utils'
import { BarColorsWrapper, Bullet, ScoreBar } from 'components/BarColors/BarColors.styles'

export default function BarColors({
  score,
  size,
  hasIndicatorBox,
  invert,
  showCircle,
  sameColor,
  barColor,
  padding,
  isActionFactorChart,
  showWideBar
}) {
  function renderBars() {
    const SCORE_COLORS_INVERTED = [
      { color: "#2C9097", min: 0, max: 20 },
      { color: "#3CC1AE", min: 21, max: 40 },
      { color: "#FACC38", min: 41, max: 60 },
      { color: "#F08526", min: 61, max: 80 },
      { color: "#D23A54", min: 81, max: 100 }
    ]

    const SAME_SCORE_COLORS = [
      { color: barColor, min: 0, max: 20 },
      { color: barColor, min: 21, max: 40 },
      { color: barColor, min: 41, max: 60 },
      { color: barColor, min: 61, max: 80 },
      { color: barColor, min: 81, max: 100 }
    ]

    const getScoreColors = () => {
      if (sameColor) {
        return SAME_SCORE_COLORS
      } else if (invert) {
        return SCORE_COLORS_INVERTED
      } else {
        return SCORE_COLORS
      }
    }

    return getScoreColors().map(({ color, max, min }, i) => {
      const barInfo = getColorAndSizeByScore({
        color,
        max,
        min,
        score,
        invert
      })
      return (
        <ScoreBar
          barInfo={barInfo}
          key={`score_bar_${i}`}
          size={size}
          isActionFactorChart={isActionFactorChart}
          showWideBar={showWideBar}
        >
          {showCircle && (
            <Bullet
              barInfo={barInfo}
              size={size}
              hasIndicatorBox={hasIndicatorBox}
            />
          )}
        </ScoreBar>
      )
    })
  }
  return <BarColorsWrapper padding={padding}>{renderBars()}</BarColorsWrapper>
}

BarColors.propTypes = {
  score: PropTypes.number,
  size: PropTypes.oneOf(['small', 'medium', 'default']),
  hasIndicatorBox:PropTypes.bool,
  invert: PropTypes.bool,
  showCircle: PropTypes.bool,
  sameColor: PropTypes.bool,
  barColor: PropTypes.string,
  padding: PropTypes.bool,
  isActionFactorChart: PropTypes.bool,
  showWideBar: PropTypes.number
}

BarColors.defaultProps = {
  score: 100,
  size: "small",
  hasIndicatorBox: false,
  invert: false,
  showCircle: true,
  sameColor: false,
  padding: true,
  isActionFactorChart: false,
  showWideBar: 0,
  barColor: "#D23A54"
}
