/* global test shallow expect */

import React from 'react'
import { BrowserRouter } from 'react-router-dom'

import Breadcrumb from './index'
import Link from '../Link'
import { Small } from '../Typography'

test('render Breadcrumb', () => {
  const wrapper = shallow(
    <BrowserRouter>
      <Breadcrumb>
        <Link title="First Page" to="/" />
        <Link title="Second Page" to="/" />
        <Link title="Third Page" to="/" />
      </Breadcrumb>
    </BrowserRouter>
  )
  expect(wrapper).toMatchSnapshot()
})


test('render Breadcrumb with just one link', () => {
  const wrapper = shallow(
    <BrowserRouter>
      <Breadcrumb>
        <Link title="First Page" to="/" />
      </Breadcrumb>
    </BrowserRouter>
  )
  expect(wrapper).toMatchSnapshot()
})

test('render Breadcrumb with minWidth', () => {
  const wrapper = shallow(
    <BrowserRouter>
      <Breadcrumb minWidth>
        <Link title="First Page" to="/">
          <Small>First Page to ensure ease of clickability</Small>
        </Link>
        <Link title="Second Page" to="/">
          <Small>Test</Small>
        </Link>
        <Link title="Third Page" to="/">
          <Small>Third Page</Small>
        </Link>
      </Breadcrumb>
    </BrowserRouter>
  )
  expect(wrapper).toMatchSnapshot()
})

test('render Breadcrumb with maxWidth', () => {
  const wrapper = shallow(
    <BrowserRouter>
      <Breadcrumb maxWidth>
        <Link title="First Page" to="/">
          <Small>First Page to ensure ease of clickability</Small>
        </Link>
        <Link title="Second Page" to="/">
          <Small>Test</Small>
        </Link>
        <Link title="Third Page" to="/">
          <Small>Third Page</Small>
        </Link>
      </Breadcrumb>
    </BrowserRouter>
  )
  expect(wrapper).toMatchSnapshot()
})
