/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { BrowserRouter } from 'react-router-dom'

import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'

// Components
import Breadcrumb from './index'
import Link from '../Link'
import { Small } from '../Typography'

addDecorator(withA11y)
addDecorator(withKnobs)

storiesOf('Breadcrumb', module)
  .addParameters({
    jest: ['Breadcrumb']
  })
  .add('Default Breadcrumb', () => (
    <BrowserRouter>
      <Breadcrumb>
        <Link to="/"><Small color="300">Current Page</Small></Link>
      </Breadcrumb>
    </BrowserRouter>
  ))
  .add('Breadcrumb with 3 links', () => (
    <BrowserRouter>
      <Breadcrumb>
        <Link to="/">
          <Small color="link">First Page</Small>
        </Link>
        <Link to="/">
          <Small color="link">Second Page</Small>
        </Link>
        <Link to="/">
          <Small color="300">Third Page</Small>
        </Link>
      </Breadcrumb>
    </BrowserRouter>
  ))
  .add('Breadcrumb - Truncation - minWidth', () => (
    <BrowserRouter>
      <Breadcrumb minWidth>
        <Link to="/">
          <Small color="link">First Page to ensure ease of clickability</Small>
        </Link>
        <Link to="/">
          <Small color="link">Test</Small>
        </Link>
        <Link to="/">
          <Small color="300">Third Page</Small>
        </Link>
      </Breadcrumb>
    </BrowserRouter>
  ))
  .add('Breadcrumb - Truncation - maxWidth', () => (
    <BrowserRouter>
      <Breadcrumb maxWidth > 
        <Link to="/">
          <Small color="link">Truncate After 200px  Unless It’s...</Small>
        </Link>
        <Link to="/">
          <Small color="link">Second Page</Small>
        </Link>
        <Link to="/">
          <Small color="300">Third Page</Small>
        </Link>
      </Breadcrumb>
    </BrowserRouter>
  ))
  .add('Breadcrumb - Truncation - Max and Min Width', () => (
    <BrowserRouter>
      <Breadcrumb maxWidth minWidth > 
        <Link to="/">
          <Small color="link">First Page with both props with ease clickability</Small>
        </Link>
        <Link to="/">
          <Small color="link">Test</Small>
        </Link>
        <Link to="/">
          <Small color="300">Third Page </Small>
        </Link>
      </Breadcrumb>
    </BrowserRouter>
  ))
