/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs, select } from '@storybook/addon-knobs'
import { action } from '@storybook/addon-actions'

// Themes
import theme from 'theme'

// Components
import { Button } from './index'

addDecorator(withA11y)
addDecorator(withKnobs)

const size = {}

Object.keys(theme.button.height).forEach((key) => {
  size[key] = key
})

storiesOf('Button', module)
  .addParameters({
    jest: ['Button'],
  })
  .add('base', () => {
    return (
      <div style={{ display: 'flex' }}>
        <div style={{ margin: '20px' }}>
          <Button
            size={select('Size', size, 'default', 'sizes-1')}
            onClick={action('clicked')}
          >
            Button Label
          </Button>
        </div>
        <div style={{ margin: '20px' }}>
          <Button
            size={select('Size', size, 'default', 'sizes-1')}
            theme="secondary"
            onClick={action('clicked')}
          >
            Button Label
          </Button>
        </div>
        <div style={{ margin: '20px' }}>
          <Button
            size={select('Size', size, 'default', 'sizes-1')}
            theme="ghost"
            onClick={action('clicked')}
          >
            Button Label
          </Button>
        </div>
      </div>
    )
  })
  .add('disabled', () => {
    return (
      <div style={{ display: 'flex' }}>
        <div style={{ margin: '20px' }}>
          <Button
            disabled
            size={select('Size', size, 'default', 'sizes-1')}
            fontWeight="bold"
          >
            Label
          </Button>
        </div>
        <div style={{ margin: '20px' }}>
          <Button
            disabled
            size={select('Size', size, 'default', 'sizes-1')}
            theme="secondary"
          >
            Label
          </Button>
        </div>
        <div style={{ margin: '20px' }}>
          <Button
            disabled
            size={select('Size', size, 'default', 'sizes-1')}
            theme="ghost"
          >
            Label
          </Button>
        </div>
      </div>
    )
  })
  .add('link', () => {
    return (
      <div style={{ display: 'flex' }}>
        <div style={{ margin: '20px' }}>
          <Button
            size={select('Size', size, 'default', 'sizes-1')}
            to="https://google.com"
          >
            Google
          </Button>
        </div>
        <div style={{ margin: '20px' }}>
          <Button
            size={select('Size', size, 'default', 'sizes-1')}
            theme="secondary"
            to="https://google.com"
          >
            Google
          </Button>
        </div>
        <div style={{ margin: '20px' }}>
          <Button
            size={select('Size', size, 'default', 'sizes-1')}
            theme="ghost"
            to="https://google.com"
          >
            Google
          </Button>
        </div>
      </div>
    )
  })
  .add('link on new tab', () => {
    return (
      <div style={{ display: 'flex' }}>
        <div style={{ margin: '20px' }}>
          <Button
            size={select('Size', size, 'default', 'sizes-1')}
            theme="secondary"
            to="https://google.com"
            newTab
          >
            Google
          </Button>
        </div>
        <div style={{ margin: '20px' }}>
          <Button
            theme="secondary"
            width="full"
            to="https://elevatesecurity.zendesk.com/hc/en-us"
            newTab
          >
            Go to help center
          </Button>
        </div>
      </div>
    )
  })
