import styled from 'styled-components'
import styledMap from 'styled-map'

import theme from 'theme'

const hasLinkPadding = (link) => {
  return !link ? styledMap('size', theme.button.horizontalPadding) : 0
}

export const StyledButton = styled.button`
  border-radius: ${theme.button.radius};
  border: none;
  transition: background-color ease-out 125ms;
  box-sizing: border-box;
  padding: 0 ${props => hasLinkPadding(props.link)};
  padding-bottom: 1px;

  line-height: calc(${styledMap('size', theme.button.height)} - 1px);
  height: ${styledMap('size', theme.button.height)};
  width: ${styledMap('width', { full: '100%', default: 'auto' })};

  font-weight: ${styledMap('fontWeight', theme.button.fontWeight)};
  font-size: ${styledMap('size', theme.button.fontSize)};
  border: 1px solid transparent;
  background-color: ${styledMap('theme', theme.button.backgroundColor)};
  color: ${styledMap('theme', theme.button.color)};

  cursor: pointer;

  & a {
    color: ${styledMap('theme', theme.button.color)};
    padding: 0 ${props => props.to && styledMap('size', theme.button.horizontalPadding)};

    &:hover {
      color: ${styledMap('theme', theme.button.color)};
    }
  }

  &:hover {
    background-color: ${styledMap('theme', theme.button.hover.backgroundColor)};
    text-decoration: ${styledMap('theme', theme.button.hover.decoration)};
  }

  &:active {
    background-color: ${styledMap('theme', theme.button.active.backgroundColor)};
  }

  &:focus {
    background-color: ${styledMap('theme', theme.button.focus.backgroundColor)};
    outline: none;
    border: 1px solid ${styledMap('theme', theme.button.focus.outline)};
    box-shadow: ${styledMap('theme', theme.button.focus.shadow)};
    text-decoration: ${styledMap('theme', theme.button.hover.decoration)};
    width: calc(${styledMap('width', { full: '100%', default: 'auto' })} - 1px);
    line-height: calc(${styledMap('size', theme.button.height)} - 6px);
  }

  &:disabled {
    cursor: not-allowed;
    background-color: ${styledMap('theme', theme.button.disabled.backgroundColor)};
    color: ${styledMap('theme', theme.button.disabled.color)};
  }
`

export const IconContainer = styled.span`
  display: inline-flex;
  align-self: center;

  & svg,
  & img {
    height: 1em;
    width: 1em;
  }

  &.baseline svg,
  & img {
    top: 0.125em;
    position: relative;
  }
`
