// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'

// styles
import {
  StyledButton,
} from './Button.styles'

import Link from '../Link'

class Button extends PureComponent {
  onClick(e) {
    const {
      disabled,
      onClick
    } = this.props

    if (disabled) return
    if (onClick) onClick(e)
  }

  render() {
    const {
      disabled,
      children,
      icon,
      to,
      newTab,
    } = this.props

    return (
      <StyledButton
        icon={icon}
        link={!!to}
        {...this.props}
        onClick={e => this.onClick(e)}
        className={`${disabled ? 'disabled' : ''}`}
      >
        {
          to ? (
            <Link
              to={to}
              target={newTab ? '_blank' : ''}
              contain="cover"
              {...this.props}
            >
              {children}
            </Link>
          ) : (
            children
          )
        }
      </StyledButton>
    )
  }
}

Button.propTypes = {
  size: PropTypes.string,
  onClick: PropTypes.func,
  disabled: PropTypes.bool,
  children: PropTypes.node,
  icon: PropTypes.bool,
  to: PropTypes.string,
  newTab: PropTypes.bool,
}

Button.defaultProps = {
  size: '',
  children: null,
  onClick: undefined,
  disabled: false,
  icon: false,
  to: '',
  newTab: false
}

export default Button

export { Button }
