// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'

import { Icon } from '../Icon'

// styles
import {
  StyledButton,
  IconContainer
} from './ButtonIcon.styles'

class ButtonIcon extends PureComponent {
  onClick() {
    const {
      disabled,
      onClick
    } = this.props

    if (disabled) return
    if (onClick) onClick()
  }

  render() {
    const {
      disabled,
      icon,
      theme,
      size
    } = this.props

    return (
      <StyledButton
        icon={icon}
        theme={theme}
        onClick={() => this.onClick()}
        className={`${disabled ? 'disabled' : ''}`}
        size={size}
      >
        <IconContainer>
          <Icon name={icon} />
        </IconContainer>
      </StyledButton>
    )
  }
}

ButtonIcon.propTypes = {
  onClick: PropTypes.func,
  disabled: PropTypes.bool,
  icon: PropTypes.string.isRequired,
  theme: PropTypes.string,
  size: PropTypes.string
}

ButtonIcon.defaultProps = {
  onClick: undefined,
  disabled: false,
  theme: '',
  size: 'md'
}

export default ButtonIcon
