// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import styled from 'styled-components'

// Theme
import theme from 'theme'

const StyledButtonLink = styled.a`
cursor: pointer;
font-size: 15px;
color: ${theme.text.color.link};
font-weight: 'normal';
:hover {
  text-decoration: underline;
  color: ${theme.text.color.linkHover};
}
`
class ButtonLink extends PureComponent {
  onClick(e) {
    const {
      disabled,
      onClick
    } = this.props

    if (disabled) return
    if (onClick) onClick(e)
  }

  render() {
    const {
      disabled,
    } = this.props

    return (
      <StyledButtonLink
        {...this.props}
        onClick={e => this.onClick(e)}
        className={`${disabled ? 'disabled' : ''}`}
      />
    )
  }
}

ButtonLink.propTypes = {
  size: PropTypes.string,
  onClick: PropTypes.func,
  disabled: PropTypes.bool,
}

ButtonLink.defaultProps = {
  size: '',
  onClick: undefined,
  disabled: false,
}

export default ButtonLink

export { ButtonLink }
