// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'

import styled from 'styled-components'
import styledMap from 'styled-map'

// Theme
import theme from 'theme'

// Styles
const CardContainer = styled.section`
  color: ${theme.text.color.default};
  border-radius: ${theme.card.borderRadius};
  min-height: 100px;
  min-width: 100px;
  margin: 20px;
  padding: 14px;
  box-shadow: ${styledMap('theme', theme.card.shadow)};
  background-color: ${styledMap('theme', theme.card.backgroundColor)};
  font-family: ${theme.text.fontFamily.default};
`

const CardHeader = styled.div`
  color: ${theme.text.color['900']};
  margin: 10px 10px 15px 10px;
  font-size: ${styledMap('headerSize', theme.text.fontSize)};
  font-weight: ${styledMap('headerWeight', theme.text.fontWeight)};
  border-radius: 15px 15px 0 0;
  padding-top: 10px;
  height: 30px;
  width: 100%;
`

const CardBody = styled.div`
  margin: 10px;
  font-size: ${styledMap('bodySize', theme.text.fontSize)};
  font-weight: ${styledMap('bodyWeight', theme.text.fontWeight)};
`

class Card extends PureComponent {
  render() {
    const { header, children } = this.props

    return (
      <CardContainer {...this.props}>
        {header && <CardHeader {...this.props}>{header}</CardHeader>}
        <CardBody>{children}</CardBody>
      </CardContainer>
    )
  }
}

export default Card

Card.propTypes = {
  header: PropTypes.string,
  theme: PropTypes.string,
  headerSize: PropTypes.string,
  headerWeight: PropTypes.string
}

Card.defaultProps = {
  header: '',
  theme: '',
  headerSize: 'lg',
  headerWeight: ''
}
