/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useState } from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'
import styled from 'styled-components'

// Components
import Carousel from './index'
import { Button } from '../Button'
import { Icon } from '../Icon'

addDecorator(withA11y)
addDecorator(withKnobs)

const Content = styled.div`
  background-color: ${props => props.color};
  width: 100%;
  height: 100%;
  text-align: center;
  color: #333;
`

const nodes = [
  <Content color="#FEDBC1">Slide 1</Content>,
  <Content color="#F8B280">Slide 2</Content>,
  <Content color="#E16720">Slide 3</Content>
]

storiesOf('Carousel', module)
  .addParameters({
    jest: ['Carousel'],
  })
  .add('Carousel', () => {
    const [activeStep, setActiveStep] = useState(1)
    const steps = ['Step 1', 'Step 2', 'Step 3']

    return (
      <Carousel
        steps={steps}
        activeStep={activeStep}
        goToStep={step => setActiveStep(step)}
      />
    )
  })
  .add('Rich content', () => {
    const [activeStep, setActiveStep] = useState(1)
    const steps = nodes

    return (
      <Carousel
        steps={steps}
        activeStep={activeStep}
        goToStep={step => setActiveStep(step)}
      />
    )
  })
  .add('Control with external events', () => {
    const [activeStep, setActiveStep] = useState(1)
    const steps = nodes

    return (
      <div>
        <Carousel
          steps={steps}
          activeStep={activeStep}
          goToStep={step => setActiveStep(step)}
        />
        <div style={{ display: 'flex', marginTop: '20px' }}>
          {
            activeStep > 1
            && (<Button onClick={() => setActiveStep(activeStep - 1)}>Back</Button>)
          }
          <span style={{ margin: 'auto' }} />
          {
            activeStep < steps.length
            && (<Button onClick={() => setActiveStep(activeStep + 1)}>Next</Button>)
          }
        </div>
      </div>
    )
  })
  .add('Hide dots', () => {
    const [activeStep, setActiveStep] = useState(1)
    const steps = nodes

    return (
      <div>
        <Carousel
          steps={steps}
          activeStep={activeStep}
          goToStep={step => setActiveStep(step)}
          showDots={false}
        />
        <div style={{ display: 'flex', marginTop: '20px' }}>
          {
            activeStep > 1
            && (<Button onClick={() => setActiveStep(activeStep - 1)}>Back</Button>)
          }
          <span style={{ margin: 'auto' }} />
          {
            activeStep !== steps.length
            && (<Button onClick={() => setActiveStep(activeStep + 1)}>Next</Button>)
          }
        </div>
      </div>
    )
  })
  .add('Example', () => {
    const [activeStep, setActiveStep] = useState(1)
    const Slide = styled.div`
      height: 240px;
      width: 448px;
      background: linear-gradient(270deg, #FDFBF8 0%, #EDE5DB 100%);
      display: flex;
      justify-content: center;
      align-items: center;
    `
    const steps = [
      <Slide>
        <Icon name="ProductPulseColored" size="lg" />
      </Slide>,
      <Slide>
        <Icon name="ProductPulseGreyscale" size="lg" />
      </Slide>
    ]

    return (
      <div style={{ width: '448px' }}>
        <Carousel
          steps={steps}
          activeStep={activeStep}
          goToStep={step => setActiveStep(step)}
          height="240px"
        />
      </div>
    )
  })
