/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'
import styled from 'styled-components'
import theme from 'theme'

// Components
import Checkbox from './index'

addDecorator(withA11y)
addDecorator(withKnobs)

const CheckboxesContainer = styled.div`
  display: flex;
  flex-wrap: wrap;
  padding: 20px;
  font-family: ${theme.text.fontFamily.default};
`

const WrapperBox = styled.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  margin-right: 20px;
  > span {
    margin-top: 30px;
    font-size: 11px;
    color: #333;
  }
`

const commonProps = () => ({
  onChange: e => console.log(e),
  id: Math.random()
})

const label = "Checkbox Label"
const title = "Checkbox Title"
const description = "Option description"
const errorMessage = "Some validation error"

const renderComponent = props => {
  return (
    <CheckboxesContainer>
      <WrapperBox>
        <Checkbox {...props} checked />
        <span>checked</span>
      </WrapperBox>
      <WrapperBox>
        <Checkbox {...props} checked indeterminate />
        <span>indeterminate</span>
      </WrapperBox>
      <WrapperBox>
        <Checkbox {...props} />
        <span>unchecked</span>
      </WrapperBox>
      <WrapperBox>
        <Checkbox {...props} invalid />
        <span>error</span>
      </WrapperBox>
      <WrapperBox>
        <Checkbox {...props} checked disabled />
        <span>checked-disabled</span>
      </WrapperBox>
      <WrapperBox>
        <Checkbox {...props} checked indeterminate disabled />
        <span>indeterminate disabled</span>
      </WrapperBox>
      <WrapperBox>
        <Checkbox {...props} disabled />
        <span>unchecked disabled</span>
      </WrapperBox>
    </CheckboxesContainer>
  )
}

storiesOf('Checkbox', module)
  .addParameters({
    jest: ['Checkbox'],
  })
  .add('Checkbox with no label', () => {
    const props = commonProps()
    return (
      <CheckboxesContainer>
        <WrapperBox>
          <Checkbox {...props} checked />
          <span>checked</span>
        </WrapperBox>
        <WrapperBox>
          <Checkbox {...props} checked indeterminate />
          <span>indeterminate</span>
        </WrapperBox>
        <WrapperBox>
          <Checkbox {...props} />
          <span>unchecked</span>
        </WrapperBox>
        <WrapperBox>
          <Checkbox {...props} invalid />
          <span>error</span>
        </WrapperBox>
        <WrapperBox>
          <Checkbox {...props} checked disabled />
          <span>checked-disabled</span>
        </WrapperBox>
        <WrapperBox>
          <Checkbox {...props} checked indeterminate disabled />
          <span>indeterminate disabled</span>
        </WrapperBox>
        <WrapperBox>
          <Checkbox {...props} disabled />
          <span>unchecked disabled</span>
        </WrapperBox>
        <WrapperBox>
          <Checkbox {...props} hasDropdown />
          <span>bulk-checkbox button</span>
        </WrapperBox>
      </CheckboxesContainer>
    )
  })
  .add('Checkbox with label', () => {
    const props = {
      label,
      ...commonProps()
    }
    return renderComponent(props)
  })
  .add('Checkbox with description', () => {
    const props = {
      label,
      description,
      ...commonProps()
    }
    return renderComponent(props)
  })
  .add('Checkbox with Title', () => {
    const props = {
      title,
      label,
      description,
      ...commonProps()
    }
    return renderComponent(props)
  })
  .add('Checkbox with Error Message', () => {
    const props = {
      errorMessage,
      title,
      label,
      description,
      ...commonProps()
    }
    return renderComponent(props)
  })
  .add('Checkbox with Bulk Action Menu', () => {
    const props = {
      dropdownOptions: [
        "Bulk action 1",
        "Bulk action 2",
        "Bulk action 3",
        "Bulk action 4",
        "Bulk action 5"
      ],
      onDropdownSelect: option => console.log('Selection bulk operation: ', option),
      ...commonProps()
    }
    return (
      <CheckboxesContainer>
        <WrapperBox>
          <Checkbox {...props} hasDropdown />
          <span>bulk-checkbox button with action dropdown</span>
        </WrapperBox>
      </CheckboxesContainer>
    )
  })
