import React, { useState } from 'react'
import PropTypes from 'prop-types'
import {
  MainWrapper,
  Title,
  ErrorMessage,
  InputCheckbox,
  InputCheckBoxWrapper,
  ContentWrapper,
  Description,
  Caret,
  Dropdown,
  Option
} from './Checkbox.styles'
import Icon from '../Icon'

const Checkbox = ({
  checked,
  disabled,
  indeterminate,
  onChange,
  label,
  description,
  title,
  errorMessage,
  id,
  invalid,
  hasDropdown,
  dropdownOptions,
  onDropdownSelect,
  className
}) => {
  const [dropdownOpen, setDropdownOpen] = useState(false)
  const handleChange = e =>
    onChange(e.currentTarget ? e.currentTarget.checked : null, e)
  const props = {
    ...(checked !== null ? { checked } : {})
  }
  const onOptionSelect = option => {
    onDropdownSelect(option)
    setDropdownOpen(false)
  }

  return (
    <MainWrapper className={className}>
      {title && <Title>{title}</Title>}
      <InputCheckBoxWrapper hasDropdown={hasDropdown} disabled={disabled}>
        <InputCheckbox
          indeterminate={indeterminate}
          disabled={disabled}
          onChange={e => handleChange(e)}
          id={id}
          invalid={invalid}
          {...props}
        />
        {!hasDropdown && (label || description) && <ContentWrapper>
          {label && <label htmlFor={id}>{label}</label>}
          {description && <Description htmlFor={id} disabled={disabled}>{description}</Description>}
        </ContentWrapper>}
        {hasDropdown && (
          <Caret onClick={() => setDropdownOpen(!dropdownOpen)}>
            <Icon name="CaretDown" size="xxsm" fill="#959DA8" />
          </Caret>
        )}
        {hasDropdown &&
          dropdownOpen &&
          dropdownOptions &&
          !!dropdownOptions.length && (
            <Dropdown>
              {dropdownOptions.map(option => (
                <Option key={option} onClick={() => onOptionSelect(option)}>
                  {option}
                </Option>
              ))}
            </Dropdown>
          )}
      </InputCheckBoxWrapper>
      {errorMessage && <ErrorMessage>{errorMessage}</ErrorMessage>}
    </MainWrapper>
  )
}

Checkbox.propTypes = {
  checked: PropTypes.bool,
  disabled: PropTypes.bool,
  indeterminate: PropTypes.bool,
  onChange: PropTypes.func,
  label: PropTypes.string,
  description: PropTypes.string,
  title: PropTypes.string,
  errorMessage: PropTypes.string,
  id: PropTypes.string,
  invalid: PropTypes.bool,
  hasDropdown: PropTypes.bool,
  dropdownOptions: PropTypes.arrayOf(PropTypes.string),
  onDropdownSelect: PropTypes.func,
  className: PropTypes.string
}

Checkbox.defaultProps = {
  checked: null,
  disabled: false,
  indeterminate: false,
  onChange: () => null,
  label: null,
  description: null,
  title: null,
  errorMessage: null,
  id: "checkbox-0",
  invalid: false,
  hasDropdown: false,
  dropdownOptions: [],
  onDropdownSelect: () => null,
  className: ''
}

export default Checkbox
