// Libraries
import React, { useState } from 'react'
import { storiesOf } from '@storybook/react'
// Components
import { ComboBoxWrapper, InnerWrapper } from 'components/ComboBox/ComboBox.styles'
import ComboBox from './index'

const techs = [
  { label: 'Vue JS', value: 355 },
  { label: 'React', value: 54 },
  { label: 'PHP', value: 43 },
  { label: 'Python', value: 443 },
  { label: 'Rubi', value: 434 },
  { label: 'C#', value: 4334 },
  { label: 'C++', value: 43343 , isDisabled:true }
]
const fixedLabelData = [
  { label: 'Vue JS', value: 355 },
  { label: 'React', value: 54 },
  { label: 'PHP', value: 43 },
  { label: 'Python', value: 443 },
  { label: 'Rubi', value: 434 },
  { label: 'C#', value: 4334 },
  { label: 'C++', value: 43343 , isDisabled:true, isSelected: true }
]
const techsSelectedOptions = [
  { label: 'Vue JS', value: 355, isDisabled:true, isSelected: true }
]

const techsRightLabel = [
  { label: 'Vue JS', value: 355, rightLabel: "355" },
  { label: 'React', value: 54, rightLabel: "54" },
  { label: 'PHP', value: 43, rightLabel: "43" },
  { label: 'Python', value: 443, rightLabel: "443" },
  { label: 'Rubi', value: 434, rightLabel: "434" },
  { label: 'C#', value: 4334 },
  { label: 'C++', value: 43343 , isDisabled:true }
]

// basic structure for grouped data type
export const colourOptions = [
  { value: 'ocean', label: 'Ocean', color: '#00B8D9' },
  { value: 'blue', label: 'Blue', color: '#0052CC', disabled: true },
  { value: 'purple', label: 'Purple', color: '#5243AA' },
  { value: 'red', label: 'Red', color: '#FF5630' },
  { value: 'orange', label: 'Orange', color: '#FF8B00' },
  { value: 'yellow', label: 'Yellow', color: '#FFC400' },
  { value: 'green', label: 'Green', color: '#36B37E' },
  { value: 'forest', label: 'Forest', color: '#00875A' },
  { value: 'slate', label: 'Slate', color: '#253858' },
  { value: 'silver', label: 'Silver', color: '#666666' }
]

export const flavourOptions = [
  { value: 'vanilla', label: 'Vanilla', rating: 'safe' },
  { value: 'chocolate', label: 'Chocolate', rating: 'good' },
  { value: 'strawberry', label: 'Strawberry', rating: 'wild' },
  { value: 'salted-caramel', label: 'Salted Caramel', rating: 'crazy' }
]

export const groupedOptions = [
  {
    label: 'Colours',
    options: colourOptions
  },
  {
    label: 'Flavours',
    options: flavourOptions
  }
]

// use cases
storiesOf('ComboBox', module)
  .addParameters({
    jest: ['ComboBox']
  })
  .add('Default Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={techs}
          clearable={false}
          onChange={() => null}
          isSearchable={false}
          isMultiOption={false}
          checked={false}
          hideSelectedOptions
          closeMenuOnSelect
          components={{}}
          disabled={false}
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Grouped Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={groupedOptions}
          clearable={false}
          onChange={() => null}
          isSearchable={false}
          isMultiOption={false}
          checked={false}
          hideSelectedOptions
          closeMenuOnSelect
          components={{}}
          disabled={false}
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Searchable Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={techs}
          clearable={false}
          onChange={() => null}
          isSearchable
          isMultiOption={false}
          checked={false}
          hideSelectedOptions
          closeMenuOnSelect
          components={{}}
          disabled={false}
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Clearable Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={techs}
          clearable
          onChange={() => null}
          isSearchable={false}
          isMultiOption={false}
          checked={false}
          hideSelectedOptions
          closeMenuOnSelect
          components={{}}
          disabled={false}
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Multi option Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={techs}
          clearable={false}
          onChange={() => null}
          isSearchable={false}
          isMultiOption
          checked={false}
          hideSelectedOptions
          closeMenuOnSelect
          components={{}}
          disabled={false}
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Checkbox Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={techs}
          clearable={false}
          onChange={() => null}
          isSearchable={false}
          isMultiOption
          checked
          hideSelectedOptions={false}
          closeMenuOnSelect={false}
          components={{}}
          disabled={false}
          defaultValue={
          [
            { label: 'Vue JS', value: 355 },
            { label: 'React', value: 54 }
          ]
        }
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Checkbox With Select All Combobox', () => {
    return (
      <div style={{ display: 'flex', padding: '20px' }}>
        <div style={{ padding: '10px', width: '400px' }}>
          <br />
          <ComboBox
            data={techs}
            clearable={false}
            isSearchable={false}
            isMultiOption
            checked
            hideSelectedOptions={false}
            closeMenuOnSelect={false}
            components={{}}
            disabled={false}
            allowSelectAll
            onChange={() => null}
            placeholder="Choose..."
          />
        </div>
      </div>
    )
  })
  .add('HasError Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={techs}
          clearable={false}
          onChange={() => null}
          isSearchable={false}
          isMultiOption
          checked={false}
          hideSelectedOptions={false}
          closeMenuOnSelect={false}
          components={{}}
          disabled={false}
          hasError
          errorMessage="some validation error"
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Dropdown with Right Label Combobox', () => (
    <ComboBoxWrapper>
      <InnerWrapper>
        <br />
        <ComboBox
          data={techsRightLabel}
          clearable={false}
          onChange={() => null}
          isSearchable={false}
          isMultiOption
          checked
          hideSelectedOptions={false}
          closeMenuOnSelect={false}
          components={{}}
          disabled={false}
          placeholder="Choose..."
        />
      </InnerWrapper>
    </ComboBoxWrapper>
  ))
  .add('Disabled Combobox', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={techs}
          clearable={false}
          onChange={() => null}
          isSearchable={false}
          isMultiOption
          checked
          hideSelectedOptions={false}
          closeMenuOnSelect={false}
          components={{}}
          disabled
          placeholder="Choose..."
        />
      </div>
    </div>
  ))
  .add('Select and deselect value from parent component', () => {
    const [selectedOptions, setSelectedOptions] = useState(techsSelectedOptions)
    const fixedLabel = [{fixedLabel:<div>12 individuals</div>}]

    return (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px', width: '400px' }}>
        <br />
        <ComboBox
          data={fixedLabelData}
          clearable={false}
          onChange={data => {
            console.log(data)
            setSelectedOptions([...data])
          }}
          value={selectedOptions.some(item=>item.fixedLabel) ? selectedOptions : fixedLabel.concat(selectedOptions)}
          isSearchable
          styles={{
            multiValueRemove: (base, state) => {
              return state.data.fixedLabel ? { ...base, display: 'none' } : base
            },
          }}
          isMultiOption
          checked
          hideSelectedOptions={false}
          closeMenuOnSelect={false}
          components={{}}
          disabled={false}
          placeholder="Choose..."
          handleScrollBotttom={()=>console.log("scrolled Bottom")}
        />
      </div>
    </div>
    )
  })
