import React from "react"
import { components } from "react-select"
import { Checkbox } from 'components'
import { CheckBoxContainer, ChipLeftLabel, ChipRightLabel } from './ComboBox.styles'

export const Option = (props) => {
  const hasSelectAll = props?.selectProps?.value?.some(item => item.value === "*")

  const isRightLabel = !!props?.data.rightLabel

  return (
    <div>
      <components.Option {...props}>
        <CheckBoxContainer>
        <Checkbox
          className='css-shared-chk'
          disabled={props.isDisabled}
          checked={props.data.isSelected || props.isSelected || hasSelectAll}
        />{" "}
          {isRightLabel ? (
            <>
              <ChipLeftLabel>{props.label}</ChipLeftLabel>
              <ChipRightLabel>{props.data.rightLabel}</ChipRightLabel>
            </>
          ) : ( <span>{props.label}</span>)}
        </CheckBoxContainer>
      </components.Option>
    </div>
  )
}

export const ValueContainer = ({ children, ...props }) => {
  const currentValues = props.getValue()
  let toBeRendered = children
  if (currentValues.some(val => val.value === '*')) {
    toBeRendered = [children[0]]
  }

  return (
    <components.ValueContainer {...props}>
      {toBeRendered}
    </components.ValueContainer>
  )
}

export const MultiValue = props => {
  let labelToBeDisplayed = `${props.data.label} `
  if (props.data.value === '*') {
    labelToBeDisplayed = "All is selected"
  }

  if (props.data.fixedLabel){
    return (
      <components.MultiValue {...props}>
        <div>{props.data.fixedLabel}</div>
      </components.MultiValue>
    )
  }

  return (
    <components.MultiValue {...props}>
      <span>{labelToBeDisplayed}</span>
    </components.MultiValue>
  )
}
