import React from 'react'
import Select from 'react-select'
import PropTypes from 'prop-types'
import { SelectContainer } from './ComboBox.styles'
import { Option, ValueContainer, MultiValue } from './_Option'

const ComboBox = ({
  clearable,
  isMultiOption,
  isSearchable,
  data,
  onChange,
  hideSelectedOptions,
  components,
  checked,
  disabled,
  hasError,
  allowSelectAll,
  errorMessage,
  allOption,
  placeholder,
  handleScrollBotttom,
  handleInputChange,
  defaultValue,
  isLoading,
  ...props
}) => {

  const onchangeExtended = (selected, event) => {
    if (selected !== null && selected.length > 0) {
      if (selected[selected.length - 1].value === allOption.value) {
        return onChange([allOption, ...data])
      }
      let result = []
      if (selected.length === data.length) {
        if (selected.includes(allOption)) {
          result = selected.filter(option => option.value !== allOption.value)
        } else if (event.action === 'select-option') {
          result = [allOption, ...data]
        }
        return onChange(result)
      }
    }

    return onChange(selected)
  }
  
  return (
  <SelectContainer hasError={hasError}>
    <Select  
      onChange={checked ? (selected, event) => onchangeExtended(selected, event) : onChange }
      onInputChange={handleInputChange}
      closeMenuOnSelect={!isMultiOption}
      options={allowSelectAll ? [allOption, ...data] : data}
      isClearable={clearable}
      placeholder={placeholder}
      isMulti={isMultiOption}
      isSearchable={isSearchable}
      hideSelectedOptions={hideSelectedOptions}
      components={checked ? { Option, MultiValue, ValueContainer } : components}
      isDisabled={disabled}
      onMenuScrollToBottom={handleScrollBotttom}
      defaultValue={defaultValue}
      isLoading={isLoading}
      {...props}
    />
    {hasError && <p>{errorMessage}</p>}
  </SelectContainer>)
}

  ComboBox.propTypes = {
    clearable: PropTypes.bool,
    disabled: PropTypes.bool,
    isMultiOption: PropTypes.bool,
    onChange: PropTypes.func,
    isSearchable: PropTypes.bool,
    hideSelectedOptions: PropTypes.bool,
    checked: PropTypes.bool,
    hasError: PropTypes.bool,
    allowSelectAll: PropTypes.bool,
    errorMessage: PropTypes.string,
    data: PropTypes.arrayOf(PropTypes.object),
    placeholder: PropTypes.string,
    handleScrollBotttom: PropTypes.func,
    handleInputChange: PropTypes.func,
    allOption: PropTypes.objectOf({}),
    components: PropTypes.objectOf({}),
    defaultValue: PropTypes.arrayOf({}),
    isLoading: PropTypes.bool
  }
  
  ComboBox.defaultProps = {
    checked: false,
    disabled: false,
    onChange: () => null,
    handleInputChange: (data) => data,
    handleScrollBotttom: () => null,
    placeholder: 'Choose...',
    errorMessage: '',
    isMultiOption: false,
    data: [],
    isSearchable: false,
    hideSelectedOptions: false,
    clearable: false,
    hasError: false,
    allowSelectAll: false,
    allOption: {
      label: "Select all",
      value: "*"
    },
    defaultValue: [],
    components: {},
    isLoading: false
  }

export default ComboBox