/* eslint-disable react/forbid-prop-types */
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import Styles from 'components/CustomSelect/CustomSelect.styles'
import {
  getOptionsContainerHeight
} from 'components/CustomSelect/utils'

class CustomOptionsContainer extends Component {
  static propTypes = {
    open: PropTypes.bool.isRequired,
    maxHeight: PropTypes.string,
    nodeRef: PropTypes.object.isRequired,
    listRef: PropTypes.object.isRequired,
  }

  static defaultProps = {
    maxHeight: null
  }

  constructor(props) {
    super(props)
    this.state = {
      height: null,
      maxHeight: props.maxHeight ? parseInt(props.maxHeight, 10) : 450
    }
  }

  componentDidMount() {
    window.addEventListener('resize', this.updateHeight.apply(this))
  }

  componentDidUpdate(prevProps) {
    const { open } = this.props
    if (open && !prevProps.open) {
      this.updateHeight()
    }
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.updateHeight.apply(this))
  }

  updateHeight() {
    const { nodeRef } = this.props
    const height = getOptionsContainerHeight(nodeRef)
    this.setState({
      height
    })
  }

  render() {
    const { height, maxHeight } = this.state
    const {
      open, children, listRef
    } = this.props
    return (
      <Styles.OptionsWrapper open={open} className="dropdown-container">
        <Styles.OptionsContainer
          ref={listRef}
          open={open}
          role="listbox"
          height={height}
          maxHeight={maxHeight}
        >
          {
            open && children
          }
        </Styles.OptionsContainer>
      </Styles.OptionsWrapper>
    )
  }
}


export default CustomOptionsContainer
