/* eslint-disable jsx-a11y/label-has-associated-control */
/* eslint-disable jsx-a11y/label-has-for */
/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useState, useEffect } from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'

// Components
import CustomSelect from './index'
import { Icon } from '../Icon'

addDecorator(withA11y)
addDecorator(withKnobs)

const onChange = (option) => {
  console.log(option)
}

const options = [
  null,
  '',
  'This is a big sentence to test the overflow-x for li',
  'ReactJs',
  'Reacting',
  'Recursive',
  'Recurrent',
  'Vuejs',
  'Vue Components',
  'Angular',
  'Angular Playground',
  'Google Angular',
  'Angular Framework',
  'TypeScript',
  'React TypeScript',
  'TypeScript Angular',
  'flow',
  'GraphQl',

]

// eslint-disable-next-line react/prop-types
const CustomOption = ({ text, users }) => (
  <div style={{ display: 'flex', justifyContent: 'space-between' }}>
    <span>{text}</span>
    <span>{`${users} participants`}</span>
  </div>
)

const customOptions = [
  {
    label: 'Null option',
    value: null
  },
  {
    label: 'React.js',
    value: 'react',
    render: <CustomOption text="React.js" users="30" />
  },
  {
    label: 'Angular.js',
    value: 'angular',
    render: <CustomOption text="Angular" users="23" />
  },
  {
    label: 'Vue.js',
    value: 'vue.js',
    render: <CustomOption text="Vue.js" users="18" />
  }
]

const groupOptions = [
  {
    label: 'Everyone',
    value: '',
    render: <CustomOption text="Everyone" users="1428" />
  },
  {
    group: 'RENDER OPTIONS'
  },
  {
    label: 'Custom Group A',
    value: 'custom-group-a',
    render: <CustomOption text="Custom Group A" users="7" />
  },
  {
    label: 'Custom Group B',
    value: 'custom-group-b',
    render: <CustomOption text="Custom Group B" users="21" />
  },
  {
    group: 'LABEL OPTIONS'
  },
  {
    value: 'new-hires',
    label: 'New Hires'
  },
  {
    value: 'department-1',
    label: 'Department 1'
  },
  {
    value: 'department-2',
    label: 'Department 2'
  }
]

storiesOf('CustomSelect', module)
  .addParameters({
    jest: ['CustomSelect'],
  })
  .add('Default CustomSelect', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <div style={{ padding: '10px' }}>
        <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column' }}>
          <span>Custom select</span>
          <br />
          <CustomSelect
            id="customSelect"
            placeholder="Select a option"
            onChange={onChange}
            options={options}
          />
        </label>
      </div>
    </div>
  ))
  .add('Render custom options', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column', width: '100%' }}>
        <div style={{ marginBottom: '10px' }}>Custom select with custom options rendering</div>
        <CustomSelect
          style={{ width: '100%' }}
          id="customSelect"
          placeholder="Select a option"
          onChange={onChange}
          options={customOptions}
        />
      </label>
    </div>
  ))
  .add('CustomSelect close to the bottom of page', () => (
    <div style={{ display: 'flex', padding: '20px', height: '100vh' }}>
      <div style={{ padding: '10px', marginBottom: 0, marginTop: 'auto' }}>
        <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column' }}>
          <span>Custom select</span>
          <br />
          <CustomSelect
            id="customSelect"
            placeholder="Select a option"
            onChange={onChange}
            options={options}
          />
        </label>
      </div>
    </div>
  ))
  .add('Default CustomSelect with 100% width', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <CustomSelect
        style={{ width: '100%' }}
        placeholder="Select a option"
        onChange={onChange}
        options={options}
      />
    </div>
  ))
  .add('Default CustomSelect, dropdown with max-height 100px', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <CustomSelect
        style={{ width: '100%' }}
        maxHeightDropdown="100px"
        placeholder="Select a option"
        onChange={onChange}
        options={options}
      />
    </div>
  ))
  .add('CustomSelect required', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <CustomSelect
        onChange={onChange}
        required
        placeholder="Select a option"
        options={options}
      />
    </div>
  ))
  .add('CustomSelect disabled', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <CustomSelect
        onChange={onChange}
        disabled
        placeholder="Select a option"
        options={options}
      />
    </div>
  ))
  .add('CustomSelect with icon inside Option ', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <CustomSelect
        onChange={onChange}
        placeholder="Select a option"
        iconLeft={<Icon name="User" />}
        options={options}
      />
    </div>
  ))
  .add('CustomSelect with search ', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <CustomSelect
        onChange={onChange}
        placeholder="Select a option"
        iconLeft={<Icon name="User" />}
        options={options}
        isSearch
      />
    </div>
  ))
  .add('Render custom options with search', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column', width: '100%' }}>
        <div style={{ marginBottom: '10px' }}>Custom select with custom options rendering and search</div>
        <CustomSelect
          style={{ width: '100%' }}
          id="customSelect"
          placeholder="Select a option"
          onChange={onChange}
          options={customOptions}
          isSearch
        />
      </label>
    </div>
  ))
  .add('Render custom options with group', () => (
    <div style={{ display: 'flex', padding: '20px' }}>
      <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column', width: '100%' }}>
        <div style={{ marginBottom: '10px' }}>Custom select with custom options rendering and search</div>
        <CustomSelect
          style={{ width: '100%' }}
          id="customSelect"
          placeholder="Select a option"
          onChange={onChange}
          options={groupOptions}
          isSearch
        />
      </label>
    </div>
  ))
  .add('Render custom options with defaultValue', () => (
    <div>
      <div style={{ display: 'flex', padding: '20px' }}>
        <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column', width: '100%' }}>
          <div style={{ marginBottom: '10px' }}>Custom select with default string value</div>
          <CustomSelect
            style={{ width: '100%' }}
            id="customSelect"
            placeholder="Select a option"
            defaultValue={options[0]}
            onChange={onChange}
            options={options}
            isSearch
          />
        </label>
      </div>
      <div style={{ display: 'flex', padding: '20px' }}>
        <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column', width: '100%' }}>
          <div style={{ marginBottom: '10px' }}>Custom select with custom options and default object value</div>
          <CustomSelect
            style={{ width: '100%' }}
            id="customSelect"
            placeholder="Select a option"
            defaultValue={groupOptions[3]}
            onChange={onChange}
            options={groupOptions}
            isSearch
          />
        </label>
      </div>
      <div style={{ display: 'flex', padding: '20px' }}>
        <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column', width: '100%' }}>
          <div style={{ marginBottom: '10px' }}>Custom select with custom options and default index (number) value</div>
          <CustomSelect
            style={{ width: '100%' }}
            id="customSelect"
            placeholder="Select a option"
            defaultValue={2}
            onChange={onChange}
            options={groupOptions}
            isSearch
          />
        </label>
      </div>
    </div>
  ))
  .add('Update options with a new state after 1 second', () => {
    function ComponentWhatever() {
      const [myOptions, setMyOptions] = useState(options)
      useEffect(() => {
        // update options for testing the re-render list
        setTimeout(() => setMyOptions(myOptions.slice(0, 5)), 1000)
      }, [])
      return (
        <div style={{ display: 'flex', padding: '20px' }}>
          <div style={{ padding: '10px' }}>
            <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column' }}>
              <span>Custom select</span>
              <br />
              <CustomSelect
                id="customSelect"
                placeholder="Select a option"
                onChange={onChange}
                options={myOptions}
              />
            </label>
          </div>
        </div>
      )
    }
    return <ComponentWhatever />
  })
  .add('Render custom options as multi select', () => {
    const BEHAVIORS = {
      P: 'Phishing',
      PM: 'Password Manager',
      M: 'Malware',
      T: 'Training',
      CD: 'Clean Desk'
    }

    function ComponentWhatever() {
      const [selection, setSelection] = useState({
        [BEHAVIORS.P]: false,
        [BEHAVIORS.PM]: false,
        [BEHAVIORS.M]: false,
        [BEHAVIORS.T]: false,
        [BEHAVIORS.CD]: false
      })

      // eslint-disable-next-line react/prop-types
      const SelectOption = ({ label, description }) => (
        <div style={{ display: 'flex', alignItems: 'flex-start' }}>
          <input type="checkbox" style={{ marginRight: '8px', marginTop: '5px' }} checked={selection[label]} onChange={() => null} />
          <div style={{ display: 'flex', flexDirection: 'column' }}>
            <span>{label}</span>
            <span>{description}</span>
          </div>
        </div>
      )

      const optionsList = [
        {
          label: BEHAVIORS.P,
          value: BEHAVIORS.P,
          render: <SelectOption label={BEHAVIORS.P} description="Add behavior category description here." />
        },
        {
          label: BEHAVIORS.PM,
          value: BEHAVIORS.PM,
          render: <SelectOption label={BEHAVIORS.PM} description="Add behavior category description here." />
        },
        {
          label: BEHAVIORS.M,
          value: BEHAVIORS.M,
          render: <SelectOption label={BEHAVIORS.M} description="Add behavior category description here." />
        },
        {
          label: BEHAVIORS.T,
          value: BEHAVIORS.T,
          render: <SelectOption label={BEHAVIORS.T} description="Add behavior category description here." />
        },
        {
          label: BEHAVIORS.CD,
          value: BEHAVIORS.CD,
          render: <SelectOption label={BEHAVIORS.CD} description="Add behavior category description here." />
        }
      ]

      const selectedCount = Object.values(selection).reduce((sum, flag) => sum + flag, 0)
      const inputText = selectedCount ? `Filter by behaviors (${selectedCount} applied)` : 'Filter by behaviors'

      return (
        <div style={{ display: 'flex', padding: '20px' }}>
          <label htmlFor="customSelect" style={{ display: 'flex', flexDirection: 'column', width: '100%' }}>
            <div style={{ marginBottom: '10px' }}>Multi select</div>
            <CustomSelect
              style={{ width: '100%' }}
              id="customSelect"
              placeholder="Filter by behaviors"
              onChange={(option) => {
                onChange(option)
                setSelection({
                  ...selection,
                  [option.value]: !selection[option.value]

                })
              }}
              options={optionsList}
              closeOnSelection={false}
              highlightSelection={false}
              inputText={inputText}
            />
          </label>
        </div>
      )
    }

    return <ComponentWhatever />
  })
