import styled, { css } from 'styled-components'
import theme from 'theme'

export const CustomSelectContainer = styled.div`
  position:relative;
  overflow: visible;
  display: table;
  margin: auto;
  font-size: ${theme.text.fontSize.md};
  &.to-top{
    .dropdown-container{
      transform: translateY(calc(-100% - 44px))
    }
  }
`

export const InputContainer = styled.div`
  display: block;
  height: 40px;
  width: 100%;
  button{
    padding: 0;
    outline: none;
    cursor: default;
    &:hover,
    &:focus{
      background-color: transparent;
      outline: 0;
      box-shadow: none;
    }
  }
  input{
    width: 100%;
    height: 40px;
    padding-right: 30px;
    font-size: ${theme.text.fontSize.md};
  }
  input:focus,
  input:hover { 
    outline: none;
    caret-color:${({ isSearch }) => (!isSearch ? 'transparent' : 'initial')};
    cursor: default;
  }
  input:disabled{
    cursor: not-allowed;
  }
  
`

const getHeight = ({ height, maxHeight }) => `${height > maxHeight ? maxHeight : height}px`

export const OptionsWrapper = styled.div`
  position: absolute;
  top: 100%;
  width: 100%;
  background-color: white;
  height: auto;
  max-height: none;
  margin: 2px 0 0;
  padding: 0;
  border: 0px solid #FFF;
  border-radius: 4px;
  transition: border-color 250ms ease;
  z-index: 10001;
  ${props => props.open && css`
    border: 1px solid #DDE1E7;
    box-shadow: 0 2px 8px 0 #DDE1E7;
  `}
`


export const OptionsContainer = styled.ul.attrs(props => ({
  height: getHeight(props)
}))`
  display: ${({ open }) => (!open ? 'none' : 'block')};
  flex-direction: column;
  flex-wrap: nowrap;
  width: 100%;
  max-height: ${props => props.height};
  min-height: auto;
  overflow: hidden;
  overflow-y: auto;
  list-style: none;
  padding: 0;
`

export const ErrorMessage = styled.span``

export default {
  CustomSelectContainer,
  InputContainer,
  OptionsContainer,
  OptionsWrapper
}
