/* eslint-disable react/prop-types */
import React, { useCallback } from 'react'
import PropTypes from 'prop-types'
import moment from 'moment'
import DatePicker from '../DatePicker'
import { DateRangeContainer, DateRangeWrapper } from './DateRange.styles'

function DateRange(props) {
  const { onChange, section, value } = props

  const handleStartChange = useCallback(
    (val, event) => {
      handleChange([val ? moment(val).format('YYYY-MM-DD') : null, value?.[1]], event)
    },
    [value]
  )

  const handleEndChange = useCallback(
    (val, event) => {
      handleChange([value?.[0], val ? moment(val).format('YYYY-MM-DD') : null], event)
    },
    [value]
  )

  const handleChange = useCallback((val, event) => {
    event.persist()
    event.preventDefault()
    event.stopPropagation()

    onChange({
      ...section,
      value: val
    })
  }, [])

  return (
    <DateRangeContainer>
      <div className="title">{section.title}</div>
      <DateRangeWrapper>
        <DatePicker
          value={value?.[0]}
          placeholder="Start Date"
          onChange={handleStartChange}
          isClearable
          selectsStart
          closeOnScroll
        />
        <DatePicker
          value={value?.[1]}
          placeholder="End Date"
          onChange={handleEndChange}
          selectsEnd
          isClearable
          closeOnScroll
        />
      </DateRangeWrapper>
    </DateRangeContainer>
  )
}

DateRange.defaultProps = {}

DateRange.propTypes = {
  value: PropTypes.arrayOf(PropTypes.string),
  section: PropTypes.object.isRequired,
  onChange: PropTypes.func.isRequired
}

export default DateRange
