import React from 'react'
import { Tooltip } from '..'
import PropTypes from 'prop-types'
import { DragonPosition, DragoWrapper, IconWrapper } from './DragosaurWithUmbrella.styles'
import Error from './Error'

function DragosaurWithUmbrella({ svgSize, paddingTop, message, tooltip, showTooltip }) {
  return (
    <DragoWrapper
      data-test-id="drago-with-umbrella"
      showPointer={showTooltip ? 'pointer' : 'default'}
    >
      <DragonPosition paddingTop={`${paddingTop}px`}>
        <IconWrapper svgSize={`${svgSize}px`}>
          <Error />
        </IconWrapper>
        {showTooltip ? (
          <Tooltip body={tooltip} placement="bottom" readOnly>
            <span data-test-id="empty-message" style={{ borderBottom: '1px dotted #7B828A' }}>
              {message}
            </span>
          </Tooltip>
        ) : (
          <span data-test-id="empty-message" style={{ borderBottom: '1px dotted #7B828A' }}>
            {message}
          </span>
        )}
      </DragonPosition>
    </DragoWrapper>
  )
}

export default DragosaurWithUmbrella

DragosaurWithUmbrella.defaultProps = {
  svgSize: 150,
  paddingTop: 60,
  message: 'It looks like something went wrong...',
  tooltip:
    'Sorry about that! Our team has been notified of this issue. In the meantime, please try refreshing the page or coming back later.',
  showTooltip: true
}

DragosaurWithUmbrella.prototype = {
  svgSize: PropTypes.number,
  paddingTop: PropTypes.number,
  message: PropTypes.string,
  tooltip: PropTypes.string,
  showTooltip: PropTypes.bool
}
