// Libraries
import React from 'react'
import PropTypes from 'prop-types'

import GlobalStyle from '../GlobalStyle'
import { Button } from '../Button'
import { Body } from '../Typography'
import { Icon } from '../Icon'

// Styles
import {
  EmptyBlockContainer,
  EmptyBlockContent
} from './EmptyBlock.styles'

export default function EmptyBlock({
  iconName, body, buttonTitle, onClickButton, className, style
}) {
  return (
    <>
      <EmptyBlockContainer style={style} className={className}>
        <EmptyBlockContent>
          { iconName && <Icon name={iconName} size="xlg" /> }
          { body && <Body fontWeight="normal" dangerouslySetInnerHTML={{ __html: body }} /> }
          {
            buttonTitle && (
              <Button
                theme="ghost"
                dangerouslySetInnerHTML={{ __html: buttonTitle }}
                onClick={onClickButton}
              />
            )
          }
        </EmptyBlockContent>
      </EmptyBlockContainer>
      <GlobalStyle />
    </>
  )
}

EmptyBlock.defaultProps = {
  style: null,
  body: undefined,
  buttonTitle: undefined,
  iconName: undefined,
  className: undefined,
  onClickButton: () => {}
}

EmptyBlock.propTypes = {
  style: PropTypes.shape({}),
  body: PropTypes.string,
  buttonTitle: PropTypes.string,
  iconName: PropTypes.string,
  className: PropTypes.string,
  onClickButton: PropTypes.func,
}
