import React from 'react'
import { shallow, mount } from 'enzyme'

import EventsLog from './index'
import { emptyEventsLogData, irpEventsLogData } from './mock'
import { getColumns } from './utils'
import { BrowserRouter } from 'react-router-dom'

const columns = getColumns('date desc', false, true, true)

const mountEventsLog = props =>
  mount(
    <BrowserRouter>
      <EventsLog
        loading={false}
        columns={columns}
        totalCount={props.data.total}
        showIndividualColumn={false}
        showDataSourceColumn={false}
        shouldDisableExport={false}
        exportData={<div>Export data</div>}
        excludeSortColumn={['action', 'data_source', 'event']}
        onSortedChange={() => {}}
        enableAdditionalDetails={false}
        onChangeTable={() => {}}
        {...props}
      />
    </BrowserRouter>
  )

test('Test render an events log component', () => {
  const wrapper = shallow(
    <EventsLog
      data={emptyEventsLogData}
      totalCount={emptyEventsLogData.total}
      onChangeTable={() => {}}
    />
  )
  expect(wrapper).toMatchSnapshot()
})

test('Test render a drago for empty table ', () => {
  const wrapper = mountEventsLog({
    data: emptyEventsLogData
  })
  const messageElement = wrapper.find('[data-test-id="empty-message"]')
  expect(messageElement.text()).toEqual('There are no insight available')
})

test('Test render events log table', () => {
  const wrapper = mountEventsLog({
    data: irpEventsLogData
  })
  const tableElement = wrapper.find('[data-test-id="events-log-table-wrapper"]').at(0)
  expect(tableElement.length).toEqual(1)
})

test('Test render events log search bar', () => {
  const wrapper = mountEventsLog({
    data: irpEventsLogData
  })
  const tableElement = wrapper.find('[data-test-id="searchbar"]').at(0)
  expect(tableElement.length).toEqual(1)
})

test('Test events log search bar not found when disableSearch prop is true', () => {
  const wrapper = mountEventsLog({
    data: irpEventsLogData,
    disableSearch: true
  })
  const searchElement = wrapper.find('[data-test-id="searchbar"]').at(0)
  expect(searchElement.length).toEqual(0)
})

test('Test events log additional filters are displayed', () => {
  const wrapper = mountEventsLog({
    data: irpEventsLogData
  })
  const moreFiltersElement = wrapper.find('[data-test-id="more-filters"]').at(0)
  expect(moreFiltersElement.length).toEqual(1)
})

test('Test events log additional filters are not displayed when prop is false', () => {
  const wrapper = mountEventsLog({
    data: irpEventsLogData,
    disableFilter: true
  })
  const moreFiltersElement = wrapper.find('[data-test-id="more-filters"]').at(0)
  expect(moreFiltersElement.length).toEqual(0)
})

test('Test events log export option is displayed', () => {
  const wrapper = mountEventsLog({
    data: irpEventsLogData
  })
  const moreFiltersElement = wrapper.find('[data-test-id="export-data"]').at(0)
  expect(moreFiltersElement.length).toEqual(1)
})

test('Test events log export option is not displayed', () => {
  const wrapper = mountEventsLog({
    data: irpEventsLogData,
    shouldDisableExport: true,
    disableFilter: true
  })
  const moreFiltersElement = wrapper.find('[data-test-id="export-data"]').at(0)
  expect(moreFiltersElement.length).toEqual(0)
})
