import styled from 'styled-components'

export const EventLogsWrapper = styled.div`
  width: 100%;
  margin: 24px 0px 0px;
`

export const EventLogTableContainer = styled.div`
  width: 100%;
  display: flex;
  flex-direction: row;
  padding-top: 16px;
  [class*='Tablestyles__TablePagination'] {
    position: ${props => (props.additionalLog ? 'absolute' : 'unset')};
    width: ${props => (props.additionalLog ? '133%' : '100%')};
    ${props => (props.additionalLog ? 'bottom: -57px' : '')};
    border-top: 1px solid #dde1e7;
    background: #ffffff;
    z-index: 1;
    input {
      cursor: pointer;
    }
  }
  .slide-in {
    animation: slide-in 0.3s forwards;
    -webkit-animation: slide-in 0.3s forwards;
  }
  .slide-out {
    animation: slide-out 0.5s forwards;
    -webkit-animation: slide-out 0.5s forwards;
  }

  @keyframes slide-in {
    0% {
      transform: translatex(100%);
    }
    100% {
      transform: translatex(0%);
    }
  }

  @-webkit-keyframes slide-in {
    0% {
      -webkit-transform: translatex(100%);
    }
    100% {
      -webkit-transform: translatex(0%);
    }
  }

  @keyframes slide-out {
    0% {
      transform: translatex(0%);
    }
    100% {
      transform: translatex(100%);
    }
  }

  @-webkit-keyframes slide-out {
    0% {
      -webkit-transform: translatex(0%);
    }
    100% {
      -webkit-transform: translatex(100%);
    }
  }
`

const tableWidth = columns => `calc(100% / ${columns}) !important`
export const TableWrapper = styled.div`
  position: relative;
  width: ${props => (props.additionalLog ? '75%' : '100%')};
  [class*='Tablestyles__TableContainer'] {
    padding: 0;
    border-top: 1px solid #eef0f3;
    border-bottom: 1px solid #eef0f3;
    /* Stick table header at top */
    > [class^='Tablestyles__TableHeader'] {
      width: 100%;
      position: relative;
      top: 0;
      z-index: 998;
      background: white;
      overflow: visible;
      padding-right: 0;
      [class^='Tablestyles__TableRow'] {
        padding: 0;
        height: 56px;
        [class^='Tablestyles__TableData'] {
          padding-top: 12px;
          padding-bottom: 12px;
          background: white;
          span {
            color: #7b828a;
            font-size: 12px;
            font-family: Neue Haas Unica Pro;
            font-weight: bold;
          }
        }
      }
    }
    > [class^='Tablestyles__TableBody'] {
      [class*='Tablestyles__TableRow'] {
        cursor: ${props => (props.enableAdditionalDetails ? 'pointer' : 'default')};
      }
      [class^='Tablestyles__TableData'][data-column-key='checkbox'] input {
        margin-left: 6px;
      }
    }
  }
  [class^='Tablestyles__TableRow'] {
    padding: 0;
    height: 40px;
    margin-top: 0;
  }
  [class*='Tablestyles__TableData'] {
    /* flex: 0 0 calc(100% / 7); */
    /* width: calc(100% / 7); */
    min-width: ${props => tableWidth(props.columns)};
    width: ${props => tableWidth(props.columns)};
    max-width: ${props => tableWidth(props.columns)};
    //min-width: calc(100% / 5) !important;

    &:last-child {
      padding-right: 0;
    }
    > .span {
      display: block;
      width: 100%;
    }
    .span-head {
      font-style: normal;
      font-weight: bold;
      font-size: 12px;
      line-height: 20px;
      color: #7b828a;
    }

    a {
      color: #0c7d84;
      text-decoration: none;
      &:hover {
        color: #039ba1;
        outline: 0;
      }
    }
  }
  .table-row {
    cursor: ${props => (props.enableAdditionalDetails ? 'pointer' : 'default')};
  }
`

export const Toolbar = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  [class^='rc-slider'] {
    width: 328px;
    cursor: pointer;
  }
`

export const FilterContainer = styled.div`
  display: flex;
  justify-content: flex-start;
  align-items: center;
  margin-top: 24px;
  margin-bottom: 4px;
  gap: 16px;

  [class^='rbt-input-main'] {
    min-width: 320px;
  }
  [class^='inputstyles__InputContainer'] {
    .icons-left {
      left: 16px;
      svg {
        stroke: #7e8691;
      }
    }
    .eZGrNi {
      background-color: white;
    }
  }
  [class^='sc-ibuqYl dyCFxG'] {
    width: 400px;
  }
  [class^='checkbox-items'] {
    input:hover {
      cursor: pointer;
    }
    label:hover {
      cursor: pointer;
    }
  }
  [class^='title'] {
    cursor: default;
  }
  [class^='rbt'][tabindex='-1'] {
    width: 125%;
  }
  .rc-slider {
    width: 328px;
    cursor: pointer;
  }
`

export const SearchBar = styled('div')`
  position: relative;
`

export const ClearSearchIcon = styled('span')`
  position: absolute;
  top: 50%;
  right: 16px;
  transform: translateY(-50%);
  z-index: 1;
  cursor: pointer;
`

export const DragoWrapper = styled.div`
  height: 350px;
`

export const ClearFilters = styled.div`
  font-size: 14px;
  line-height: 24px;
  text-decoration: underline;
  color: #34383c;
  cursor: pointer;
`

export const EventLogAdditional = styled.div`
  width: 25%;
  display: ${props => (props.additionalLog ? 'flex' : 'none')};
  flex-direction: column;
  border-left: 1px solid #dde1e7;
  border-top: 1px solid #dde1e7;
  padding: 24px;
  padding-bottom: 12px;
  overflow: scroll;
  height: calc(100vh - 300px);
  min-height: calc(100vh - 300px);
  svg {
    cursor: pointer;
  }
`
export const EventLogSeverity = styled.div`
  color: #565d66;
  font-size: 14px;
  font-weight: normal;
  padding-top: 24px;
  line-height: 24px;
`
export const EventLogSeverityData = styled.div`
  color: #565d66;
  font-weight: bold;
  font-size: 14px;
  line-height: 24px;
`
export const EventLogUrlWrapper = styled.div`
  padding-top: 8px;
  padding-left: 16px;
  padding-right: 16px;
  overflow: hidden;
  width: 280px;
  height: 128px;
  background-color: #f5f6f8;
  border: 1px solid #c9cfd6;
  box-sizing: border-box;
  border-radius: 4px;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  word-break: break-all;
  box-shadow: 0 0 2px grey;
  .couponcode:hover .coupontooltip {
    display: block;
    visibility: visible;
    opacity: 1;
  }

  .coupontooltip {
    visibility: hidden;
    opacity: 0;
    transition: opacity 2s;
    background: #e9e5e2;
    font-size: 12px;
    font-weight: normal;
    margin-left: 45px;
    padding-left: 10px;
    padding-right: 10px;
    padding-top: 3px;
    padding-bottom: 3px;
    position: absolute;
    z-index: 1000;
    width: 280px;
    height: auto;
    border-radius: 4px;
    box-shadow: gray;
  }

  .couponcode {
    font-weight: bold;
  }
`
export const EventLogCopyWrapper = styled.div`
  display: flex;
  flex-direction: row;
  padding-bottom: 16px;
  p {
    padding-left: 8px;
    font-family: Neue Haas Unica Pro;
    font-style: normal;
    font-weight: normal;
    font-size: 14px;
    color: #0c7d84;
  }
  svg:hover {
    stroke: #039ba1;
  }
`
export const EventLogDevice = styled.div`
  color: #565d66;
  font-size: 14px;
  font-weight: normal;
  padding-top: 24px;
  line-height: 24px;
`
export const EventLogDeviceData = styled.div`
  color: #565d66;
  font-weight: bold;
  font-size: 14px;
  line-height: 24px;
`
export const EventLogFound = styled.div`
  color: #0c7d84;
  cursor: pointer;
  padding-top: 15px;
`
export const EventLogBodyWrapper = styled.div`
  display: flex;
  flex-direction: column;
  height: 100%;
  justify-content: space-between;
`
export const EventLogHeader = styled.div`
  color: #34383c;
  font-size: 18px;
  line-height: 24px;
  font-weight: bold;
`

export const AdditionalLogNoData = styled.p`
  color: #c9cfd6;
  font-size: 14px;
  padding-top: 10px;
`
export const StoryContainer = styled.div`
  display: block;
  min-width: 100%;
  height: 100%;
  overflow: hidden;
  padding: 0 20px;
  box-sizing: border-box;
  .dropdown-container {
    transform: translateY(calc(-100% + 44px));
  }
`

export const ExportWrapper = styled.div`
  display: flex;
  gap: 5px;
  align-items: center;
`
