import React from 'react'
import { NavLink } from 'react-router-dom'

import { humanize } from 'utils/strings'
import { timeWithTimeZone } from 'utils/dates'
import TextOverflow from '../TextOverflow'
import SkeletonLoader from '../SkeletonLoader'

export const FILTER_TYPE = {
  MULTI_SELECT: 'MULTI_SELECT',
  DATE_RANGE: 'DATE_RANGE',
  SLIDER: 'slider'
}

export const getStringDataRender = (loading, value) => {
  if (loading)
    return (
      <div style={{ width: '90%' }}>
        <SkeletonLoader />
      </div>
    )
  return (
    <div style={{ paddingLeft: '5px' }}>
      <TextOverflow name={humanize(value || '')} color={'#565d66'} />
    </div>
  )
}

export const getSortProperty = (sort, key) => {
  if (!sort.includes(key)) return {}

  return {
    asc: !sort.includes('desc')
  }
}

const getDataSourceEventColumn = (sort, showDatasourceEventLog, loading) => {
  return showDatasourceEventLog
    ? [
        {
          key: 'data_source',
          header: humanize('data_source').toUpperCase(),
          render: value => getStringDataRender(loading, value),
          ...getSortProperty(sort, 'data_source')
        }
      ]
    : []
}

const getIndividualColumn = (sort, showIndividualColumn, loading) => {
  return showIndividualColumn
    ? [
        {
          key: 'individual',
          header: 'individual'.toUpperCase(),
          render: (value, row) =>
            loading ? (
              <div style={{ width: '90%' }}>
                <SkeletonLoader />
              </div>
            ) : (
              <NavLink
                title={value}
                style={{
                  width: '300px',
                  overflow: 'hidden',
                  textOverflow: 'ellipsis',
                  whiteSpace: 'nowrap'
                }}
                target="_blank"
                to={{
                  pathname: `/engagement/vision2/${row?.es_person_id}/profile`
                }}
              >
                {humanize(value || '')}
              </NavLink>
            ),
          ...getSortProperty(sort, 'individual')
        }
      ]
    : []
}

export const getColumns = (sort, loading, showDataSourceCol, showIndividualColumn) => {
  return [
    ...getIndividualColumn(sort, showIndividualColumn, loading),
    {
      key: 'event',
      header: 'event'.toUpperCase(),
      render: value =>
        loading ? (
          <div style={{ width: '90%' }}>
            <SkeletonLoader />
          </div>
        ) : (
          <TextOverflow name={humanize(value)} color={'#565d66'} />
        ),
      ...getSortProperty(sort, 'action')
    },
    {
      key: 'date',
      header: 'DATE',
      render: date =>
        loading ? (
          <div style={{ width: '90%' }}>
            <SkeletonLoader />
          </div>
        ) : (
          <span style={{ padding: '0 4px' }} title={date}>
            {timeWithTimeZone({
              date: date
            })}
          </span>
        ),
      ...getSortProperty(sort, 'date')
    },
    ...getDataSourceEventColumn(sort, showDataSourceCol, loading),
    {
      key: 'action',
      header: 'action'.toUpperCase(),
      render: value => getStringDataRender(loading, value),
      ...getSortProperty(sort, 'action')
    }
  ]
}

export const getDummyEventsLog = () => {
  let insightEventLogDummyData = []

  for (let i = 0; i < 15; i++) {
    insightEventLogDummyData.push({
      action: 'Actual Phishing',
      action_event: 'real-world-phishing-clicked',
      date: '2021-10-17T12:51:00',
      full_name: 'Garner Mumford',
      title: 'Actual phishing email clicked (phish)'
    })
  }
  return insightEventLogDummyData
}

export const InsightDataFilterOptions = params => [
  {
    type: FILTER_TYPE.DATE_RANGE,
    title: 'date'.toUpperCase(),
    key: 'date'
  },
  ...(params?.actions?.length > 0
    ? [
        {
          type: FILTER_TYPE.MULTI_SELECT,
          title: 'action'.toUpperCase(),
          key: 'action',
          items:
            params?.actions?.map(decision => ({
              label: humanize(decision),
              value: decision.toLowerCase().replace(/\s/g, '_'),
              original: decision
            })) || [],
          ...(params?.actions &&
            params?.actions?.length > 4 && {
              showMore: 'Show all actions',
              showLess: 'Show fewer actions'
            })
        }
      ]
    : []),
  ...(params?.data_sources?.length > 0
    ? [
        {
          type: FILTER_TYPE.MULTI_SELECT,
          title: 'Data Source'.toUpperCase(),
          key: 'data_source',
          items:
            params?.data_sources?.map(decision => ({
              label: humanize(decision),
              value: humanize(decision),
              original: decision
            })) || [],
          ...(params?.data_sources &&
            params?.data_sources?.length > 4 && {
              showMore: 'Show all Data Source',
              showLess: 'Show fewer Data Source'
            })
        }
      ]
    : [])
]

export const normalizeActionName = action => action.toLowerCase().replace(/\s/g, '_')

export const similarEventFoundLink = (data, action) => {
  const numberOfEvent = data?.[`${action}_count`] || 0

  let linkText = 'similar events found'
  if (numberOfEvent === 0) {
    return ''
  } else if (numberOfEvent === 1) {
    linkText = 'similar event found'
  }
  return `${numberOfEvent} ${linkText}`
}
