// Libraries
import React from 'react'
import styled from 'styled-components'
import PropTypes from 'prop-types'
import { pie, arc, lineRadial } from 'd3-shape'

// Theme
import theme from 'theme'

// Utils
import { defineSections, gaugeScale } from '../../../utils/charts'

// Styles
const GaugeContainer = styled.svg`
  font-family: ${theme.text.fontFamily.default};
`

const Gauge = (props) => {
  const { score, margin, containerWidth } = props
  const svgWidth = containerWidth
  const svgHeight = svgWidth / 1.9

  // Dimensions
  const w = svgWidth - margin.left - margin.right
  const outerR = w / 2
  const innerR = w / 2.3

  // D3 Math
  const d3Pie = pie()
    .startAngle(-Math.PI / 2)
    .endAngle(Math.PI / 2)
    .padAngle(0.01)
    .sort(null)
  const d3Arc = arc()
    .innerRadius(innerR)
    .outerRadius(outerR)
  const d3LineRadial = lineRadial()

  // Data
  const { gaugeSections, scoreQuintant } = defineSections(score)
  const arcSections = d3Pie(gaugeSections)

  return (
    <GaugeContainer width={svgWidth} height={svgHeight}>
      <g transform={`translate(${margin.left}, ${margin.top})`} className="gauge">
        {arcSections.map((section, i) => {
          return (
            <g transform={`translate(${outerR}, ${outerR})`} key={`score-g-${section.endAngle}`}>
              <path
                fill={i > scoreQuintant ? '#EAECF0' : gaugeScale(score)}
                d={d3Arc({
                  innerRadius: innerR,
                  outerRadius: outerR,
                  startAngle: section.startAngle,
                  endAngle: section.endAngle,
                  padAngle: section.padAngle
                })}
              />
            </g>
          )
        })}
        <g transform={`translate(${outerR}, ${outerR})`}>
          <path
            d={d3LineRadial([
              [arcSections[scoreQuintant].endAngle, innerR - 4],
              [arcSections[scoreQuintant].endAngle, outerR + 4]
            ])}
            stroke="#393B3D"
            strokeWidth={3}
            strokeLinecap="round"
          />
        </g>
        <text
          x={w / 2}
          y={w / 2}
          fontSize={`${w / 3}px`}
          textAnchor="middle"
          fill={gaugeScale(score)}
          fontWeight="bold"
        >
          {score}
        </text>
      </g>
    </GaugeContainer>
  )
}

export default Gauge

Gauge.propTypes = {
  containerWidth: PropTypes.number,
  score: PropTypes.number,
  margin: PropTypes.shape({
    top: PropTypes.number,
    bottom: PropTypes.number,
    left: PropTypes.number,
    right: PropTypes.number
  })
}

Gauge.defaultProps = {
  containerWidth: 500,
  score: 0,
  margin: {
    top: 10,
    bottom: 10,
    left: 10,
    right: 10
  }
}

