/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useState } from 'react'

import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs, text, boolean, number, object } from '@storybook/addon-knobs'
import {
  simpleGraphData,
  sameDataGraphData,
  lowToHighGraphData,
  highToLowGraphData,
  missingMonthsGraphData,
  nullValuesGraphData
} from './mock'
// Themes
import theme from 'theme'

// Components
import HRSGraph from './index'

// Mocked Data

const graphData = {
  Action_Score: [
    {
      date: '2021-06-01',
      previous_score: null,
      score: 57.98,
      variation: null
    },
    {
      date: '2021-07-01',
      previous_score: 57.98,
      score: 57.68,
      variation: -0.3
    },
    {
      date: '2021-08-01',
      previous_score: 57.68,
      score: 57.38,
      variation: -0.3
    },
    {
      date: '2021-09-01',
      previous_score: 57.38,
      score: 57.08,
      variation: -0.3
    },
    {
      date: '2021-10-01',
      previous_score: 57.08,
      score: 56.79,
      variation: -0.29
    },
    {
      date: '2021-11-01',
      previous_score: 56.79,
      score: 56.49,
      variation: -0.3
    },
    {
      date: '2021-12-01',
      previous_score: 56.49,
      score: 56.19,
      variation: -0.3
    },
    {
      date: '2022-01-01',
      previous_score: 56.19,
      score: 55.89,
      variation: -0.3
    },
    {
      date: '2022-02-01',
      previous_score: 55.89,
      score: 72.74,
      variation: 16.85
    },
    {
      date: '2022-03-01',
      previous_score: 72.74,
      score: 72.44,
      variation: -0.3
    },
    {
      date: '2022-04-01',
      previous_score: 72.44,
      score: 72.14,
      variation: -0.3
    },
    {
      date: '2022-05-01',
      previous_score: 72.14,
      score: 71.84,
      variation: -0.3
    },
    {
      date: '2022-06-01',
      previous_score: 71.84,
      score: 88.69,
      variation: 16.85
    }
  ],
  Simulated_Phishing: [
    {
      date: '2021-06-01',
      previous_score: null,
      score: 60,
      variation: null
    },
    {
      date: '2021-07-01',
      previous_score: 60,
      score: 60,
      variation: 0
    },
    {
      date: '2021-08-01',
      previous_score: 60,
      score: 60,
      variation: 0
    },
    {
      date: '2021-09-01',
      previous_score: 60,
      score: 60,
      variation: 0
    },
    {
      date: '2021-10-01',
      previous_score: 60,
      score: 60,
      variation: 0
    },
    {
      date: '2021-11-01',
      previous_score: 60,
      score: 60,
      variation: 0
    },
    {
      date: '2021-12-01',
      previous_score: 60,
      score: 60,
      variation: 0
    },
    {
      date: '2022-01-01',
      previous_score: 60,
      score: 60,
      variation: 0
    },
    {
      date: '2022-02-01',
      previous_score: 60,
      score: 80,
      variation: 20
    },
    {
      date: '2022-03-01',
      previous_score: 80,
      score: 80,
      variation: 0
    },
    {
      date: '2022-04-01',
      previous_score: 80,
      score: 80,
      variation: 0
    },
    {
      date: '2022-05-01',
      previous_score: 80,
      score: 80,
      variation: 0
    },
    {
      date: '2022-06-01',
      previous_score: 80,
      score: 100,
      variation: 20
    }
  ],
  Physical_Security: [
    {
      date: '2021-06-01',
      previous_score: null,
      score: 22.22,
      variation: null
    },
    {
      date: '2021-07-01',
      previous_score: 22.22,
      score: 16.67,
      variation: -5.55
    },
    {
      date: '2021-08-01',
      previous_score: 16.67,
      score: 11.11,
      variation: -5.56
    },
    {
      date: '2021-09-01',
      previous_score: 11.11,
      score: 5.56,
      variation: -5.55
    },
    {
      date: '2021-10-01',
      previous_score: 5.56,
      score: 0,
      variation: -5.56
    },
    {
      date: '2021-11-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2021-12-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-01-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-02-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-03-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-04-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-05-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-06-01',
      previous_score: 0,
      score: 0,
      variation: 0
    }
  ],
  Secure_Browsing: [
    {
      date: '2021-06-01',
      previous_score: null,
      score: 0,
      variation: null
    },
    {
      date: '2021-07-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2021-08-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2021-09-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2021-10-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2021-11-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2021-12-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-01-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-02-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-03-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-04-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-05-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-06-01',
      previous_score: 0,
      score: 0,
      variation: 0
    }
  ],
  Sensitive_Data_Handling: [
    {
      date: '2021-06-01',
      previous_score: null,
      score: 91.67,
      variation: null
    },
    {
      date: '2021-07-01',
      previous_score: 91.67,
      score: 87.5,
      variation: -4.17
    },
    {
      date: '2021-08-01',
      previous_score: 87.5,
      score: 83.33,
      variation: -4.17
    },
    {
      date: '2021-09-01',
      previous_score: 83.33,
      score: 79.17,
      variation: -4.16
    },
    {
      date: '2021-10-01',
      previous_score: 79.17,
      score: 75,
      variation: -4.17
    },
    {
      date: '2021-11-01',
      previous_score: 75,
      score: 70.83,
      variation: -4.17
    },
    {
      date: '2021-12-01',
      previous_score: 70.83,
      score: 66.67,
      variation: -4.16
    },
    {
      date: '2022-01-01',
      previous_score: 66.67,
      score: 62.5,
      variation: -4.17
    },
    {
      date: '2022-02-01',
      previous_score: 62.5,
      score: 58.33,
      variation: -4.17
    },
    {
      date: '2022-03-01',
      previous_score: 58.33,
      score: 54.17,
      variation: -4.16
    },
    {
      date: '2022-04-01',
      previous_score: 54.17,
      score: 50,
      variation: -4.17
    },
    {
      date: '2022-05-01',
      previous_score: 50,
      score: 45.83,
      variation: -4.17
    },
    {
      date: '2022-06-01',
      previous_score: 45.83,
      score: 41.67,
      variation: -4.16
    }
  ],
  Unauthorized_Software: [
    {
      date: '2021-06-01',
      previous_score: null,
      score: 37.5,
      variation: null
    },
    {
      date: '2021-07-01',
      previous_score: 37.5,
      score: 33.33,
      variation: -4.17
    },
    {
      date: '2021-08-01',
      previous_score: 33.33,
      score: 29.17,
      variation: -4.16
    },
    {
      date: '2021-09-01',
      previous_score: 29.17,
      score: 25,
      variation: -4.17
    },
    {
      date: '2021-10-01',
      previous_score: 25,
      score: 20.83,
      variation: -4.17
    },
    {
      date: '2021-11-01',
      previous_score: 20.83,
      score: 16.67,
      variation: -4.16
    },
    {
      date: '2021-12-01',
      previous_score: 16.67,
      score: 12.5,
      variation: -4.17
    },
    {
      date: '2022-01-01',
      previous_score: 12.5,
      score: 8.33,
      variation: -4.17
    },
    {
      date: '2022-02-01',
      previous_score: 8.33,
      score: 4.17,
      variation: -4.16
    },
    {
      date: '2022-03-01',
      previous_score: 4.17,
      score: 0,
      variation: -4.17
    },
    {
      date: '2022-04-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-05-01',
      previous_score: 0,
      score: 0,
      variation: 0
    },
    {
      date: '2022-06-01',
      previous_score: 0,
      score: 0,
      variation: 0
    }
  ]
}

const handleOnMouseEnter = data => {
  alert(`This is a dummy tooltip for : ${data.behaviourName}`)
}

// let lineFocus = 'Action_Score'
// const changeLineFocus = key => (lineFocus = key)

addDecorator(withA11y)
addDecorator(withKnobs)

storiesOf('Charts / HRS Graph', module)
  .add('No data', () => {
    const [lineFocus, setLineFocus] = useState('Action_Score')
    const handleFocusChange = key => {
      setLineFocus(key)
    }
    return (
      <HRSGraph
        behaviorScores={{}}
        campaignScores={[]}
        onMouseEnter={handleOnMouseEnter}
        graphTitle={null}
        yAxisLabel={text('Y Axis Label', 'Grade')}
        xAxisLabel={text('X Axis Label', 'Action')}
        keyToBeDashed={lineFocus}
        sortAlphabetical={boolean('Sort Alphabetical', true)}
        showHeading={boolean('Show Heading', false)}
        heading={text('Graph heading', 'Historical Trend')}
        showTabs={boolean('Show Tabs', false)}
        changeGraphTabsPosition={boolean('Change Tabs position', true)}
        minMaxValue={{
          min: 0.0,
          max: 100.0
        }}
        yAxisDecimal={boolean('Y Axis Decimal', true)}
        showGradeLabel={boolean('Show Grade Label', true)}
        changeLineFocus={handleFocusChange}
        lineFOcus={lineFocus}
        performanceFlag={boolean('Clickable Lines / Performance Flag', true)}
        showLegend={boolean('Show Legend', true)}
        tabsToPosition={number('Tabs top position', -10)}
        containerStyle={object('Container styles', {
          marginTop: '0px'
        })}
        onMouseEnter={handleOnMouseEnter}
      />
    )
  })
  .add('Low to high score', () => {
    const [lineFocus, setLineFocus] = useState('Action_Score')
    const handleFocusChange = key => {
      setLineFocus(key)
    }
    return (
      <HRSGraph
        behaviorScores={lowToHighGraphData}
        campaignScores={[]}
        onMouseEnter={handleOnMouseEnter}
        graphTitle={null}
        yAxisLabel={text('Y Axis Label', 'Grade')}
        xAxisLabel={text('X Axis Label', 'Action')}
        keyToBeDashed={lineFocus}
        sortAlphabetical={boolean('Sort Alphabetical', true)}
        showHeading={boolean('Show Heading', false)}
        heading={text('Graph heading', 'Historical Trend')}
        showTabs={boolean('Show Tabs', false)}
        changeGraphTabsPosition={boolean('Change Tabs position', true)}
        minMaxValue={{
          min: 0.0,
          max: 100.0
        }}
        yAxisDecimal={boolean('Y Axis Decimal', true)}
        showGradeLabel={boolean('Show Grade Label', true)}
        changeLineFocus={handleFocusChange}
        lineFOcus={lineFocus}
        performanceFlag={boolean('Clickable Lines / Performance Flag', true)}
        showLegend={boolean('Show Legend', true)}
        tabsToPosition={number('Tabs top position', -10)}
        containerStyle={object('Container styles', {
          marginTop: '0px'
        })}
      />
    )
  })
  .add('High to low score', () => {
    const [lineFocus, setLineFocus] = useState('Action_Score')
    const handleFocusChange = key => {
      setLineFocus(key)
    }
    return (
      <HRSGraph
        behaviorScores={highToLowGraphData}
        campaignScores={[]}
        onMouseEnter={handleOnMouseEnter}
        graphTitle={null}
        yAxisLabel={text('Y Axis Label', 'Grade')}
        xAxisLabel={text('X Axis Label', 'Action')}
        keyToBeDashed={lineFocus}
        sortAlphabetical={boolean('Sort Alphabetical', true)}
        showHeading={boolean('Show Heading', false)}
        heading={text('Graph heading', 'Historical Trend')}
        showTabs={boolean('Show Tabs', false)}
        changeGraphTabsPosition={boolean('Change Tabs position', true)}
        minMaxValue={{
          min: 0.0,
          max: 100.0
        }}
        yAxisDecimal={boolean('Y Axis Decimal', true)}
        showGradeLabel={boolean('Show Grade Label', true)}
        changeLineFocus={handleFocusChange}
        lineFOcus={lineFocus}
        performanceFlag={boolean('Clickable Lines / Performance Flag', true)}
        showLegend={boolean('Show Legend', true)}
        tabsToPosition={number('Tabs top position', -10)}
        containerStyle={object('Container styles', {
          marginTop: '0px'
        })}
      />
    )
  })
  .add('Low and high mix data graph', () => {
    const [lineFocus, setLineFocus] = useState('Action_Score')
    const handleFocusChange = key => {
      setLineFocus(key)
    }
    return (
      <HRSGraph
        behaviorScores={simpleGraphData}
        campaignScores={[]}
        onMouseEnter={handleOnMouseEnter}
        graphTitle={null}
        yAxisLabel={text('Y Axis Label', 'Grade')}
        xAxisLabel={text('X Axis Label', 'Action')}
        keyToBeDashed={lineFocus}
        sortAlphabetical={boolean('Sort Alphabetical', true)}
        showHeading={boolean('Show Heading', false)}
        heading={text('Graph heading', 'Historical Trend')}
        showTabs={boolean('Show Tabs', false)}
        changeGraphTabsPosition={boolean('Change Tabs position', true)}
        minMaxValue={{
          min: 0.0,
          max: 100.0
        }}
        yAxisDecimal={boolean('Y Axis Decimal', true)}
        showGradeLabel={boolean('Show Grade Label', true)}
        changeLineFocus={handleFocusChange}
        lineFOcus={lineFocus}
        performanceFlag={boolean('Clickable Lines / Performance Flag', true)}
        showLegend={boolean('Show Legend', true)}
        tabsToPosition={number('Tabs top position', -10)}
        containerStyle={object('Container styles', {
          marginTop: '0px'
        })}
      />
    )
  })
  .add('Same data multiple lines', () => {
    const [lineFocus, setLineFocus] = useState('Action_Score')
    const handleFocusChange = key => {
      setLineFocus(key)
    }
    return (
      <HRSGraph
        behaviorScores={sameDataGraphData}
        campaignScores={[]}
        onMouseEnter={handleOnMouseEnter}
        graphTitle={null}
        yAxisLabel={text('Y Axis Label', 'Grade')}
        xAxisLabel={text('X Axis Label', 'Action')}
        keyToBeDashed={lineFocus}
        sortAlphabetical={boolean('Sort Alphabetical', true)}
        showHeading={boolean('Show Heading', false)}
        heading={text('Graph heading', 'Historical Trend')}
        showTabs={boolean('Show Tabs', false)}
        changeGraphTabsPosition={boolean('Change Tabs position', true)}
        minMaxValue={{
          min: 0.0,
          max: 100.0
        }}
        yAxisDecimal={boolean('Y Axis Decimal', true)}
        showGradeLabel={boolean('Show Grade Label', true)}
        changeLineFocus={handleFocusChange}
        lineFOcus={lineFocus}
        performanceFlag={boolean('Clickable Lines / Performance Flag', true)}
        showLegend={boolean('Show Legend', true)}
        tabsToPosition={number('Tabs top position', -10)}
        containerStyle={object('Container styles', {
          marginTop: '0px'
        })}
      />
    )
  })
  .add('Missing months / half line data graph ', () => {
    const [lineFocus, setLineFocus] = useState('Action_Score')
    const handleFocusChange = key => {
      setLineFocus(key)
    }
    return (
      <HRSGraph
        behaviorScores={missingMonthsGraphData}
        campaignScores={[]}
        onMouseEnter={handleOnMouseEnter}
        graphTitle={null}
        yAxisLabel={text('Y Axis Label', 'Grade')}
        xAxisLabel={text('X Axis Label', 'Action')}
        keyToBeDashed={lineFocus}
        sortAlphabetical={boolean('Sort Alphabetical', true)}
        showHeading={boolean('Show Heading', false)}
        heading={text('Graph heading', 'Historical Trend')}
        showTabs={boolean('Show Tabs', false)}
        changeGraphTabsPosition={boolean('Change Tabs position', true)}
        minMaxValue={{
          min: 0.0,
          max: 100.0
        }}
        yAxisDecimal={boolean('Y Axis Decimal', true)}
        showGradeLabel={boolean('Show Grade Label', true)}
        changeLineFocus={handleFocusChange}
        lineFOcus={lineFocus}
        performanceFlag={boolean('Clickable Lines / Performance Flag', true)}
        showLegend={boolean('Show Legend', true)}
        tabsToPosition={number('Tabs top position', -10)}
        containerStyle={object('Container styles', {
          marginTop: '0px'
        })}
      />
    )
  })
  .add('Null values data graph', () => {
    const [lineFocus, setLineFocus] = useState('Action_Score')
    const handleFocusChange = key => {
      setLineFocus(key)
    }
    return (
      <HRSGraph
        behaviorScores={nullValuesGraphData}
        campaignScores={[]}
        onMouseEnter={handleOnMouseEnter}
        graphTitle={null}
        yAxisLabel={text('Y Axis Label', 'Grade')}
        xAxisLabel={text('X Axis Label', 'Action')}
        keyToBeDashed={lineFocus}
        sortAlphabetical={boolean('Sort Alphabetical', true)}
        showHeading={boolean('Show Heading', false)}
        heading={text('Graph heading', 'Historical Trend')}
        showTabs={boolean('Show Tabs', false)}
        changeGraphTabsPosition={boolean('Change Tabs position', true)}
        minMaxValue={{
          min: 0.0,
          max: 100.0
        }}
        yAxisDecimal={boolean('Y Axis Decimal', true)}
        showGradeLabel={boolean('Show Grade Label', true)}
        changeLineFocus={handleFocusChange}
        lineFOcus={lineFocus}
        performanceFlag={boolean('Clickable Lines / Performance Flag', true)}
        showLegend={boolean('Show Legend', true)}
        tabsToPosition={number('Tabs top position', -10)}
        containerStyle={object('Container styles', {
          marginTop: '0px'
        })}
      />
    )
  })
