import * as d3 from 'd3'

export const getGraphLabel = value => {
  if (0 <= value && value < 20) return 'Very Strong'
  if (20 <= value && value < 40) return 'Strong'
  if (40 <= value && value < 60) return 'Medium'
  if (60 <= value && value < 80) return 'Weak'
  if (80 <= value) return 'Very Weak'
  return 'No Data'
}

export const BEHAVIOR_COLORS = [
  '#0C7D84',
  '#668CE5',
  '#AC3ECF',
  '#86CC55',
  '#EDA039',
  '#DE4B6D',
  '#FAD250',
  '#1CB696',
  '#7E8691',
  '#DE6900',
  '#178574',
  '#CB7D20',
  '#035257',
  '#B8E5E3',
  '#AECCCE'
]

export const setLineMargin = month => {
  const initialValue = 22
  switch (month.getMonth()) {
    case 2:
    case 6:
      return initialValue + 2
    case 3:
    case 7:
      return initialValue - 1
    case 11:
    case 8:
      return initialValue - 3
    case 9:
      return initialValue - 2
    case 10:
      return initialValue - 4
    case 0:
      return initialValue - 5
    case 1:
      return initialValue - 7
    default:
      return initialValue
  }
}
const formatLabel = ({ value, showGradeLabel, yAxisDecimal, max }) => {
  if (showGradeLabel) {
    return getGraphLabel(value)
  } else if (value >= 1000) {
    return `${parseFloat(value / 1000).toFixed(1)}K`
  } else if (yAxisDecimal) {
    return value !== max ? value.toFixed(1) : `${value.toFixed(1)}+`
  } else return value
}
export const yAxisLabel = ({ yScale, showGradeLabel, yAxisDecimal, max }) => {
  if (!showGradeLabel) {
    return d3
      .axisLeft(yScale)
      .tickSize(0)
      .tickSizeOuter(0)
      .tickPadding(15)
      .ticks(6)
      .tickFormat(value => formatLabel({ value, showGradeLabel, yAxisDecimal, max }))
      .scale(yScale)
  }

  return d3
    .axisLeft(yScale)
    .tickSize(0)
    .tickSizeOuter(0)
    .tickPadding(15)
    .tickValues([10, 30, 50, 70, 90])
    .ticks(6)
    .tickFormat(value => formatLabel({ value, showGradeLabel, yAxisDecimal, max }))
    .scale(yScale)
}

export const showHorizontalLines = ({ yScale, svgWidth, showGradeLabel }) => {
  if (!showGradeLabel) {
    return d3
      .axisLeft(yScale)
      .tickSize(0)
      .tickSizeOuter(0)
      .tickSizeInner(-svgWidth)
      .ticks(4)
      .tickFormat('')
  }

  return d3
    .axisLeft(yScale)
    .tickSize(0)
    .tickSizeOuter(0)
    .tickSizeInner(-svgWidth)
    .tickValues([0, 20, 40, 60, 80, 100])
    .ticks(4)
    .tickFormat('')
}
