const { useRef, useState, useEffect } = require('react')
import { useDrawChart } from './useDrawChart'

export const useGraph = ({
  behaviorScores,
  campaignScores,
  onMouseEnter,
  prevDisabledLines = [],
  showExport,
  keyToBeDashed,
  minMaxValue,
  sortAlphabetical = false,
  isInsight,
  yAxisDecimal = false,
  changeLineFocus,
  lineFOcus,
  performanceFlag = false,
  showGradeLabel = false
}) => {
  const chartRef = useRef(null)
  const printChartRef = useRef(null)
  const [disabledLines, setDisabledLines] = useState(prevDisabledLines)
  const [hideActionsTaken, setHideActionsTaken] = useState(false)

  const [isReady, setIsReady] = useState(false)
  const [typeGraph, setTypeGraph] = useState('monthly')

  const drawChart = useDrawChart(
    chartRef,
    printChartRef,
    disabledLines,
    typeGraph,
    behaviorScores,
    campaignScores,
    hideActionsTaken,
    onMouseEnter,
    setIsReady,
    showExport,
    keyToBeDashed,
    minMaxValue,
    isInsight,
    changeLineFocus,
    lineFOcus,
    performanceFlag,
    showGradeLabel,
    sortAlphabetical,
    yAxisDecimal
  )

  useEffect(() => drawChart(false), [chartRef, typeGraph, behaviorScores, campaignScores])

  useEffect(() => {
    if (!isReady) return
    drawChart(true)
  }, [disabledLines, hideActionsTaken])

  useEffect(() => {
    window.addEventListener('resize', () => drawChart(true))
    return () => window.removeEventListener('resize', drawChart)
  }, [chartRef, disabledLines, typeGraph, behaviorScores])

  return {
    chartRef,
    printChartRef,
    disabledLines,
    setDisabledLines,
    hideActionsTaken,
    setHideActionsTaken,
    typeGraph,
    setTypeGraph,
    isReady
  }
}
