import React, { Component } from 'react'
import PropTypes from 'prop-types'

// Components
import Card from '../Card'
import Link from '../Link'

import {
  ContentContainer,
  HeaderCell,
  HeaderRow,
  TableRow,
  TableCellFirst,
  TableCell,
  HeaderLabel
} from './Heatmap.styles'

// Utils
import { camelToTitleCase, getCircleDiameter, gaugeScale } from '../../../utils/charts'

const getCircle = score => (
  <div
    style={{
      borderRadius: '50%',
      width: getCircleDiameter(score),
      height: getCircleDiameter(score),
      backgroundColor: gaugeScale(score)
    }}
  />
)

class Heatmap extends Component {
  render() {
    const {
      data, keys, header
    } = this.props

    // Dynamic Styling
    const rowSpacing = {
      flex: `1 1 ${Math.floor((1 / keys.length) * 100)}%`,
      minWidth: '7vw'
    }

    return (
      <Card header={header} headerSize="xxlg">
        <ContentContainer>
          <HeaderRow>
            {keys.map((key, i) => (
              <HeaderCell
                key={`th-${key}`}
                style={{ ...rowSpacing, textAlign: i === 0 ? 'left' : 'center' }}
              >
                <HeaderLabel>{camelToTitleCase(key)}</HeaderLabel>
              </HeaderCell>
            ))}
          </HeaderRow>
          {data.map(row => (
            <TableRow key={row.id}>
              {
                keys.map(key => ((key === 'name') ? (
                  <TableCellFirst key={`${key}-${row.id}`} style={rowSpacing}>
                    {
                      row.link ? (
                        <Link
                          to={row.link}
                          style={{ overflow: 'hidden', textOverflow: 'ellipsis' }}
                        >
                          {row.name}
                        </Link>
                      ) : (
                        row.name
                      )
                    }
                  </TableCellFirst>
                ) : (
                  <TableCell key={`${key}-${row.id}`} style={rowSpacing}>
                    {getCircle(row.scores[key])}
                  </TableCell>
                )
                ))
              }
            </TableRow>
          ))}
        </ContentContainer>
      </Card>
    )
  }
}

Heatmap.propTypes = {
  data: PropTypes.arrayOf(
    PropTypes.shape({
      id: PropTypes.any.isRequired,
      name: PropTypes.string,
      link: PropTypes.string,
      scores: PropTypes.shape({
        overall: PropTypes.number
      })
    })
  ).isRequired,
  header: PropTypes.string,
  keys: PropTypes.arrayOf(PropTypes.string)
}

Heatmap.defaultProps = {
  header: null,
  keys: ['name', 'malware', 'passwordHygiene', 'phishing', 'reporting']
}

export default Heatmap
