
// Libraries
import React from 'react'
import PropTypes from 'prop-types'

// Styling
import styled from 'styled-components'
import theme from '../../../themes/theme'

// Icons
import * as icons from './icons'


/* TODO: Add size prop, revisit the structure of the dynamic naming employed
 here-- it feels very redundant. -MH */

const Icon = (props) => {
  const { name, size } = props
  const iconSize = theme.icons.size[size]
  const TagName = icons[name]

  return TagName ? <TagName {...props} size={iconSize} /> : <span />
}

Icon.propTypes = {
  name: PropTypes.string.isRequired,
  size: PropTypes.string,
}


Icon.defaultProps = {
  size: 'default',
}
const IconContainer = styled.span`
  display: inline-flex;
  align-self: center;

  & svg,
  & img {
    height: 1em;
    width: 1em;
  }

  &.baseline svg,
  & img {
    top: 0.125em;
    position: relative;
  }
`

const ChildContainer = styled.span`
  padding-right: 5px;
  font-family: ${theme.text.fontFamily.default};
`

const TextIcon = (props) => {
  const { name, children } = props
  const TagName = icons[name]

  if (TagName) {
    return (
      <span>
        <ChildContainer>
          {children}
        </ChildContainer>
        <IconContainer className="icon baseline">
          <TagName {...props} />
        </IconContainer>
      </span>
    )
  }
  return <span />
}

TextIcon.propTypes = {
  name: PropTypes.string.isRequired,
  children: PropTypes.node.isRequired
}

export default Icon

export { Icon, TextIcon }
