/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'
import styled from 'styled-components'
import theme from 'theme'

// Components
import IconAction from './index'

const Container = styled.div`
  display: flex;
  flex-wrap: wrap;
  padding: 20px;
  margin-top: 100px;
  margin-left: 40px;
  font-family: ${theme.text.fontFamily.default};
`

const Wrapper = styled.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  margin-right: 20px;
  > .component-help-text {
    margin-top: 10px;
    font-size: 13px;
    color: #333333;
  }
`

addDecorator(withA11y)
addDecorator(withKnobs)


storiesOf('Icon Action', module)
  .addParameters({
    jest: ['Icon Action'],
  })
  .add('Icon Action with Tooltip', () => {
    return (
      <Container>
        <Wrapper>
          <IconAction name="Pencil" tooltipText="Edit campaign" onClick={() => console.log('clicked')} />
        </Wrapper>
        <Wrapper>
          <IconAction name="Copy" tooltipText="Copy campaign" renderTooltipOnHover />
        </Wrapper>
        <Wrapper>
          <IconAction name="Trash" tooltipText="Delete campaign" />
        </Wrapper>
        <Wrapper>
          <IconAction name="Cancel" tooltipText="Cancel campaign" />
        </Wrapper>
        <Wrapper>
          <IconAction name="Eye" tooltipText="View Template" tooltipPlacement="right" />
          <span className="component-help-text">tooltip placement</span>
        </Wrapper>
        <Wrapper>
          <IconAction name="Layers" tooltipText="Archive campaign" size="lg" tooltipProps={{ distance: 16 }} />
          <span className="component-help-text">size with custom tooltip props</span>
        </Wrapper>
      </Container>
    )
  })
  .add('Icon Action without Tooltip', () => {
    return (
      <Container>
        <Wrapper>
          <IconAction name="Pencil" />
        </Wrapper>
        <Wrapper>
          <IconAction name="Copy" />
        </Wrapper>
        <Wrapper>
          <IconAction name="Trash" />
        </Wrapper>
        <Wrapper>
          <IconAction name="Cancel" />
        </Wrapper>
        <Wrapper>
          <IconAction name="Layers" />
        </Wrapper>
        <Wrapper>
          <IconAction name="Eye" />
        </Wrapper>
      </Container>
    )
  })
  .add('Icon Action disabled', () => {
    return (
      <Container>
        <Wrapper>
          <IconAction name="Pencil" disabled />
          <span className="component-help-text">without tooltip</span>
        </Wrapper>
        <Wrapper>
          <IconAction name="Copy" disabled tooltipText="Copy campaign" />
          <span className="component-help-text">with tooltip</span>
        </Wrapper>
      </Container>
    )
  })
