import React, { useState } from 'react'
import PropTypes from 'prop-types'

// eslint-disable-next-line import/no-named-as-default
import Icon from '../Icon'
import Tooltip from '../Tooltip'
import { ActionWrapper } from './IconAction.styles'

const IconAction = ({
  name,
  size,
  disabled,
  onClick,
  tooltipText,
  tooltipPlacement,
  tooltipProps = {},
  className,
  /**
   * if true, tooltip component will be rendered
   * in the DOM only when icon is hovered
   *
   * default value is false
   */
  renderTooltipOnHover
}) => {
  const [isHover, setIsHover] = useState(false)
  return (
    <ActionWrapper
      disabled={disabled}
      onClick={onClick}
      className={className}
      onMouseEnter={() => setIsHover(true)}
      onMouseLeave={() => setIsHover(false)}
    >
      {
        tooltipText && (!renderTooltipOnHover || isHover) ? (
          <Tooltip
            body={tooltipText}
            placement={tooltipPlacement}
            size="sm"
            readOnly
            {...tooltipProps}
          >
            <Icon name={name} size={size} />
          </Tooltip>
        ) : <Icon name={name} size={size} />
      }
    </ActionWrapper>
  )
}

IconAction.propTypes = {
  name: PropTypes.string.isRequired,
  size: PropTypes.string,
  disabled: PropTypes.bool,
  onClick: PropTypes.func,
  tooltipText: PropTypes.string,
  tooltipPlacement: PropTypes.string,
  tooltipProps: PropTypes.shape({}),
  className: PropTypes.string,
  renderTooltipOnHover: PropTypes.bool
}

IconAction.defaultProps = {
  size: 'sm',
  disabled: false,
  onClick: () => null,
  tooltipText: null,
  tooltipPlacement: 'top',
  tooltipProps: {},
  className: '',
  renderTooltipOnHover: false
}

export default IconAction
