/* eslint-disable import/no-extraneous-dependencies */
import React from 'react'

import { storiesOf } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withState } from '@dump247/storybook-state'

import Input from './index'
import Icon from '../Icon'

const stories = storiesOf('Input', module)

stories.addDecorator(withA11y)

stories.add('default', () => {
  return (
    <div>
      <Input
        defaultValue="Initial Value"
        onBlur={e => console.log('blur event', e)}
        onFocus={e => console.log('focus event', e)}
        onClick={e => console.log('click event', e)}
      />
    </div>
  )
})

stories.add('large', () => {
  return (
    <div>
      <Input defaultValue="Initial Value" large />
    </div>
  )
})

stories.add('placeholder', () => {
  return (
    <div>
      <Input placeholder="Placeholder Text" />
    </div>
  )
})

stories.add('required', () => {
  return (
    <div>
      <Input required />
    </div>
  )
})

stories.add('error border', () => {
  return (
    <div>
      <Input invalid />
    </div>
  )
})

stories.add('full width', () => {
  return (
    <Input width="full" placeholder="Full width input" />
  )
})

const state = {
  text: 'Initial Text',
  value: '',
}

stories.add('Controlled',
  withState(state)(({ store }) => (
    <Input
      value={store.state.text}
      onChange={e => store.set({ text: e })}
    />
  )))

stories.add('with left icon',
  withState(state)(({ store }) => (
    <Input
      iconLeft={<Icon name="Calendar" stroke="#959DA8" />}
      value={store.state.text}
      onChange={e => store.set({ text: e })}
      placeholder="mm/dd/yyyy"
      width="full"
    />
  )))

stories.add('Get event', withState(state)(({ store }) => {
  return (
    <div>
      <Input
        defaultValue="Initial Value"
        value={store.state.value}
        onChange={(value, e) => {
          store.set({ value })
          console.log(e)
        }
        }
      />
    </div>
  )
}))
