// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import uncontrollable from 'uncontrollable'
import { Icon } from '../Icon'
import { Button } from '../Button'
import ButtonIcon from '../ButtonIcon'


import * as styles from './input.styles'

class Input extends PureComponent {
  constructor(props) {
    super(props)

    this.timeoutID = null
    this.state = {
      isManagingFocus: false,
    }
  }

  onBlur(e) {
    const {
      isManagingFocus
    } = this.state

    const {
      onBlur
    } = this.props

    this.timeoutID = setTimeout(() => {
      if (isManagingFocus) {
        this.setState({
          isManagingFocus: false,
        }, () => {
          onBlur(e)
        })
      }
    }, 0)
  }

  onFocus(e) {
    clearTimeout(this.timeoutID)
    const {
      isManagingFocus
    } = this.state

    const {
      onFocus
    } = this.props

    if (!isManagingFocus) {
      this.setState({
        isManagingFocus: true,
      }, () => {
        onFocus(e)
      })
    }
  }

  render() {
    const {
      type,
      placeholder,
      width,
      invalid,
      disabled,
      large,
      required,
      value,
      onChange,
      iconRight,
      iconLeft,
      readOnly,
      onClick,
      onKeyDown,
      autoFocus,
      ...rest
    } = this.props

    return (
      <styles.InputContainer>
        {iconLeft && <span className="icons-left">{iconLeft}</span>}
        <styles.StyledInput
          type={type}
          value={value}
          onFocus={e => this.onFocus(e)}
          onBlur={e => this.onBlur(e)}
          onClick={e => onClick(e)}
          onChange={e => onChange(e.target.value, e)}
          onKeyDown={e => onKeyDown(e)}
          placeholder={placeholder}
          disabled={disabled}
          readOnly={readOnly}
          size={large ? 'large' : 'default'}
          required={required && true}
          width={width}
          border={invalid ? 'error' : 'dark'}
          iconLeft={iconLeft}
          iconRight={iconRight}
          autoFocus={autoFocus}
          {...rest}
        />
        {iconRight && <span className="icons-right">{iconRight}</span>}
      </styles.InputContainer>
    )
  }
}

Input.propTypes = {
  value: PropTypes.string,
  onChange: PropTypes.func.isRequired,
  onFocus: PropTypes.func,
  onBlur: PropTypes.func,
  onClick: PropTypes.func,
  onKeyDown: PropTypes.func,
  type: PropTypes.string,
  placeholder: PropTypes.string,
  width: PropTypes.string,
  disabled: PropTypes.bool,
  required: PropTypes.bool,
  readOnly: PropTypes.bool,
  large: PropTypes.bool,
  invalid: PropTypes.bool,
  autoFocus: PropTypes.bool,
  iconRight: PropTypes.oneOfType([
    PropTypes.arrayOf(PropTypes.shape({
      type: PropTypes.oneOf([Icon, Button, ButtonIcon])
    })),
    PropTypes.shape({
      type: PropTypes.oneOf([Icon, Button, ButtonIcon])
    })
  ]),
  iconLeft: PropTypes.oneOfType([
    PropTypes.arrayOf(PropTypes.shape({
      type: PropTypes.oneOf([Icon, Button, ButtonIcon])
    })),
    PropTypes.shape({
      type: PropTypes.oneOf([Icon, Button, ButtonIcon])
    })
  ])
}

Input.defaultProps = {
  value: '',
  type: 'text',
  placeholder: '',
  width: 'default',
  disabled: false,
  required: false,
  readOnly: false,
  large: false,
  invalid: false,
  onFocus: () => {},
  onBlur: () => {},
  onClick: () => {},
  onKeyDown: () => {},
  iconRight: null,
  iconLeft: null,
  autoFocus: false,
}

const UncontrolledInput = uncontrollable(Input, {
  value: 'onChange',
})

export default UncontrolledInput
