import styled from 'styled-components'
import styledMap from 'styled-map'

import theme from 'theme'

export const InputContainer = styled.div`
  display: flex;
  align-items: center;
  justify-content: center;
  position: relative;
  width: ${styledMap('width', { full: '100%', default: 'auto' })};
  transition: border-color 125ms ease;
  .icons-right{
    z-index:2;
    display: flex;
    align-items: center;
    position: absolute;
    right: 16px;
    svg {
      width: 9px;
      height: 10px;
      margin-top: 4px;
      path{
        fill: #9BA2AC
      }
    }
  }
  .icons-left{
    display: flex;
    align-items: center;
    position: absolute;
    left: 10px;
    z-index: 2;
  }
  svg {
    position: relative;
    pointer-events: none;
    color: ${theme.input.iconColor};
    
  }
`

export const StyledInput = styled.input`
  height: ${styledMap('size', theme.input.height)};
  width: ${styledMap('width', { full: '100%', default: 'auto' })};
  border-radius: ${theme.input.borderRadius};
  outline: none;
  box-sizing: border-box;
  border: 1px solid ${styledMap('border', theme.colors.border)};
  transition: border-color 125ms ease;
  color: ${theme.input.color};
  padding: 0 ${({ iconRight }) => (!iconRight ? '16px' : '35px')} 0  ${({ iconLeft }) => (!iconLeft ? '16px' : '45px')};
  background-color: transparent;
  z-index: 1;
  font-size: ${styledMap('size', theme.input.fontSize)};
  
  &::placeholder {
    left: -10px;
    color: ${theme.input.placeholder.color};
  }
  
  &:hover {
    border: 1px solid ${theme.input.hover.borderColor};
  }
  
  &:focus {
    border: 1px solid ${theme.input.focus.borderColor};
    box-shadow: ${theme.input.focus.boxShadow};
  }
  &:invalid {
    border: 1px solid ${theme.input.error.borderColor};
    box-shadow: none;
  }
  
  &:disabled {
    border: 1px solid ${theme.input.disabled.borderColor};
    color: ${theme.input.disabled.color};
  }
`
