/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { scaleLinear } from 'd3-scale'
import theme from 'theme'
import Moment from 'moment'

// Components
import Line from './index'

const { colors } = theme.chart.default

const scores = [
  { date: '012018', value: 0 },
  { date: '022018', value: 37 },
  { date: '032018', value: 43 },
  { date: '042018', value: 17 },
  { date: '052018', value: 32 },
  { date: '062018', value: 44 },
  { date: '072018', value: 33 },
  { date: '082018', value: 29 },
  { date: '092018', value: 15 },
  { date: '102018', value: 94 },
  { date: '112018', value: 62 },
  { date: '122018', value: 100 }
]

const formattedScores = scores.map((obj) => {
  obj.date = Moment(obj.date, 'MMYYYY').toDate()
  return obj
})

const xScale = scaleLinear()
  .domain([formattedScores[0].date, formattedScores[11].date])
  .range([0, 359])
const yScale = scaleLinear()
  .domain([0, 100])
  .range([167.5, 0])

const lineProps = {
  color: 'black',
  data: formattedScores,
  translate: 'translate(8, 20)',
  xKey: 'date',
  yKey: 'value',
  xScale,
  yScale
}

const lineGradProps = {
  ...lineProps,
  colorArr: colors,
  gradientId: 'line-gradient'
}

addDecorator(withA11y)

storiesOf('Charts/Line', module)
  .add('With Gradient', () => (
    <svg width="500" height="500">
      <Line {...lineGradProps} />
    </svg>
  ))
  .add('Without Gradient', () => (
    <svg width="500" height="500">
      <Line {...lineProps} />
    </svg>
  ))
