// Libraries
import React, { PureComponent } from 'react'
import styled from 'styled-components'
import { Link as ReactLink } from 'react-router-dom'
import PropTypes from 'prop-types'

// Theme
import theme from 'theme'


const LinkStyle = (props) => {
  const display = props.contain ? 'flex' : 'inline'
  return `
    color: ${theme.text.color.link};
    text-decoration:none;
    display: ${display};
    justify-content: center;
    cursor:pointer;
    &:hover {
      color: ${theme.text.color.linkHover};
      text-decoration:underline;
    }
  `
}

const HyperLink = styled.a`${props => LinkStyle(props)}`
const RouterLink = styled(ReactLink)`${props => LinkStyle(props)}`

class Link extends PureComponent {
  static defaultProps = {
    title: '',
    isExternal: false,
    contain: '',
    onClick: () => {},
    disabled: false,
    target: ''
  }

  static propTypes = {
    title: PropTypes.string,
    to: PropTypes.string.isRequired,
    isExternal: PropTypes.bool,
    contain: PropTypes.string,
    onClick: PropTypes.func,
    disabled: PropTypes.bool,
    target: PropTypes.string
  }
  /**
   * The isExternalLink is responsible by to check
   * whether the url is a external link  or not
   *
   * @param {string} url
   * @returns {boolean}
   * @memberof Link
   */

  isExternalLink = (url) => {
    return (
      /^https?:\/\//.test(url)
      || /^mailto?:/.test(url)
    )
  }

  render() {
    const {
      to,
      title,
      children,
      isExternal,
      contain,
      onClick,
      disabled,
      target
    } = this.props

    const newProps = {
      to,
      title,
      children,
      contain,
      onClick,
      disabled
    }

    return !isExternal && !this.isExternalLink(to)
      ? (
        <RouterLink {...newProps} contain={contain}>{!children ? title : children}</RouterLink>)
      : (
        <HyperLink {...newProps} contain={contain} href={to} target={target}>
          {!children ? title : children}
        </HyperLink>
      )
  }
}

export default Link
