/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs, select } from '@storybook/addon-knobs';
import { action } from '@storybook/addon-actions'


// Themes
import theme from 'theme'

// Components
import Messages from './index'

const messageContent = [
  {
    id: 1,
    type: 'generic',
    level: 'success',
    header: 'success!',
    content: 'This is a success message'
  },
  {
    id: 2,
    type: 'generic',
    level: 'info',
    header: 'info!',
    content: 'This is a info message'
  },
  {
    id: 3,
    type: 'generic',
    level: 'warning',
    header: 'warning!',
    content: 'This is a warning message'
  },
  {
    id: 4,
    type: 'generic',
    level: 'danger',
    header: 'error!',
    content: 'This is a error message'
  }
]

const messageConfirmation = [
  {
    id: 1,
    type: 'confirm',
    level: 'success',
    header: 'success!',
    content: 'This is a success message',
    confirmAction: action('Confirming 1')
  },
  {
    id: 2,
    type: 'confirm',
    level: 'info',
    header: 'info!',
    content: 'This is a info message',
    confirmAction: action('Confirming 2')
  },
  {
    id: 3,
    type: 'confirm',
    level: 'warning',
    header: 'warning!',
    content: 'This is a warning message',
    confirmAction: action('Confirming 3')
  },
  {
    id: 4,
    type: 'confirm',
    level: 'danger',
    header: 'error!',
    content: 'This is a error message',
    confirmAction: action('Confirming 4')
  }
]

addDecorator(withA11y)
addDecorator(withKnobs)

storiesOf('Messages', module)
  .addParameters({
    jest: ['Messages'],
  })
  .add('Messages', () => (
    <Messages
      actions={{
        deleteMessage: action('Deleted a message')
      }}
      messages={{
        messages: messageContent 
      }}
    />
  ))
  .add('confirmation messages', () => (
    <Messages
      actions={{
        deleteMessage: action('Deleted a message')
      }}
      messages={{ messages: messageConfirmation }}
    />
  ))