// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'

// Styles
import Styles, { MessagingContainer, Container, MessageText }  from './Messages.styles'

class Messages extends PureComponent {
  render() {
    const { deleteMessage } = this.props.actions
    const { messages } = this.props.messages

    return (
      <Styles.Messages>
        <MessagingContainer>
          <Container>
            {messages.filter(message => message.type === 'confirm').map(message => (
              <div
                key={message.id}
                role="Note"
                className={`alert alert-${message.level} d-flex justify-content-between`}
              >
                <MessageText>
                  <strong>{message.header}</strong>
                  &nbsp;
                  <span>{message.content}</span>
                </MessageText>
                <div>
                  <button
                    className="confirm float-right btn btn-sm btn-primary"
                    type="button"
                    aria-label="Confirm"
                    onClick={() => message.confirmAction(message.id)}
                  >
                    <span aria-hidden="true">OK</span>
                  </button>
                  <button
                    className="cancel float-right btn btn-sm btn-outline-success-custom mr-1"
                    type="button"
                    aria-label="Cancel"
                    onClick={() => deleteMessage(message.id)}
                  >
                    <span aria-hidden="true">Cancel</span>
                  </button>
                </div>
              </div>
            ))}
            {messages.filter(message => message.type === 'generic').map(message => (
              <div
                key={message.id}
                role="alert"
                className={`alert alert-${message.level} d-flex justify-content-between`}
              >
                <MessageText>
                  <strong>{message.header}</strong>
                  &nbsp;
                  <span dangerouslySetInnerHTML={{ __html: message.content }} />
                </MessageText>
                <button
                  type="button"
                  className="close"
                  aria-label="Close"
                  onClick={() => deleteMessage(message.id)}
                >
                  <span aria-hidden="true">&times;</span>
                </button>
              </div>
            ))}
          </Container>
        </MessagingContainer>
      </Styles.Messages>
    )
  }
}

Messages.propTypes = {
  actions: PropTypes.shape({
    deletedMessage: PropTypes.func
  }),
  messages: PropTypes.shape({
    messages: PropTypes.arrayOf(
      PropTypes.shape({
        id: PropTypes.number,
        type: PropTypes.string,
        level: PropTypes.string,
        header: PropTypes.string,
        content: PropTypes.string
      })
    )
  })
}

Messages.defaultProps = {
  actions: {deleteMessage: undefined},
  messages: {messages: [{
    id: 1,
    type: 'generic',
    level: 'success',
    header: 'success!',
    content: 'This is a success message'
  }]}
}

export default Messages
