/* eslint-disable react/prop-types */
/* eslint-disable no-console */
/* eslint-disable no-undef */
import { mount } from 'enzyme'
import React from 'react'
import Modal from './index'


import { Button } from '../Button'
import Header from '../Header'
import { H1 } from '../Typography'

const headerTitle = (
  <Header>
    <H1
      fontWeight="bold"
      color="900"
      dangerouslySetInnerHTML={{ __html: 'Importing employee data' }}
    />
  </Header>
)

const ComponentMocked = ({ onClose, isOpen, onOpen }) => (
  <Modal
    key="modal"
    onClose={onClose}
    isOpen={isOpen}
    onOpen={onOpen}
    header={headerTitle}
    leftButtons={[<Button key="goBack">Go Back</Button>]}
    rightButtons={[<Button key="save">Save</Button>]}
  />
)

// Build the mocked wrapper of modal
const mockMountedWrapper = ({ onOpen = null, isOpen = null, onClose = null } = {}) => {
  const isOpenFn = isOpen === null ? true : isOpen
  const onOpenFn = !onOpen ? jest.fn() : onOpen
  const onCloseFn = !onClose ? jest.fn() : onClose
  const wrapper = mount(
    <ComponentMocked
      onClose={onCloseFn}
      isOpen={isOpenFn}
      onOpen={onOpenFn}
    />
  )
  return wrapper
}

describe('Describe the modal', () => {
  test('Rendering Modal', () => {
    expect(mockMountedWrapper()).toMatchSnapshot()
  })

  test('When the Modal was rendered as closed', () => {
    const onOpen = jest.fn()
    const isOpen = false
    const wrapper = mockMountedWrapper({ onOpen, isOpen })

    expect(wrapper.props().isOpen).toEqual(false)
    expect(onOpen).toHaveBeenCalledTimes(0)
    expect(wrapper.isEmptyRender()).toEqual(true)
  })

  test('When the Modal was rendered as opened', () => {
    const isOpen = true
    const onOpen = jest.fn()
    const onClose = jest.fn()
    const wrapper = mockMountedWrapper({ onOpen, onClose, isOpen })

    expect(wrapper.props().isOpen).toEqual(true)
    expect(onOpen).toHaveBeenCalledTimes(1)
    expect(wrapper.html()).not.toBeNull()
    expect(wrapper.isEmptyRender()).toEqual(false)
  })


  test('When the user close the modal by the button', () => {
    let isOpen = true
    const onOpen = jest.fn()
    const onClose = jest.fn(() => { isOpen = false })

    const wrapper = mockMountedWrapper({ onOpen, onClose, isOpen })

    const closeButton = wrapper.find('button').at(0)
    closeButton.simulate('click', wrapper.setProps({ isOpen: !isOpen }))

    expect(wrapper.props().isOpen).toEqual(false)
    expect(onClose).toHaveBeenCalledTimes(1)
    expect(wrapper.isEmptyRender()).toEqual(true)
  })

  test('When the user closes the modal by over layer', () => {
    let isOpen = true
    const onOpen = jest.fn()
    const onClose = jest.fn(() => { isOpen = false })

    const wrapper = mockMountedWrapper({ onOpen, onClose, isOpen })

    const overLayer = wrapper.find('div').at(0)
    overLayer.simulate('click', wrapper.setProps({ isOpen: !isOpen }))

    expect(wrapper.props().isOpen).toEqual(false)
    expect(onClose).toHaveBeenCalledTimes(1)
    expect(wrapper.isEmptyRender()).toEqual(true)
  })
})
