/* eslint-disable jsx-a11y/label-has-associated-control */
/* eslint-disable jsx-a11y/label-has-for */
/* eslint-disable no-console */
/* eslint-disable react/jsx-wrap-multilines */
/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useState } from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'

import styled from 'styled-components'


// Components
import Modal from './index'
import Header from '../Header'
import Link from '../Link'
import Breadcrumb from '../Breadcrumb'
import Input from '../Input'
import EmptyBlock from '../EmptyBlock'
import { Button } from '../Button'
import {
  H2, Body, H1, Small, H3, H4, H5
} from '../Typography'

const HelperContent = styled.div`
  padding: 16px 24px;
  height: 115px;
  border-radius: 6px;
  background-color: #F1F9F9;
  margin-bottom: 24px;
  h2{
    padding: 5px 0;
  }
`
function renderBodyContent() {
  return (
    <div>
      <HelperContent>
        <H2 fontWeight="bold" color="900">Need Help Importing employee data?</H2>
        <Body>
          Start by downloading our demo CSV file make sure all the column headers are the same.
          If you feel lost, don’t hesitate to contact our Customer Success team
        </Body>
      </HelperContent>
      <EmptyBlock
        iconName="Users"
        body="No employees imported"
        buttonTitle="Import Employees CSV"
        onClickButton={(e) => {
          console.log(e)
        }}
      />
    </div>
  )
}

function renderButtons() {
  return [
    <Button key="cancel" theme="ghost">Cancel</Button>,
    <Button key="save">Save</Button>
  ]
}
function renderBodyContentPulseExample() {
  return (
    <div style={{ maxWidth: '556px', margin: 'auto' }}>
      <fieldset>
        <H5 fontWeight="bold" color="900" style={{ display: 'block', padding: '8px 0' }}>Campaign Name</H5>
        <Input width="full" />

        <H5 fontWeight="bold" color="900" style={{ display: 'block', padding: '8px 0' }}>Choose the behaviors you want to influence</H5>

        <label style={{ display: 'block', padding: '8px 0' }}>
          <input type="checkbox" />
          <H5 style={{ display: 'inline-block', paddingLeft: '5px' }}> Password Manager</H5>
        </label>
        <label style={{ display: 'block', padding: '8px 0' }}>
          <input type="checkbox" />
          <H5 style={{ display: 'inline-block', paddingLeft: '5px' }}> Phishing Detection</H5>
        </label>

        <label style={{ display: 'block', padding: '8px 0' }}>
          <input type="checkbox" />
          <H5 style={{ display: 'inline-block', paddingLeft: '5px' }}> Phishing Reporting</H5>
        </label>

        <label style={{ display: 'block', padding: '8px 0' }}>
          <input type="checkbox" />
          <H5 style={{ display: 'inline-block', paddingLeft: '5px' }}> Malware Infection</H5>
        </label>
        <label style={{ display: 'block', padding: '8px 0' }}>
          <input type="checkbox" />
          <H5 style={{ display: 'inline-block', paddingLeft: '5px' }}> Security Training</H5>
        </label>
      </fieldset>
    </div>
  )
}

const headerTitle = (
  <Header>
    <H2
      fontWeight="bold"
      color="900"
      dangerouslySetInnerHTML={{ __html: 'Importing New Employees' }}
      margin={0}
    />
  </Header>
)

export default function WhateverContainer() {
  const [isOpen, seIsOpen] = useState(false)
  return (
    <div>
      <Button
        onClick={() => seIsOpen(!isOpen)}
      >
        Open Modal
      </Button>
      <Modal
        key="modal"
        onClose={() => seIsOpen(!isOpen)}
        header={headerTitle}
        rightButtons={renderButtons()}
        isOpen={isOpen}
      >
        {renderBodyContent()}
      </Modal>
    </div>
  )
}

addDecorator(withA11y)
addDecorator(withKnobs)

storiesOf('Modal', module)
  .addParameters({
    jest: ['Modal'],
  })
  .add('Render the container with complete modal content', () => {
    return (
      <WhateverContainer />
    )
  })
  .add('Render the  Modal with header title only', () => {
    return (
      <Modal
        key="modal"
        onClose={() => true}
        header={headerTitle}
        isOpen
      />
    )
  })

  .add('Render the  Modal with header title and content', () => {
    return (
      <Modal
        key="modal"
        onClose={() => true}
        header={headerTitle}
        isOpen
      >
        {renderBodyContent()}
      </Modal>
    )
  })
  .add('Render the  Modal with header title, content and bottom buttons', () => {
    return (
      <Modal
        key="modal"
        onClose={() => true}
        header={headerTitle}
        rightButtons={renderButtons()}
        isOpen
      >
        {renderBodyContent()}
      </Modal>
    )
  })
  .add('Render the  Modal with  custom close button and breadcrumb', () => {
    function Example() {
      const [isOpen, setIsOpen] = useState(true)

      const headerTitlePulse = (
        <Header>
          <Small>CREATE A PULSE CAMPAIGN 1 OF 4</Small>
          <H3
            fontWeight="bold"
            color="900"
            dangerouslySetInnerHTML={{ __html: 'Create New Pulse Campaign' }}
          />
        </Header>
      )
      const closeModal = (e) => {
        e.preventDefault()
        setIsOpen(!isOpen)
      }

      const closeButton = (
        <Link to="/#" isExternal title="Close Button" onClick={closeModal}>Finish Later</Link>
      )

      const breadcrumb = (
        <Breadcrumb>
          <Link to="/efactored" isExternal>
            <Small color="300" fontWeight="bold">Campaign Type</Small>
          </Link>
          <Link to="/" isExternal>
            <Small color="300">Recipients</Small>
          </Link>
          <Link to="/" isExternal>
            <Small color="300">Launch Date</Small>
          </Link>
          <Link to="/" isExternal>
            <Small color="300">Confirm</Small>
          </Link>
        </Breadcrumb>
      )

      if (!isOpen) {
        return (
          <Button
            onClick={() => setIsOpen(!isOpen)}
          >
            Open Modal
          </Button>
        )
      }

      return (
        <Modal
          key="modal"
          style={{ maxWidth: '1096px' }}
          onClose={() => setIsOpen(!isOpen)}
          header={headerTitlePulse}
          leftButtons={[<Button key="back" theme="ghost" style={{ minWidth: '140px', border: '1px solid #0c7d84' }}>Back</Button>]}
          rightButtons={[<Button key="save">Save & Continue</Button>]}
          closeButton={closeButton}
          breadcrumb={breadcrumb}
          isOpen={isOpen}
        >
          {renderBodyContentPulseExample()}
        </Modal>
      )
    }
    return <Example />
  })
