/* eslint-disable react/prop-types */
import React, { useState, useEffect, useCallback, useRef } from 'react'
import PropTypes from 'prop-types'
import { Container, DropdownToggle, Dropdown, Section } from './MoreFilters.styles'
import { getDropdownOptions, FILTER_TYPE } from './utils'
import { Icon } from '..'
import MultiSelectFilter from '../MultiSelectFilter'
import DateRange from '../DateRange'

const MoreFilters = ({ filters, onSelection, _options, optionParams }) => {
  const ref = useRef(null)
  const count = filters?.length

  const [isOpen, setIsOpen] = useState(false)
  const [options, setOptions] = useState()

  useEffect(() => {
    setOptions(getDropdownOptions(_options, ...optionParams))
  }, [_options, optionParams])

  const clickListener = useCallback(
    e => {
      if (
        !ref.current.contains(e.target) &&
        !e.target.classList.contains('show-more-link') &&
        !e.target.classList.contains('expand-icon')
      ) {
        setIsOpen(false)
      }
    },
    [ref.current]
  )

  useEffect(() => {
    document.addEventListener('click', clickListener)
    return () => {
      document.removeEventListener('click', clickListener)
    }
  })
  useEffect(() => {
    if (count === 0) {
      setIsOpen(false)
    }
  }, [count])

  const renderFilterComponent = section => {
    const { type, showAllFilter } = section
    if (type === FILTER_TYPE.MULTI_SELECT)
      return (
        <MultiSelectFilter
          section={section}
          filters={filters}
          handleChange={onSelection}
          showAllFilters={showAllFilter}
        />
      )
    else if (type === FILTER_TYPE.DATE_RANGE) {
      const dataRangeFilter = filters?.find(filter => filter.key === section.key)
      return <DateRange section={section} value={dataRangeFilter?.value} onChange={onSelection} />
    }
    return null
  }
  return (
    <Container ref={ref} data-test-id="more-filters">
      <DropdownToggle isOpen={isOpen} onClick={() => setIsOpen(!isOpen)}>
        More Filters
        {count > 0 ? <span>&nbsp;({count})</span> : null}
        <Icon name="CaretDown" size="xxsm" fill="#959DA8" />
      </DropdownToggle>
      {isOpen && options && (
        <Dropdown>
          {options.map(section => (
            <Section key={section.key}>{renderFilterComponent(section)}</Section>
          ))}
        </Dropdown>
      )}
    </Container>
  )
}

MoreFilters.propTypes = {
  filters: PropTypes.arrayOf(PropTypes.shape({})).isRequired,
  onSelection: PropTypes.func.isRequired
}

export default MoreFilters
