import React, { useState } from 'react'
import PropTypes from 'prop-types'

import Checkbox from './Checkbox'
import { Icon } from '..'
import { Wrapper } from './MultiSelectFilter.styles'

const MultiSelectFilter = ({ section, filters, handleChange, showAllFilters = false }) => {
  const { showMore, showLess, items, key } = section
  const showInLowerCase = item => item.toLowerCase().replace(/\s/g, '_')

  const [expanded, setExpanded] = useState(showAllFilters)
  const showCount = expanded ? items.length : 4
  const isChecked = value => {
    return !!filters.find(filter => filter.key === key && filter.value === showInLowerCase(value))
  }

  return (
    <Wrapper>
      <div className="title">{section.title}</div>
      <div className="checkbox-items">
        {items.slice(0, showCount).map(item => {
          const { label, value, original } = item
          return (
            <Checkbox
              label={label}
              id={`${section.title}-${label}`}
              key={value}
              checked={isChecked(value)}
              onChange={checked =>
                handleChange({
                  key,
                  label,
                  value,
                  checked,
                  original
                })
              }
            />
          )
        })}
      </div>
      {showMore && (
        <div className="show-more-link" onClick={() => setExpanded(!expanded)}>
          {expanded ? showLess : showMore}
          <Icon
            name={expanded ? 'CaretUp' : 'CaretDown'}
            size="xxsm"
            fill="#0C7D84"
            className="expand-icon"
          />
        </div>
      )}
    </Wrapper>
  )
}

MultiSelectFilter.propTypes = {
  section: PropTypes.shape({
    title: PropTypes.string.isRequired,
    items: PropTypes.arrayOf(PropTypes.shape({})).isRequired,
    key: PropTypes.string.isRequired,
    showMore: PropTypes.string,
    showLess: PropTypes.string
  }).isRequired,
  filters: PropTypes.arrayOf(
    PropTypes.shape({
      key: PropTypes.string,
      value: PropTypes.oneOfType([PropTypes.string, PropTypes.bool, PropTypes.number])
    })
  ).isRequired,
  handleChange: PropTypes.func.isRequired
}

export default MultiSelectFilter
