// Libraries
import React from 'react'
import PropTypes from 'prop-types'

// Components
import Card from '../Card'
import Avatar from '../Avatar'
import { Text, H2 } from '../Typography'
import Layout from '../Layout'
import { Button } from '../Button'
import Link from '../Link'
import GloblStyle from '../GlobalStyle'

// styles
import * as Styles from './OrganizationCard.styles'

export default function OrganizationCard({ organizationName, totalEmployees }) {
  const employees = !totalEmployees ? <Text>No employees imported</Text> : <Link to="/#">{totalEmployees}</Link>
  return (
    <>
      <Styles.OrganizationCard>
        <Card>
          <Layout alignItems="flex-start" container>
            <Layout>
              <Avatar name={organizationName} type="square" size="xlg" />
            </Layout>
            <Layout>
              <H2 fontWeight="bold" fontSize="xxlg" color="900">{organizationName}</H2>
              {employees}
            </Layout>
          </Layout>
          <Layout alignItems="flex-start" container>
            <Button theme="secondary" size="xlg">Organization Details</Button>
          </Layout>
        </Card>
      </Styles.OrganizationCard>
      <GloblStyle />
    </>
  )
}

OrganizationCard.propTypes = {
  organizationName: PropTypes.string.isRequired,
  totalEmployees: PropTypes.string,
}

OrganizationCard.defaultProps = {
  totalEmployees: null
}
