/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useEffect, useState } from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'
import { Text } from '../Typography'
// Components
import RadioButton from './index'

addDecorator(withA11y)
addDecorator(withKnobs)

const options = [
  {
    value: 'Option 1',
    label: 'This is the label 1',
    helpText: 'This is the help text',
    tooltipText: 'This is the tooltip text for option 1'
  },
  {
    value: 'Option 2',
    label: 'This is the label 2',
    helpText: 'This is the help text',
    tooltipText: 'This is the tooltip text for option 2'
  },
  {
    value: 'Option 3 - Selected',
    label: 'This is the label 3',
    helpText: 'This is the help text',
    tooltipText: 'This is the tooltip text for option 3'
  }
]

const optionsWithDisabled = [
  {
    value: 'Option 1',
    label: 'Real-World Phishing',
    tooltipText: 'This is the tooltip text for option 1'
  },
  {
    value: 'Option 2',
    label: 'Malware',
    tooltipText: 'This is the tooltip text for option 2',
    optionDisabled: true
  },
  {
    value: 'Option 3 - Selected',
    label: 'Password Manager',
    tooltipText: 'This is the tooltip text for option 3'
  }
]

const optionsWizardExample = [
  {
    value: 'General',
    label: 'General',
    helpText: 'We’ll offer session scenarios geared toward employees in non-technical roles'
  },
  {
    value: 'Technical',
    label: 'Technical',
    helpText: 'We’ll offer session scenarios geared toward employees primarily in technical roles'
  }
]

const handleChange = (value, event) => {
  console.log(value)
  console.log(event)
}

storiesOf('RadioButton', module)
  .addParameters({
    jest: ['RadioButton']
  })
  .add('RadioButton', () => (
    <RadioButton
      options={options}
      name="defaultRadio"
      radioSelected="Option 3 - Selected"
      onChange={handleChange}
      controlled={false}
    />
  ))
  .add('RadioButton Vertical', () => (
    <RadioButton
      options={options}
      name="defaultRadio"
      radioSelected="Option 3 - Selected"
      vertical
      onChange={handleChange}
      controlled={false}
    />
  ))
  .add('RadioButton wizard example', () => (
    <div style={{ display: 'block', maxWidth: '780px' }}>
      <RadioButton
        options={optionsWizardExample}
        name="defaultRadio"
        radioSelected="Technical"
        onChange={handleChange}
        controlled={false}
      />
    </div>
  ))
  .add('RadioButton required', () => (
    <RadioButton
      options={options}
      name="defaultRadio"
      onChange={handleChange}
      invalid
      controlled={false}
    />
  ))
  .add('RadioButton disabled', () => (
    <RadioButton
      radioSelected="Option 3 - Selected"
      options={options}
      name="defaultRadio"
      onChange={handleChange}
      disabled
      controlled={false}
    />
  ))
  .add('RadioButton with some disabled options', () => (
    <RadioButton
      radioSelected="Option 3 - Selected"
      options={optionsWithDisabled}
      name="defaultRadio"
      onChange={handleChange}
      controlled={false}
    />
  ))
  .add('RadioButton with Tooltip', () => (
    <RadioButton
      options={options}
      name="defaultRadio"
      onChange={handleChange}
      tooltip
      controlled={false}
    />
  ))
  .add('Controlled Radio button', () => {
    const [selection, setSelection] = useState(null)

    useEffect(() => {
      setTimeout(() => setSelection('Option 3 - Selected'), 1000)
    }, [])

    return (
      <RadioButton
        options={options}
        name="defaultRadio"
        radioSelected={selection}
        vertical
        onChange={val => setSelection(val)}
      />
    )
  })
  .add('Radio button with Border', () => {
    const [selection, setSelection] = useState(null)
    const connectionMethods = [
      {
        label: 'Api Integration (recommended)',
        value: 'Api Integration',
        tooltipText: 'This is the tooltip for the API Integration'
      },
      {
        label: 'Push Data',
        value: 'Push Data',
        tooltipText: 'This is the tooltip for the Push Data'
      }
    ]
    useEffect(() => {
      setTimeout(() => setSelection('Option 3 - Selected'), 1000)
    }, [])

    return (
      <RadioButton
        options={connectionMethods}
        name="defaultRadio"
        radioSelected={selection}
        bordered
        onChange={val => setSelection(val)}
      />
    )
  })
  .add('Radio button with Border and Nested Radio Button', () => {
    const [selectionParent, setSelectionParent] = useState(null)
    const [selectionChild, setSelectionChild] = useState(null)

    const pushMethods = [
      {
        label: 'Import a single data file',
        value: 'Import a single data file',
        tooltipText: 'This is the tooltip for the API Integration'
      },
      {
        label: 'Push data through SFTP',
        value: 'Push data through SFTP',
        tooltipText: 'This is the tooltip for the API Integration'
      },
      {
        label: 'Elevate data push API',
        value: 'Elevate data push API',
        tooltipText: 'This is the tooltip for the API Integration'
      }
    ]

    const nestedRadioButton = (
      <React.Fragment>
        <Text fontWeight="normal" color="500">
          Select a push integration method:
        </Text>
        <RadioButton
          options={pushMethods}
          name="defaultNestedRadio"
          vertical
          onChange={setSelectionChild}
          radioSelected={selectionChild}
          tooltip
        />
      </React.Fragment>
    )

    const connectionMethods = [
      {
        label: 'Api Integration (recommended)',
        value: 'Api Integration',
        tooltipText: 'This is the tooltip for the API Integration'
      },
      {
        label: 'Push Data',
        value: 'Push Data',
        tooltipText: 'This is the tooltip for the Push Data',
        nestedRadioButton
      }
    ]

    return (
      <React.Fragment>
        <RadioButton
          options={connectionMethods}
          name="defaultRadio"
          tooltip
          radioSelected={selectionParent}
          bordered
          onChange={val => setSelectionParent(val)}
        />
        {selectionParent && (
          <Text fontWeight="normal" color="500">
            {selectionParent}
            in the parent has been selected
          </Text>
        )}
        <br />
        {selectionChild && (
          <Text fontWeight="normal" color="500">
            {selectionChild}
            in the child has been selected
          </Text>
        )}
      </React.Fragment>
    )
  })
