import styled, { css } from 'styled-components'
import theme from 'theme'
import styledMap from 'styled-map'

const RadioButtonWrapper = styled.div`
  display: flex;
  flex-direction: ${props => (props.vertical ? 'column' : 'row')};
  opacity: ${({ disabled }) => (disabled ? 0.7 : 1)};
  .no-selected {
    height: fit-content;
  }
`

const CheckMark = styled.span`
  position: absolute;
  display: flex;
  align-items: center;
  justify-content: center;
  top: 0;
  left: 0;
  height: 16px;
  width: 16px;
  background-color: white;
  border: 1px solid ${styledMap('border', theme.colors.border)};
  box-sizing: border-box;
  border-radius: 50%;
  &:after {
    content: '';
    position: absolute;
    display: none;
    width: 6px;
    height: 6px;
    border-radius: 50%;
    background: white;
  }
`

const RadioInput = styled.input`
  position: absolute;
  opacity: 0;
  cursor: ${({ disabled }) => (disabled ? 'not-allowed' : 'cursor')};
  &:checked + ${CheckMark} {
    background-color: ${({ disabled }) =>
      disabled ? theme.colors.gray.opaque[300] : theme.colors.primary[500]};
    border: 1px solid
      ${({ disabled }) => (disabled ? theme.colors.gray.opaque[300] : theme.colors.primary[500])};
  }
  &:checked + ${CheckMark}:after {
    display: block;
  }
`

const RadioInputContainer = styled.div`
  padding: 5px;
  ${({ disabled }) =>
    disabled &&
    css`
      opacity: 0.7;
    `}
  ${props =>
    props.bordered
      ? css`
          border: 1px solid #dde1e7;
          padding: 16px;
          margin: 0px 16px;
          border-radius: 4px;
        `
      : null};
`

const Label = styled.label`
  display: block;
  position: relative;
  padding: 0 25px;
  cursor: ${({ disabled }) => (disabled ? 'not-allowed' : 'cursor')};
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
`
const IconWrapper = styled.div`
  display: inline-block;
  margin-left: 8px;
  width: 16px;
  height: 16px;
  svg:hover {
    path {
      stroke: #039ba1;
    }
  }
`

const NestedRadioButtonWrapper = styled.div`
  border-top: 1px solid #dde1e7;
  margin-top: 16px;
  padding-top: 16px;
  [class^='RadioButtonstyles__RadioButtonWrapper'] {
    margin-top: 10px;
  }
`

export {
  RadioButtonWrapper,
  RadioInputContainer,
  RadioInput,
  CheckMark,
  Label,
  IconWrapper,
  NestedRadioButtonWrapper
}
