import React from 'react'
import { BodyWrapper, HeaderContainer, Row, Wrapper } from 'components/ScoreProgressBar/styles'
import { HeaderText } from 'components/ScoreProgressBar/utils'
import { Text } from 'components/Typography'
import PropTypes from 'prop-types'
import BarColors from 'components/BarColors'

function ScoreProgressBar(Props) {
  const {isHeader, score, headerDescription, bodyPadding, min, max} = Props
  return (
    <Wrapper>
      <HeaderContainer id="score_progress_bar_header">
        {isHeader && (
          <HeaderText value={score} description={headerDescription} />
        )}
      </HeaderContainer>
      <BodyWrapper id="score_progress_bar_body" padding={bodyPadding}>
        <Row justifyContent="space-between">
          {/* eslint-disable-next-line jsx-a11y/accessible-emoji */}
          <Text>{min.toFixed(1)} 💪</Text>
          {/* eslint-disable-next-line jsx-a11y/accessible-emoji */}
          <Text>😱 {max.toFixed(1)}</Text>
        </Row>
        <BarColors
          {...Props}
          score={score * 10}
        />
      </BodyWrapper>
    </Wrapper>
  )
}

ScoreProgressBar.propTypes = {
  bodyPadding: PropTypes.string,
  isHeader: PropTypes.bool,
  score: PropTypes.number,
  headerDescription: PropTypes.string,
  min: PropTypes.number,
  max: PropTypes.number,
  size: PropTypes.oneOf(['small', 'medium', 'default']),
  hasIndicatorBox:PropTypes.bool,
  invert: PropTypes.bool,
  showCircle: PropTypes.bool,
  sameColor: PropTypes.bool,
  // eslint-disable-next-line react/require-default-props
  barColor: PropTypes.string,
  padding: PropTypes.bool,
  isActionFactorChart: PropTypes.bool,
  showWideBar: PropTypes.number
}
ScoreProgressBar.defaultProps = {
  bodyPadding: '0 10px',
  isHeader: true,
  score: 10,
  headerDescription: "Human Risk Score",
  min: 0,
  max: 100,
  size: "small",
  hasIndicatorBox: false,
  invert: false,
  showCircle: true,
  sameColor: false,
  padding: true,
  isActionFactorChart: false,
  showWideBar: 0
}
export default ScoreProgressBar

