import { shallow, mount } from 'enzyme'
import React from 'react'

import SearchInput from './index'

test('Render a SearchInput', () => {
  const wrapper = shallow(<SearchInput value="test search..." handleSearch={() => {}} />)
  expect(wrapper).toMatchSnapshot()
})

test('Clearable search input with value', () => {
  const wrapper = mount(<SearchInput value="test search..." handleSearch={() => {}} />)
  expect(wrapper.find('[data-test-id="clear-search-icon"]').exists()).toEqual(true)
})

test('Non clearable search input with value', () => {
  const wrapper = mount(
    <SearchInput value="test search..." handleSearch={() => {}} isClearable={false} />
  )
  expect(wrapper.find('[data-test-id="clear-search-icon"]').exists()).toEqual(false)
})

test('Detect clicking cross icon to search input', () => {
  const mockCallback = jest.fn()
  const wrapper = mount(
    <SearchInput value="test search..." handleSearch={() => {}} clearSearch={mockCallback} />
  )
  const clearSearchIcon = wrapper.find('[data-test-id="clear-search-icon"]').at(0)
  clearSearchIcon.simulate('click')

  expect(mockCallback).toHaveBeenCalled()
})
