import React from 'react'
import PropTypes from 'prop-types'

import { Icon } from '..'
import { SearchInputWrapper, StyledInput, ClearSearchIcon } from './SearchInput.styles'

const SearchInput = props => {
  const { value, handleSearch, isClearable, clearSearch } = props

  return (
    <SearchInputWrapper data-test-id="searchbar">
      <StyledInput
        value={value}
        iconLeft={<Icon name="Search" size="xsm" fill="#7E8691" />}
        placeholder="Filter by event, individual, data source..."
        onChange={val => handleSearch(val)}
      />
      {isClearable && value !== '' && (
        <ClearSearchIcon data-test-id="clear-search-icon" onClick={clearSearch}>
          <Icon name="Close" stroke="#959DA8" size="xxsm" />
        </ClearSearchIcon>
      )}
    </SearchInputWrapper>
  )
}

SearchInput.defaultProps = {
  value: '',
  isClearable: true,
  clearSearch: () => {
    // This is intentional
  }
}

SearchInput.propTypes = {
  value: PropTypes.string,
  handleSearch: PropTypes.func.isRequired,
  isClearable: PropTypes.bool,
  clearSearch: PropTypes.func
}

export default SearchInput
