/* eslint-disable react/prop-types */
// Libraries
import PropTypes from 'prop-types'
import React, { PureComponent } from 'react'

// components
import Card from '../Card'
import Layout from '../Layout'
import { Icon } from '../Icon'
import Link from '../Link'
import {
  Text,
  H2,
  H3,
  Small
} from '../Typography'

// Styles
import Styles from './SubscriptionCard.styles'


const ProductCard = ({
  title,
  description,
  icon,
  active = true,
  onClick
}) => {
  return (
    <Layout
      key={Math.random()}
      sm={6}
      container
      item
      className={`card ${!active ? 'disable' : ''}`}
      onClick={onClick}
      // active={active}
    >
      <Layout>
        <Icon name={icon} className="icon" />
      </Layout>
      <Layout>
        <H3 fontWeight="bold" color="700">
          {title}
          {
            !active && <Icon name="Lock" size="sm" />
          }
        </H3>
        <Text fontWeight="normal" color="300" fontSize="sm">{description}</Text>
      </Layout>
    </Layout>
  )
}

class SubscriptionCard extends PureComponent {
  static propTypes = {
    cards: PropTypes.arrayOf(PropTypes.shape({
      title: PropTypes.string.isRequired,
      description: PropTypes.string.isRequired,
      icon: PropTypes.string.isRequired,
      active: PropTypes.bool,
      onClick: PropTypes.func
    })).isRequired
  }

  render() {
    const { cards } = this.props
    return (
      <Styles.SubscriptionCard>
        <Card>
          <Layout className="header">
            <H2 fontWeight="bold" fontSize="xxlg" color="900">Your Products</H2>
            <Small fontWeight="normal" color="500">You are on the Insights Plan.  </Small>
            <Link to="mailto:inbound@elevatesecurity.com">Request to Upgrade</Link>
          </Layout>
          <Layout container>
            <Layout sm={6} item>
              <Small fontWeight="bold" color="300" className="uppercase">
                Insights
              </Small>
            </Layout>
            <Layout sm={6} item>
              <Small fontWeight="bold" color="300" className="uppercase">
                Influence
              </Small>
            </Layout>
          </Layout>
          <Layout container className="cards">
            {cards.map((item, index) => <ProductCard {...item} key={index.toString()} />)}
          </Layout>
        </Card>
      </Styles.SubscriptionCard>
    )
  }
}

export default SubscriptionCard
