/* global test shallow expect */

import React from 'react'

import Table from './index'

const mockData = require('./mockData.json')

beforeEach(() => {
  jest.spyOn(global.Math, 'random').mockReturnValue(1)
})

afterEach(() => {
  jest.spyOn(global.Math, 'random').mockRestore()
})

test('render Table', () => {
  const wrapper = shallow(<Table totalCount={0} />)
  expect(wrapper).toMatchSnapshot()
})

test('row gets highlighted upon click', () => {
  const columns = [
    {
      key: 'first_name',
      header: 'FIRST NAME',
    },
    {
      key: 'last_name',
      header: 'LAST NAME',
    }
  ]
  const { results } = mockData

  const clickHandler = (event, index) => {
    expect(index).toBe(0)
    expect(event).toBe(results[0])
  }

  const wrapper = shallow(<Table
    totalCount={2}
    columns={columns}
    data={results}
    highlightSelected
    onClickRow={(e, rowIndex) => clickHandler(e, rowIndex)}
  />)

  wrapper.find('.table-body>.table-row>.table-data').at(0).simulate('click')
})

test('row Index state update upon click', () => {
  let clickCount = 0
  const expectedIndex = [0,-1]
  const columns = [
    {
      key: 'first_name',
      header: 'FIRST NAME',
    },
    {
      key: 'last_name',
      header: 'LAST NAME',
    },
    {
      key: 'department',
      header: 'Department',
    }
  ]

  const { results } = mockData
  const clickHandler = (event, index) => {
    expect(event).toHaveProperty(["last_name"])
    expect(index).toBe(expectedIndex[clickCount])
    clickCount += 1
  }

  const wrapper = shallow(<Table
    enabledHeaderContainer
    totalCount={2}
    columns={columns}
    data={results}
    onClickRow={(e, rowIndex) => clickHandler(e, rowIndex)}
  />)

  wrapper.find('.table-body>.table-row>.table-data').at(0).simulate('click')
  wrapper.find('.table-body>.table-row>.table-data').at(0).simulate('click')
})

test('check click on sort icon result in default sort being asc', () => {
  const columns = [
    {
      key: 'first_name',
      header: 'FIRST NAME',
    },
    {
      key: 'last_name',
      header: 'LAST NAME',
    },
    {
      key: 'department',
      header: 'Department',
    }
  ]

  const { results } = mockData
  const sortHandler = (property, direction) => {
    expect(property).toBe(columns[0].key)
    expect(direction).toMatch("asc")
  }

  const wrapper = shallow(<Table
    enabledHeaderContainer
    totalCount={2}
    onSortedChange={sortHandler}
    columns={columns}
    data={results}
    highlightSelected
  />)
  wrapper.find('.table-head>.table-row>.table-data>.table-header-sort-icon').at(0).simulate('click', {preventDefault: () => {}})
})

test('check click on sort icon result in reversed sort for already sorted header', () => {
  const columns = [
    {
      key: 'first_name',
      header: 'FIRST NAME',
      asc: "asc"
    },
    {
      key: 'last_name',
      header: 'LAST NAME',
    },
    {
      key: 'department',
      header: 'Department',
    }
  ]

  const { results } = mockData
  const sortHandler = (property, direction) => {
    expect(property).toBe(columns[0].key)
    expect(direction).toMatch("desc")
  }

  const wrapper = shallow(<Table
    enabledHeaderContainer
    totalCount={2}
    onSortedChange={sortHandler}
    columns={columns}
    data={results}
  />)
  wrapper.find('.table-head>.table-row>.table-data>.table-header-sort-icon').at(0).simulate('click', {preventDefault: () => {}})
})

