/* eslint-disable import/no-extraneous-dependencies */
/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useEffect, useState } from 'react'
import styled from 'styled-components'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'

// Components
import Header from 'components/Header'
import { H3, Body } from 'components/Typography'
import Table from './index'
import { Button } from '../Button'
import HeaderTableContainer from '../HeaderTableContainer'

const mockData = require('./mockData.json')

const columns = [
  {
    key: 'first_name',
    header: 'FIRST NAME',
    title: (value, item) => value
  },
  {
    key: 'last_name',
    header: 'LAST NAME',
    asc: true
  },
  {
    key: 'email',
    header: 'EMAIL'
  },
  {
    key: 'title',
    header: 'TITLE'
  },
  {
    key: 'department',
    header: 'DEPARTMENT'
  },
  {
    key: 'location',
    header: 'LOCATION'
  },
  {
    key: 'score',
    header: 'SCORE'
  },
  {
    key: 'first_name',
    header: 'FULL NAME',
    render: (firstName, row) => <span title={row.title}>{`${row.title} ${firstName} ${row.last_name}`}</span>
  }
]

addDecorator(withA11y)
addDecorator(withKnobs)

const Container = styled.div``

storiesOf('Table', module)
  .addParameters({
    jest: ['Table']
  })
  .add('Table', () => {
    function ContainerMock() {
      const { results } = mockData
      const onClickRow = info => {
        console.log('Click on Row')
        console.log(info)
      }
      return (
        <Container>
          <HeaderTableContainer
            title="Employees"
            button={<Button>Import New Employees</Button>}
            hasSearchInput
            titleOverSearchInput="Last updated Sep 5, 2019 at 12:00 AM"
          />
          <Table
            resizable
            bodyHeight="calc(100vh - 250px)"
            data={results}
            totalCount={results.length}
            columns={columns}
            defaultPage={1}
            defaultPageSize={100}
            pageSizeOptions={[25, 50, 100, 200]}
            onChangeTable={info => console.log(info)}
            onClickRow={onClickRow}
            excludeFromClickRow={['department']}
          />
        </Container>
      )
    }
    return <ContainerMock />
  })
  .add('Table with few items and column resizing', () => {
    const { results } = mockData

    return (
      <Container>
        <HeaderTableContainer
          title="Employees"
          button={<Button>Import New Employees</Button>}
          hasSearchInput
          titleOverSearchInput="Last updated Sep 5, 2019 at 12:00 AM"
        />
        <Table
          resizable
          enabledHeaderContainer
          data={[results[0], results[1], results[2], results[3], results[4]]}
          columns={columns}
          resizingInfo={{
            first_name: { dataResizerWidth: 150, dataWidth: 150 },
            title: { dataResizerWidth: 60, dataWidth: 60 }
          }}
          totalCount={1}
        />
      </Container>
    )
  })
  .add('Table Hovered', () => {
    const { results } = mockData

    return (
      <Container>
        <HeaderTableContainer
          title="Employees"
          button={<Button>Import New Employees</Button>}
          hasSearchInput
          titleOverSearchInput="Last updated Sep 5, 2019 at 12:00 AM"
        />
        <Table
          enabledHeaderContainer
          data={[results[0], results[1], results[2], results[3], results[4]]}
          columns={columns}
          totalCount={1}
          tableHover
        />
      </Container>
    )
  })
  .add('Table Passing Placeholder for Empty Data', () => {
    const emptyData = (
      <React.Fragment>
        <div style={{ textAlign: 'center' }}>
          <Header>
            <img
              src="https://hm-assets.elevatesecurity.com/master/ep/data-integrations/dragosaur-confused.png"
              style={{ maxWidth: '200px' }}
              alt="No Data"
            />
            <br />
            <div style={{ maxWidth: '325px', margin: 'auto' }}>
              <br />
              <H3 color="900" fontWeight="bold">
                No integrations
              </H3>
              <br />
              <Body>
                <span style={{ lineHeight: '24px' }}>
                  No integrations initiated. Get started by clicking on “Add Integrations” button in
                  the top right or on the “All Integrations” tab{' '}
                </span>
              </Body>
            </div>
          </Header>
        </div>
      </React.Fragment>
    )

    return (
      <Container>
        <Table
          enabledHeaderContainer
          data={[]}
          columns={columns}
          totalCount={0}
          tableHover
          placeholderForEmptyData={emptyData}
        />
      </Container>
    )
  })
  .add('Table - Capturing event when Click Row, excluding Some specific cells by key', () => {
    const { results } = mockData
    const onClickRow = info => {
      console.log('Click on Row')
      console.log(info)
    }
    return (
      <Container>
        <HeaderTableContainer
          title="Employees"
          button={<Button>Import New Employees</Button>}
          hasSearchInput
          titleOverSearchInput="Last updated Sep 5, 2019 at 12:00 AM"
        />
        <Table
          enabledHeaderContainer
          data={[results[0], results[1], results[2], results[3], results[4]]}
          columns={columns}
          totalCount={1}
          tableHover
          onClickRow={onClickRow}
          excludeFromClickRow={['department', 'location', 'score']}
        />
      </Container>
    )
  })
  .add('Table - Excluding Some specific columns from sorting', () => {
    const { results } = mockData
    const onClickRow = info => {
      console.log('Click on Row')
      console.log(info)
    }
    return (
      <Container>
        <HeaderTableContainer
          title="Employees"
          button={<Button>Import New Employees</Button>}
          hasSearchInput
          titleOverSearchInput="Last updated Sep 5, 2019 at 12:00 AM"
        />
        <Table
          enabledHeaderContainer
          data={[results[0], results[1], results[2], results[3], results[4]]}
          columns={columns}
          totalCount={1}
          tableHover
          onClickRow={onClickRow}
          excludeSortColumn={['department', 'location', 'score']}
        />
      </Container>
    )
  })
  .add('Table - Highlight clicked row', () => {
    const { results } = mockData
    const [resetRowSelection, setResetRowSelection] = useState(false)
    const onClickRow = (info, index) => {
      console.log(info, index)
    }
    return (
      <Container>
        <button onClick={()=>setResetRowSelection(!resetRowSelection)}>Click</button>
        <HeaderTableContainer
          title="Employees"
          button={<Button>Import New Employees</Button>}
          hasSearchInput
          titleOverSearchInput="Last updated Sep 5, 2019 at 12:00 AM"
        />
        <Table
          enabledHeaderContainer
          data={[results[0], results[1], results[2], results[3], results[4]]}
          columns={columns}
          totalCount={1}
          highlightSelected
          onClickRow={onClickRow}
          excludeFromClickRow={['department', 'location', 'score']}
          resetRowSelection={resetRowSelection}
        />
      </Container>
    )
  })
