import styled from 'styled-components'
import theme from 'theme'
import { Icon } from '../Icon'

export const TableContainer = styled.div`
  display: block;
  min-width: 100%;
  height: 100%;
  overflow: hidden;
  padding: 0 20px;
  .dropdown-container {
    transform: translateY(calc(-100% + 44px));
  }
`
export const TableHeader = styled.div`
  display: inline-block;
  min-width: 100%;
  overflow: hidden;
  padding-right: 8px;
`
export const TableBody = styled.div`
  display: block;
  width: 100%;
  overflow: scroll;
  height: ${({ bodyHeight }) => bodyHeight};
  min-height: ${({ bodyHeight }) => bodyHeight};
  ${props =>
    props.tableHover &&
    `.table-row:hover {
    background: #f5f6f8;
  }
        `}
`

const tableRowSelected = "background-color: #f5f6f8;"

export const TableRow = styled.div`
  display: inline-flex;
  min-width: 100%;
  flex: 0;
  padding: 8px 0;
  border-bottom: 1px solid ${theme.colors.gray.opaque[100]};
  ${props => props.selectedRow && tableRowSelected}
`
export const TableData = styled.div`
  display: flex;
  align-items: center;
  position: relative;
  width: ${({ defaultWidth }) => defaultWidth};
  min-width: ${({ defaultWidth }) => defaultWidth};
  flex: 0 0 ${({ defaultWidth }) => defaultWidth};
  flex-wrap: nowrap;
  overflow: hidden;
  transition: ease width 50ms, ease min-width 50ms, ease flex 50ms;

  span {
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    color: ${theme.text.color.default};
    font-size: 14px;
    line-height: 24px;
    &.span-head {
      color: ${theme.text.color[300]};
      font-size: 12px;
      font-weight: bold;
      line-height: 20px;
    }
  }
`
export const TableResizer = styled.div`
  width: 2px;
  height: 100%;
  position: absolute;
  right: 2px;
  top: 0;
  cursor: col-resize;
`

// TABLE PAGINATION

export const TablePagination = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: flex-start;
  padding: 8px 0;
`
export const TableNavigation = styled.div`
  display: flex;
  align-items: center;
`

const cursorStyle = count => count !== 0 ? "cursor: pointer": "cursor: default"
export const TableNavigationArrow = styled.button`
  height: 32px;
  width: 32px;
  margin: 0;
  opacity: 1;
  background-color: transparent;
  border: none;
  ${({count}) => cursorStyle(count)};
  outline: 0;
  svg {
    width: 10px;
    height: 10px;
    path {
      fill: ${theme.colors.gray.opaque[500]};
    }
  }
  &:disabled {
    svg path {
      fill: ${theme.colors.gray.opaque[200]};
    }
  }
`
export const TableNavigationPageNumbersContent = styled.div`
  display: flex;
  align-items: center;
`
export const TableNavigationPageNumber = styled.button`
  display: block;
  height: 32px;
  width: 32px;
  outline: 0;
  background-color: transparent;
  border: none;
  cursor: pointer;
  font-size: 14px;
  color: ${theme.text.color.link};
  font-weight: bold;
  line-height: 24px;
  text-align: center;
  &:hover {
    color: ${theme.text.color.linkHover};
    text-decoration: underline;
  }
  &:disabled {
    color: ${theme.text.color[500]};
  }
`
export const TableNavigationInfo = styled.div`
  display: flex;
  align-items: center;
`
export const TableRangeInterval = styled.div`
  height: 25.08px;
  font-size: 14px;
  line-height: 25.08px;
  color: ${theme.text.color[500]};
  padding-left: 24px;
  margin-left: 24px;
  border-left: 1px solid ${theme.colors.gray.opaque[200]};
`
export const TableHeaderColumnSortIconContent = styled.div`
  display: flex;
  flex-direction: column;
  padding: 4px;
  margin: 0;
`
export const TableHeaderColumnSortIcon = styled(Icon)`
  transform: ${({ direction }) => (direction === 'up' ? 'rotate(180deg)' : 'none')};
  margin: -5px 0;
  cursor: pointer;
  path {
    fill: ${({ active }) => (active ? theme.text.color.linkHover : theme.colors.gray.opaque[400])};
  }
`
