/* eslint-disable react/jsx-one-expression-per-line */
/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useState } from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'

// Themes

// Components
import Tabs from './index'
import Tab from '../Tab'

import {
  H1,
  Body,
  Text
} from '../Typography'

addDecorator(withA11y)
addDecorator(withKnobs)

const tabs = [
  'First', 'Second', 'Third', 'Fourth'
]

storiesOf('Tabs', module)
  .addParameters({
    jest: ['Tabs'],
  })
  .add('Tabs', () => (
    <Tabs onChange={index => console.log(index)}>
      {
        tabs.map(tab => (
          <Tab title={`${tab} tab`} key={tab}>
            <H1>{`This is the ${tab} Tab Header`}</H1>
            <Body>
              {`This is the ${tab} Tab Content`}
            </Body>
          </Tab>
        ))
      }
    </Tabs>
  ))
  .add('Selected Tab', () => (
    <Tabs onChange={index => console.log(index)}>
      {
        tabs.map(tab => (
          <Tab title={`${tab} tab`} key={tab} selected={tab === 'Third'}>
            <H1>{`This is the ${tab} Tab Header`}</H1>
            <Body>
              {`This is the ${tab} Tab Content`}
            </Body>
          </Tab>
        ))
      }
    </Tabs>
  ))
  .add('Tab Count Header', () => {
    function Component() {
      const title = (
        <Text color="link" name="ArrowsSelect">
          Title
          <Text color="link" padding="0 0 0 2px">(30)</Text>
        </Text>
      )

      return (
        <Tabs onChange={index => console.log(index)}>
          <Tab title={title}>
            <H1>This is the Icon Tab Header</H1>
            <Body>
              This is the Icon Tab Content
            </Body>
          </Tab>
        </Tabs>
      )
    }
    return <Component />
  })
  .add('Tab with states update', () => {
    function Component() {
      const [counter, setCounter] = useState(30)
      const [text, setText] = useState('This is the Icon Tab Content')
      const [headerText, setHeaderText] = useState('This is the Icon Tab Header')

      setTimeout(() => {
        setCounter(30)
        setText('Text updated')
        setHeaderText('Header text updated')
      }, 1000)

      const title = (
        <Text color="link" name="ArrowsSelect">
          Title
          <Text color="link" padding="0 0 0 2px">({counter})</Text>
        </Text>
      )

      return (
        <Tabs onChange={index => console.log(index)}>
          <Tab title={title}>
            <H1>{headerText}</H1>
            <Body>
              {text}
            </Body>
          </Tab>
        </Tabs>
      )
    }
    return <Component />
  })
  .add('Tabs Variable Fonts', () => (
    <Tabs onChange={index => console.log(index)}>
      {
        tabs.map((tab, idx) => {
          const font = idx % 2 ? 'mono' : 'default'

          const title = (
            <Text color="link" fontFamily={font}>
              {
                `(${idx}) ${font}`
              }
            </Text>
          )

          return (
            <Tab title={title} key={tab}>
              <H1>{`This is the ${tab} Tab Header`}</H1>
              <Body>
                {`This is the ${tab} Tab Content`}
              </Body>
            </Tab>
          )
        })
      }
    </Tabs>
  ))
  .add('Tab switch with button click', () => {
    const [currentIndex, setCurrentIndex] = useState(0)
    return (
      <div>
        <button onClick={() => {
          setCurrentIndex(old => old < tabs.length - 1? old+1: 0)
        }}>
          Switch tab
        </button>
        <Tabs onChange={index => {
          console.log(index)
          setCurrentIndex(index)
        }} currentTabIndex={currentIndex}>
          {
            tabs.map(tab => (
              <Tab title={`${tab} tab`} key={tab}>
                <H1>{`This is the ${tab} Tab Header`}</H1>
                <Body>
                  {`This is the ${tab} Tab Content`}
                </Body>
              </Tab>
            ))
          }
        </Tabs>
      </div>
    )
  })
