import React, { useEffect, useRef, useState } from 'react'
import { NameSpan } from './TextOverflow.styles'

function TextOverflow({ name, color = '' }) {
  const [isOverflowed, setIsOverflow] = useState(false)
  const textElementRef = useRef()
  const compareSize = () => {
    const compare = textElementRef.current.scrollWidth > textElementRef.current.clientWidth
    setIsOverflow(compare)
  }

  // compare once and add resize listener on "componentDidMount"
  useEffect(() => {
    compareSize()
    window.addEventListener('resize', compareSize)
  }, [])

  // remove resize listener again on "componentWillUnmount"
  useEffect(
    () => () => {
      window.removeEventListener('resize', compareSize)
    },
    []
  )
  const props = {}
  if (isOverflowed) {
    props['title'] = name
  }

  return (
    <NameSpan ref={textElementRef} {...props} color={color}>
      {name}
    </NameSpan>
  )
}

export default TextOverflow
