// Libraries
import React from 'react'
import PropTypes from 'prop-types'

import {
  EventContainer,
  EventLabel,
  RowContainer,
  TimeLine
} from './TimelineBock.styles'

import { Icon } from '../Icon'
import { Button } from '../Button'

const TimelineBlock = ({
  isDone,
  isCurrent,
  label,
  btnLabel,
  onBtnClick,
  hasNext,
}) => (
  <EventContainer
    isCurrent={isCurrent}
  >
    <RowContainer>
      <Icon name={isDone ? 'CircleChecked' : 'CircleEmpty'} fill="#0C7D84" />
      <EventLabel isDone={isDone}>{label}</EventLabel>
    </RowContainer>
    {(btnLabel && isCurrent) && (
      <Button
        theme={isDone && 'ghost'}
        onClick={onBtnClick}
      >
        {btnLabel}
      </Button>
    )}
    { hasNext && <TimeLine /> }
  </EventContainer>
)

TimelineBlock.propTypes = {
  isDone: PropTypes.bool,
  isCurrent: PropTypes.bool,
  hasNext: PropTypes.bool,
  label: PropTypes.string.isRequired,
  btnLabel: PropTypes.string,
  onBtnClick: PropTypes.func,
}

TimelineBlock.defaultProps = {
  isDone: false,
  isCurrent: false,
  hasNext: false,
  btnLabel: null,
  onBtnClick: () => null,
}

export default TimelineBlock
