// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'

// components
import Card from '../Card'
import TimelineBlock from '../TimelineBlock'
import { Button } from '../Button'
import { H2 } from '../Typography'
import GlobalStyle from '../GlobalStyle'

// Styles
import * as Styles from './TimelineCard.styles'

class TimelineCard extends PureComponent {
  static propTypes = {
    isComplete: PropTypes.bool,
    title: PropTypes.string,
    settings: PropTypes.arrayOf(PropTypes.shape({
      label: PropTypes.string,
      hasNext: PropTypes.bool,
      isCurrent: PropTypes.bool,
      isDone: PropTypes.bool,
      btnLabel: PropTypes.string,
      onBtnClick: PropTypes.func,
    })).isRequired,
    onDismiss: PropTypes.func,
  }

  static defaultProps = {
    isComplete: false,
    title: 'Finish setting up your account',
    onDismiss: () => null,
  }

  constructor(props) {
    super(props)

    this.state = {
      isClosed: false
    }
  }

  closeCard = () => {
    const { onDismiss } = this.props
    this.setState({ isClosed: true })
    onDismiss()
  }

  renderTimelineBlocks = (items = []) => {
    return items.map((item, index) => (
      <TimelineBlock
        {...item}
        key={index.toString()}
      />
    ))
  }

  getTitle = () => {
    const { title, isComplete } = this.props
    return isComplete ? 'Congratulations, your account is set up' : title
  }

  render() {
    const {
      isComplete,
      settings,
    } = this.props
    const {
      isClosed
    } = this.state
    return (
      <>
        <Styles.TimelineCard className={isClosed ? 'close-card' : ''}>
          <Card>
            <H2 fontWeight="bold" fontSize="xxlg" color="900">
              {this.getTitle()}
            </H2>
            {this.renderTimelineBlocks(settings)}
            {
              isComplete && (
                <div className="btn-dismiss">
                  <Button
                    theme="secondary"
                    onClick={this.closeCard}
                    style={{ fontWeight: 'bold', fontSize: '15px' }}
                  >
                    Dismiss
                  </Button>
                </div>
              )
            }
          </Card>
        </Styles.TimelineCard>
        <GlobalStyle />
      </>
    )
  }
}

export default TimelineCard
