import React from 'react'
import PropTypes from 'prop-types'
import styled from 'styled-components'
import CustomSelect from '../CustomSelect'
import { getTimezoneOptions, getDefaultTimezoneOption } from '../../timezone'

const Container = styled.div`
  input[type='text'] {
    border: 1px solid
      ${({ invalid }) => (invalid ? 'rgb(199, 52, 52)' : 'rgba(189, 197, 209, 0.5)')};
    &:hover {
      border: 1px solid rgba(58, 70, 85, 0.3);
    }
    &:focus {
      border: 1px solid rgb(12, 125, 132);
      box-shadow: rgb(12, 125, 132) 0px 0px 3px;
    }
  }
  .dropdown-container {
    width: ${(props) => props.dropdownWidth};
  }
`

const TimezonePicker = ({
  defaultTimezone,
  defaultValue,
  isSearch,
  onChange,
  placeholder,
  width,
  dropdownWidth,
  dropdownMaxHeight,
  invalid
}) => {
  const options = getTimezoneOptions(defaultTimezone)
  const companyDefaultTimezone = getDefaultTimezoneOption(defaultTimezone)

  return (
    <Container dropdownWidth={dropdownWidth} invalid={invalid}>
      <CustomSelect
        options={options}
        isSearch={isSearch}
        defaultValue={defaultValue || (companyDefaultTimezone || {}).value}
        onChange={(e) => onChange(e.value)}
        placeholder={placeholder}
        style={width ? { width } : {}}
        maxHeightDropdown={dropdownMaxHeight}
        searchBy="label"
      />
    </Container>
  )
}

TimezonePicker.propTypes = {
  defaultTimezone: PropTypes.string.isRequired,
  isSearch: PropTypes.bool,
  onChange: PropTypes.func,
  defaultValue: PropTypes.string,
  placeholder: PropTypes.string,
  width: PropTypes.string,
  dropdownWidth: PropTypes.string,
  dropdownMaxHeight: PropTypes.string,
  invalid: PropTypes.bool
}

TimezonePicker.defaultProps = {
  isSearch: true,
  onChange: () => null,
  defaultValue: null,
  placeholder: 'Click to select',
  width: null,
  dropdownWidth: '100%',
  dropdownMaxHeight: '350px',
  invalid: false
}

export default TimezonePicker
