/* eslint-disable no-undef */
/* global test shallow expect */
import { mount } from 'enzyme'
import React from 'react'

import Toggle from './index'

test('render Toggle', () => {
  const wrapper = shallow(<Toggle onChange={e => console.log(e)} name="My toggle" checked />)
  expect(wrapper).toMatchSnapshot()
})

test('Calling the event onChange when the current state is true to false', () => {
  let checkedState = true
  const onChange = jest.fn(({ checked }) => {
    checkedState = checked
  })

  const wrapper = mount(<Toggle onChange={onChange} name="My toggle" checked={checkedState} label="My label" />)
  const clickToggle = wrapper.find('input')
  clickToggle.simulate('change', wrapper.setProps({ checked: !checkedState }))
  expect(wrapper.props().checked).toEqual(false)
  expect(wrapper.props().label).toEqual('My label')
  expect(onChange).toHaveBeenCalledTimes(1)
})


test('Calling the event onChange when the current state is false to true', () => {
  let checkedState = false
  const onChange = jest.fn(({ checked }) => {
    checkedState = checked
  })

  const wrapper = mount(<Toggle onChange={onChange} name="My toggle" checked={checkedState} label="My label" />)
  const clickToggle = wrapper.find('input')
  expect(wrapper.props().label).toEqual('My label')
  clickToggle.simulate('change', wrapper.setProps({ checked: !checkedState }))
  expect(wrapper.props().checked).toEqual(true)
  expect(onChange).toHaveBeenCalledTimes(1)
})


test('Testing update of checked property', () => {
  let checkedState = false
  const onChange = jest.fn(({ checked }) => {
    checkedState = checked
  })

  const wrapper = mount(<Toggle onChange={onChange} name="My toggle" checked={checkedState} label="My label" />)

  expect(wrapper.props().checked).toEqual(false)
  wrapper.setProps({ checked: !checkedState })
  expect(wrapper.props().checked).toEqual(true)
})
