// Libraries
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'

// components
import GlobalStyle from 'components/GlobalStyle'

// styles
import { Icon } from '../Icon'

import {
  Container, Bullet, CheckBox, Content, LabelText
} from './Toggle.styles'

class Toggle extends PureComponent {
  constructor(props) {
    super(props)
    const { checked } = props
    this.state = {
      checked
    }
  }

  componentDidUpdate = ({ checked: oldCheckedValue }) => {
    const { checked } = this.props
    // eslint-disable-next-line react/no-did-update-set-state
    if (oldCheckedValue !== checked) this.setState({ checked })
  }

  handleOnChange = (event) => {
    const { onChange } = this.props
    const { checked } = this.state
    const newCheckedState = !checked
    this.setState({ checked: newCheckedState })
    if (onChange && typeof onChange === 'function') { onChange({ event, checked: newCheckedState }) }
  }

  render = () => {
    const { handleOnChange } = this
    const { checked } = this.state
    const {
      role, name, label, disabled
    } = this.props
    return (
      <>
        <Container disabled={disabled}>
          <Content>
            <CheckBox
              onChange={handleOnChange}
              role={role}
              name={name}
              checked={checked}
              disabled={disabled}
            />
            <Bullet><Icon name="CircleCheckSolid" fill="white" size="sm" /></Bullet>
          </Content>
          {label && <LabelText>{label}</LabelText>}
        </Container>
        <GlobalStyle />
      </>
    )
  }
}

Toggle.defaultProps = {
  role: 'toggle',
  checked: false,
  disabled: false,
  label: null
}
Toggle.propTypes = {
  onChange: PropTypes.func.isRequired,
  name: PropTypes.string.isRequired,
  role: PropTypes.string,
  label: PropTypes.string,
  checked: PropTypes.bool,
  disabled: PropTypes.bool,
}

export default Toggle
