/* global test shallow expect */

import React from 'react'

import Tooltip from './index'
import { H5, Text } from '../Typography'

test('Render read-only Tooltip', () => {
  const wrapper = shallow(
    <Tooltip body="Bottom caret" placement="top" readOnly>
      Top
    </Tooltip>
  )
  expect(wrapper).toMatchSnapshot()
})

test('Render confirmation Tooltip', () => {
  const wrapper = shallow(
    <Tooltip
      body="Top caret"
      placement="top"
      primaryButton="Confirmation Button"
      onPrimaryAction={() => {}}
    >
      Bottom
    </Tooltip>
  )
  expect(wrapper).toMatchSnapshot()
})

test('Render on click Tooltip', () => {
  const wrapper = shallow(
    <Tooltip
      body="Max width. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua."
      placement="top"
      primaryButton="OK, got it"
      onPrimaryAction={() => {}}
      trigger="click"
    >
      <div>
        Trigger on click
      </div>
    </Tooltip>
  )
  expect(wrapper).toMatchSnapshot()
})

test('Render sequential Tooltip with 1 button', () => {
  const wrapper = shallow(
    <Tooltip
      body="Top caret"
      placement="top"
      primaryButton="Next"
      secondaryButton="Back"
      stepNo={1}
      totalSteps={4}
      onPrimaryAction={() => {}}
      onSecondaryAction={() => {}}
    >
      1 button
    </Tooltip>
  )
  expect(wrapper).toMatchSnapshot()
})

test('Render sequential Tooltip with 2 buttons', () => {
  const wrapper = shallow(
    <Tooltip
      body="Top caret"
      placement="top"
      primaryButton="Next"
      secondaryButton="Back"
      stepNo={2}
      totalSteps={4}
      onPrimaryAction={() => {}}
      onSecondaryAction={() => {}}
    >
      2 buttons
    </Tooltip>
  )
  expect(wrapper).toMatchSnapshot()
})

test('Render tootlip with custom body', () => {
  const wrapper = shallow(
    <Tooltip
      body={(
        <div>
          <H5>Service or Area Name</H5>
          <Text fontWeight="normal">
            Some description. Lorem ipsum dolor sit amet.
            <br />
            Some instruction for next steps to unlock.
          </Text>
        </div>
      )}
      placement="right"
      readOnly
    >
      Right
    </Tooltip>
  )
  expect(wrapper).toMatchSnapshot()
})

test('Render tooltip with close button', () => {
  const wrapper = shallow(
    <Tooltip
      body="Top caret"
      placement="bottom"
      showCloseIcon
      trigger="manual"
      visible
      onCloseEvent={() => {}}
    >
      With close button
    </Tooltip>
  )
  expect(wrapper).toMatchSnapshot()
})
