/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React, { useState } from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs } from '@storybook/addon-knobs'
import { action } from '@storybook/addon-actions'

// Components
import { createGlobalStyle } from 'styled-components'
import Tooltip from './index'
import { H5, Text } from '../Typography'
import { Button } from '../Button'

const GlobalStyle = createGlobalStyle`
  .custom-parent { display: inline-block; }
`

addDecorator(withA11y)
addDecorator(withKnobs)

storiesOf('Tooltip', module)
  .addParameters({
    jest: ['Tooltip'],
  })
  .add('Read-only tooltips', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Bottom caret" placement="top" readOnly>
          Top
        </Tooltip>
      </div>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Top caret" placement="bottom" readOnly>
          Bottom
        </Tooltip>
      </div>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Left caret" placement="right" readOnly>
          Right
        </Tooltip>
      </div>
      <div style={{ marginLeft: '300px' }}>
        <Tooltip body="Right caret" placement="left" readOnly>
          Left
        </Tooltip>
      </div>
      <div style={{ marginLeft: '150px' }} readOnly>
        <Tooltip
          body="Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam"
          placement="bottom"
        >
          Maximum width
        </Tooltip>
      </div>
    </div>
  ))
  .add('Sizes', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Hello World!" placement="top" readOnly showOnCreate>
          default
        </Tooltip>
      </div>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Hello World!" placement="top" readOnly size="sm" showOnCreate>
          sm
        </Tooltip>
      </div>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Hello World!" placement="top" readOnly size="xsm" showOnCreate>
          xsm
        </Tooltip>
      </div>
    </div>
  ))
  .add('Theme', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Hello World!" placement="top" size="xsm" readOnly showOnCreate>
          light (default)
        </Tooltip>
      </div>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip body="Hello World!" placement="top" size="xsm" theme="light-border" readOnly showOnCreate>
          light-border
        </Tooltip>
      </div>
    </div>
  ))
  .add('Confirmation tooltips', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip
          body="Top caret"
          placement="top"
          primaryButton="Confirmation Button"
          onPrimaryAction={action('priamry button clicked')}
        >
          Bottom
        </Tooltip>
      </div>
      <div style={{ marginLeft: '300px' }}>
        <Tooltip
          body="Max width. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua."
          placement="bottom"
          primaryButton="OK, got it"
          onPrimaryAction={action('priamry button clicked')}
        >
          Maximum tooltip width; multi-line message
        </Tooltip>
      </div>
      <div style={{ marginLeft: '300px' }}>
        <Tooltip
          body="Max width. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua."
          placement="bottom"
          primaryButton="OK, got it"
          onPrimaryAction={action('priamry button clicked')}
          trigger="click"
        >
          Trigger on click
        </Tooltip>
      </div>
    </div>
  ))
  .add('Sequential tooltips', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip
          body="Top caret"
          placement="top"
          primaryButton="Next"
          secondaryButton="Back"
          stepNo={1}
          totalSteps={4}
          onPrimaryAction={action('priamry button clicked')}
          onSecondaryAction={action('secondary button clicked')}
        >
          1 button
        </Tooltip>
      </div>
      <div style={{ marginLeft: '300px' }}>
        <Tooltip
          body="Top caret"
          placement="top"
          primaryButton="Next"
          secondaryButton="Back"
          stepNo={2}
          totalSteps={4}
          onPrimaryAction={action('priamry button clicked')}
          onSecondaryAction={action('secondary button clicked')}
        >
          2 buttons
        </Tooltip>
      </div>
    </div>
  ))
  .add('Custom body tootltip', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip
          body={(
            <div>
              <H5>Service or Area Name</H5>
              <Text fontWeight="normal">
                Some description. Lorem ipsum dolor sit amet.
                <br />
                Some instruction for next steps to unlock.
              </Text>
            </div>
          )}
          placement="right"
          readOnly
        >
          Right
        </Tooltip>
      </div>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip
          body="Hello <i>World</i>!"
          placement="right"
          readOnly
        >
          Bottom
        </Tooltip>
      </div>
    </div>
  ))
  .add('Tooltip on a button', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip
          body={(
            <div>
              <Text fontWeight="normal">
                {`Lorem ipsum dolor sit amet, consectetur adipiscing elit, 
                sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.`}
              </Text>
            </div>
          )}
          placement="bottom"
          trigger="click"
          parentClass="custom-parent"
        >
          <Button>Click me!</Button>
        </Tooltip>
        <GlobalStyle />
      </div>
    </div>
  ))
  .add('Show on create', () => (
    <div style={{ display: 'flex', padding: '100px 50px' }}>
      <div style={{ marginLeft: '100px' }}>
        <Tooltip
          body={(
            <div>
              <Text fontWeight="normal">
                {`Lorem ipsum dolor sit amet, consectetur adipiscing elit, 
                sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.`}
              </Text>
            </div>
          )}
          placement="right"
          parentClass="custom-parent"
          showOnCreate
        >
          Lorem ipsum dolor sit amet
        </Tooltip>
        <GlobalStyle />
      </div>
    </div>
  ))
  .add('Trigger manullay', () => {
    const [visible, setVisible] = useState(false)
    return (
      <div style={{ display: 'flex', padding: '100px 50px' }}>
        <div style={{ marginLeft: '100px' }}>
          <Button onClick={() => { setVisible(!visible) }}>Click Me!</Button>
          <Tooltip
            body={(
              <div>
                <Text fontWeight="normal">
                  {`Lorem ipsum dolor sit amet, consectetur adipiscing elit, 
                  sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.`}
                </Text>
              </div>
            )}
            placement="right"
            parentClass="custom-parent"
            trigger="manual"
            visible={visible}
            hideOnClick={false}
          >
            <span style={{ marginLeft: '200px' }}>Lorem ipsum dolor sit amet</span>
          </Tooltip>
          <GlobalStyle />
        </div>
      </div>
    )
  })
  .add('Close button', () => {
    const [visible, setVisible] = useState(true)
    return (
      <div style={{ display: 'flex', padding: '100px 50px' }}>
        <div style={{ marginLeft: '100px' }}>
          <Tooltip
            body={(
              <div>
                <H5>Service or Area Name</H5>
                <Text fontWeight="normal">
                  Some description. Lorem ipsum dolor sit amet.
                  <br />
                  Some instruction for next steps to unlock.
                </Text>
              </div>
            )}
            placement="bottom"
            showCloseIcon
            trigger="manual"
            primaryButton="Next"
            secondaryButton="Back"
            stepNo={1}
            totalSteps={4}
            onPrimaryAction={action('priamry button clicked')}
            onSecondaryAction={action('secondary button clicked')}
            visible={visible}
            onCloseEvent={() => { setVisible(!visible) }}
          >
            <span>With close button</span>
          </Tooltip>
        </div>
      </div>
    )
  })
