/* eslint-disable import/no-extraneous-dependencies */

// Libraries
import React from 'react'
import { storiesOf, addDecorator } from '@storybook/react'
import { withA11y } from '@storybook/addon-a11y'
import { withKnobs, select } from '@storybook/addon-knobs'

// Themes
import theme from 'theme'

// Components
import {
  Display,
  H1,
  H2,
  H3,
  H4,
  H5,
  Body,
  Text,
  Small,
  Caption,
} from './index'

addDecorator(withA11y)
addDecorator(withKnobs)

const colors = {}

Object.keys(theme.text.color).forEach((key) => {
  colors[key] = key
})

const fontFamily = {}

Object.keys(theme.text.fontFamily).forEach((key) => {
  fontFamily[key] = key
})

const fontWeight = {}

Object.keys(theme.text.fontWeight).forEach((key) => {
  fontWeight[key] = key
})

const lineHeight = {}

Object.keys(theme.text.lineHeight).forEach((key) => {
  lineHeight[key] = key
})

const Elements = [Display, H1, H2, H3, H4, H5]

storiesOf('Typography', module)
  .addParameters({
    jest: ['Typography'],
  })
  .add('Headers', () => (
    <div style={{
      display: 'flex',
      flexDirection: 'column'
    }}
    >
      {
        Elements.map((Element) => {
          return (
            <Element
              key={Element}
              color={select('Colors', colors, 'default', 'Typography-1')}
              fontFamily={select('Fonts', fontFamily, 'default', 'Typography-1')}
              fontWeight={select('Weight', fontWeight, 'default', 'Typography-1')}
              lineHeight={select('Line Height', lineHeight, 'default', 'Typography-1')}

            >
              The quick brown fox jumps over the lazy dog.
            </Element>
          )
        })
      }
    </div>
  ))
  .add('Caption', () => (
    <div>
      <table>
        <Caption
          color={select('Colors', colors, 'default', 'Typography-1')}
          fontFamily={select('Fonts', fontFamily, 'default', 'Typography-1')}
          fontWeight={select('Weight', fontWeight, 'default', 'Typography-1')}
          lineHeight={select('Line Height', lineHeight, 'default', 'Typography-1')}
        >
          Caption
        </Caption>
      </table>
    </div>
  ))
  .add('Paragraph + Span', () => (
    <div>
      <Body
        color={select('Colors', colors, 'default', 'Typography-1')}
        fontFamily={select('Fonts', fontFamily, 'default', 'Typography-1')}
        fontWeight={select('Weight', fontWeight, 'default', 'Typography-1')}
        lineHeight={select('Line Height', lineHeight, 'default', 'Typography-1')}
      >
        The quick brown fox jumps over the lazy dog.
      </Body>
      <div>
        <Text
          color={select('Colors', colors, 'default', 'Typography-1')}
          fontFamily={select('Fonts', fontFamily, 'default', 'Typography-1')}
          fontWeight={select('Weight', fontWeight, 'default', 'Typography-1')}
          lineHeight={select('Line Height', lineHeight, 'default', 'Typography-1')}
        >
          The quick brown fox (end)
        </Text>
        <Text
          color={select('Colors', colors, 'default', 'Typography-1')}
          fontFamily={select('Fonts', fontFamily, 'default', 'Typography-1')}
          fontWeight={select('Weight', fontWeight, 'default', 'Typography-1')}
          lineHeight={select('Line Height', lineHeight, 'default', 'Typography-1')}
        >
          (start)Jumps over the lazy dog.
        </Text>
      </div>
    </div>
  ))
  .add('Small', () => (
    <div>
      <Small
        color={select('Colors', colors, 'default', 'Typography-1')}
        fontFamily={select('Fonts', fontFamily, 'default', 'Typography-1')}
        fontWeight={select('Weight', fontWeight, 'default', 'Typography-1')}
        lineHeight={select('Line Height', lineHeight, 'default', 'Typography-1')}
      >
        The quick brown fox jumps over the lazy dog.
      </Small>
    </div>
  ))
  .add('Different margin bottom', () => (
    <div>
      <Body marginBottom="sm">This a SM margin bottom</Body>
      <Body marginBottom="md">This a MD margin bottom</Body>
      <Body marginBottom="lg">This a LG margin bottom</Body>
      <Body>This a default margin bottom</Body>
      <Body>This a default margin bottom</Body>
    </div>
  ))
