import moment from 'moment'
import Timezone from 'moment-timezone'

/**
 * converts the UTC timestamp to a corresponding timezone
 *
 * example params:-
 * date: 2020-11-18T17:00:00
 * timezone: Asia/Karachi
 *
 * example return value:-
 * 2020-11-18T22:00 (as Asia/Karachi is GMT+5)
 */
export const utcAndTzToTime = ({ date, timezone }) => {
  const formatedTimezone = timezone
    ? Timezone.tz(moment.utc(date).format(), timezone)
    : Timezone.tz(moment.utc(date).format(), moment.tz.guess())
  return date ? formatedTimezone : null
}

export const timeWithTimeZone = date => {
  const timeZoneAbbr = moment.tz(moment.tz.guess()).format('z')
  const exp = /^[`!@#$%^&*()_+\-={};':"|,.<>?~]/
  let zone = new Date().toLocaleTimeString('en-us', { timeZoneName: 'short' }).split(' ')[2]
  const formattedTime = utcAndTzToTime(date).format('MMM D, YYYY h:mm A')
  return `${formattedTime} ${exp.test(timeZoneAbbr) ? zone : timeZoneAbbr}`
}
