import theme from 'theme'

const colors = theme.colors.data

export const defineSections = (score) => {
  const percentage = score / 100
  const gaugeSections = [0.2, 0.2, 0.2, 0.2, 0.2]

  // Determining which quadrant of the gauge the score falls into
  let scoreQuintant = 0
  const below = percentage % 0.2

  if (score > 1) {
    const quintant = Math.ceil(percentage / 0.2)
    scoreQuintant = below > 0 ? quintant - 1 : quintant
  }

  // Dividing scoreQuintant into the part that falls below the score
  // and the part that falls above it, for coloring purposes
  gaugeSections[scoreQuintant] = below
  gaugeSections.splice(scoreQuintant + 1, 0, 0.2 - below)

  return { gaugeSections, scoreQuintant }
}

export const gaugeScale = (score = null) => {
  if (score && score >= 0) {
    if (score < 20) return colors.flimsy
    if (score < 40) return colors.tenuous
    if (score < 60) return colors.sturdy
    if (score < 80) return colors.fortified
    if (score <= 100) return colors.indestructible
  }
  return colors.none
}

export const formatDate = (date) => {
  const monthNames = [
    'Jan',
    'Feb',
    'Mar',
    'Apr',
    'May',
    'Jun',
    'Jul',
    'Aug',
    'Sep',
    'Oct',
    'Nov',
    'Dec'
  ]

  const month = date.substr(0, 2) - 1

  return monthNames[month]
}

// Date is in format MMYYYY
export const toDate = (date) => {
  if (typeof date === 'object') return date

  const month = date.substr(0, 2) - 1
  const year = date.slice(2)

  return new Date(year, month)
}

export const camelToTitleCase = str => str
// Insert space before upper case letters
  .replace(/([A-Z])/g, match => ` ${match}`)
// Capitalize first letter
  .replace(/^./, match => match.toUpperCase())

export const getCircleDiameter = (score = null) => {
  if (score && score >= 0) {
    if (score < 20) return '24px'
    if (score < 40) return '22px'
    if (score < 60) return '16px'
    if (score < 80) return '12px'
    if (score <= 100) return '8px'
  }
  return 5
}
